@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # User Authentication Module
 #
-# $Id: lonauth.pm,v 1.96 2008/10/02 13:37:52 www Exp $
+# $Id: lonauth.pm,v 1.101.4.1 2009/08/12 19:28:09 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -40,6 +40,7 @@ use Apache::lonmenu();
 use Apache::createaccount;
 use Fcntl qw(:flock);
 use Apache::lonlocal;
+use HTML::Entities;
  
 # ------------------------------------------------------------ Successful login
 sub success {
@@ -73,20 +74,57 @@ sub success {
 # ------------------------------------------------------------ Get cookie ready
     $cookie="lonID=$cookie; path=/";
 # -------------------------------------------------------- Menu script and info
+    my $destination = $lowerurl;
+
+    if (defined($form->{role})) {
+        my $envkey = 'user.role.'.$form->{role};
+        my $now=time;
+        my $then=$env{'user.login.time'};
+        my $refresh=$env{'user.refresh.time'};
+        if (exists($env{$envkey})) {
+            my ($role,$where,$trolecode,$tstart,$tend,$tremark,$tstatus);
+            &Apache::lonnet::role_status($envkey,$then,$refresh,$now,\$role,\$where,
+                                         \$trolecode,\$tstatus,\$tstart,\$tend);
+            if ($tstatus eq 'is') {
+                $destination  .= ($destination =~ /\?/) ? '&' : '?';
+                my $newrole = &HTML::Entities::encode($form->{role},'"<>&');
+                $destination .= 'selectrole=1&'.$newrole.'=1';
+            }
+        }
+    }
+    if (defined($form->{symb})) {
+        my $destsymb = $form->{symb};
+        $destination  .= ($destination =~ /\?/) ? '&' : '?';
+        if ($destsymb =~ /___/) {
+            # FIXME Need to deal with encrypted symbs and urls as needed.
+            my ($map,$resid,$desturl)=split(/___/,$destsymb);
+            unless ($desturl=~/^(adm|uploaded|editupload|public)/) {
+                $desturl = &Apache::lonnet::clutter($desturl);
+            }
+            $desturl = &HTML::Entities::encode($desturl,'"<>&');
+            $destsymb = &HTML::Entities::encode($destsymb,'"<>&');
+            $destination .= '&destinationurl='.$desturl.
+                            '&destsymb='.$destsymb;
+        } else {
+            $destsymb = &HTML::Entities::encode($destsymb,'"<>&');
+            $destination .= '&destinationurl='.$destsymb;
+        }
+    }
+
     my $windowinfo=&Apache::lonmenu::open($env{'browser.os'});
-    my $startupremote=&Apache::lonmenu::startupremote($lowerurl);
+    my $startupremote=&Apache::lonmenu::startupremote($destination);
     my $remoteinfo=&Apache::lonmenu::load_remote_msg($lowerurl);
     my $setflags=&Apache::lonmenu::setflags();
     my $maincall=&Apache::lonmenu::maincall();
     my $start_page=&Apache::loncommon::start_page('Successful Login',
-						  $startupremote,
-						  {'no_inline_link' => 1,});
+                                                  $startupremote,
+                                                  {'no_inline_link' => 1,});
     my $end_page  =&Apache::loncommon::end_page();
 
     my $continuelink;
     if (($env{'browser.interface'} eq 'textual') ||
         ($env{'environment.remote'} eq 'off')) {
-	$continuelink="<a href=\"$lowerurl\">".&mt('Continue')."</a>";
+	$continuelink='<a href="'.$destination.'">'.&mt('Continue').'</a>';
     }
 # ------------------------------------------------- Output for successful login
 
@@ -120,6 +158,14 @@ sub failed {
     my ($r,$message,$form) = @_;
     my $start_page = &Apache::loncommon::start_page('Unsuccessful Login',undef,
 						    {'no_inline_link' => 1,});
+    my $retry = '/adm/login?username='.$form->{'uname'}.
+                '&domain='.$form->{'udom'};
+    if (exists($form->{role})) {
+        $retry .= '&role='.$form->{role};
+    }
+    if (exists($form->{symb})) {
+        $retry .= '&symb='.$form->{symb};
+    }
     my $end_page   = &Apache::loncommon::end_page();
     &Apache::loncommon::content_type($r,'text/html');
     $r->send_http_header;
@@ -127,8 +173,7 @@ sub failed {
        $start_page
       .'<h1>'.&mt('Sorry ...').'</h1>'
       .'<p class="LC_warning">'.&mt($message).'</p>'
-      .'<p>'.&mt('Please [_1]log in again[_2].'
-                ,"<a href=\"/adm/login?username=$form->{'uname'}&domain=$form->{'udom'}\">",'</a>')
+      .'<p>'.&mt('Please [_1]log in again[_2].','<a href="'.$retry.'">','</a>')
       .'</p>'
       .'<p><a href="/adm/loginproblems.html">'.&mt('Login problems?').'</a></p>'
       .$end_page
@@ -172,7 +217,7 @@ sub handler {
         $r->print(
            $start_page
           .'<h1>'.&mt('You are already logged in!').'</h1>'
-          .'<p>'.&mt('Please either [_1]continue the current session[_2] or [_3]logout[_4].'
+          .'<p>'.&mt('Please either [_1]continue the current session[_2] or [_3]log out[_4].'
                     ,'<a href="/adm/roles">','</a>','<a href="/adm/logout">','</a>')
           .'</p>'
           .'<p><a href="/adm/loginproblems.html">'.&mt('Login problems?').'</a></p>'
@@ -231,11 +276,25 @@ sub handler {
 	    return OK;
 	}
     }
+
     if (!&Apache::lonnet::domain($form{'udom'})) {
         &failed($r,'The domain you provided is not a valid LON-CAPA domain.',\%form);
         return OK;
     }
-    my ($key,$firsturl)=split(/&/,$tmpinfo);
+
+    my ($key,$firsturl,$rolestr,$symbstr)=split(/&/,$tmpinfo);
+    if ($rolestr) {
+        $rolestr = &unescape($rolestr);
+    }
+    if ($symbstr) {
+        $symbstr= &unescape($symbstr);
+    }
+    if ($rolestr =~ /^role=/) {
+        (undef,$form{'role'}) = split('=',$rolestr);
+    }
+    if ($symbstr =~ /^symb=/) { 
+        (undef,$form{'symb'}) = split('=',$symbstr);
+    }
 
     my $keybin=pack("H16",$key);
 
