@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # essay (ungraded) style responses
 #
-# $Id: essayresponse.pm,v 1.100 2009/01/21 16:43:30 raeburn Exp $
+# $Id: essayresponse.pm,v 1.101 2009/05/23 18:07:57 riegler Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -67,7 +67,7 @@ sub start_essayresponse {
 		'</label> <br />'.
 		'<label>'.
 		'<input type="radio" name="HWDRAFT'.$part.'_'.$id.'" value="no" /> '.
-		&mt('Save entries below as a draft answer (not submitting them for credit yet)').
+		&mt('Save entries below (not submitted for credit yet)').
 		'</label>'.
 		'</td></tr>';
 	}
