@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # external style responses
 #
-# $Id: externalresponse.pm,v 1.13 2008/02/01 22:05:45 raeburn Exp $
+# $Id: externalresponse.pm,v 1.15 2008/11/20 14:37:37 jms Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -26,6 +26,8 @@
 # http://www.lon-capa.org/
 #
 
+
+
 package Apache::externalresponse;
 use strict;
 use HTTP::Request::Common;
@@ -36,10 +38,16 @@ BEGIN {
     &Apache::lonxml::register('Apache::externalresponse',('externalresponse'));
 }
 
-#FIXME
-# send of response params and their current values (form good enough?
-# what parameters to send?)
-# Need to get returned message displayed 
+=pod
+
+=head1 FIXME (start_externalresponse)
+
+send of response params and their current values (form good enough? what parameters to send?)
+Need to get returned message displayed
+
+=cut
+
+
 sub start_externalresponse {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
     my $result;
@@ -143,3 +151,29 @@ sub format_prior_response {
 __END__
 
 
+=pod
+
+=head1 NAME
+
+Apache::externalresponse.pm
+
+=head1 SYNOPSIS
+
+Handler to evaluate externally graded responses.
+
+This is part of the LearningOnline Network with CAPA project
+described at http://www.lon-capa.org.
+
+=head1 SUBROUTINES
+
+=over
+
+=item start_externalresponse()
+
+=item end_externalresponse()
+
+=item format_prior_response()
+
+=back
+
+=cut
\ No newline at end of file
