@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # The LON-CAPA Homework handler
 #
-# $Id: lonhomework.pm,v 1.298.2.1 2009/03/20 20:36:41 raeburn Exp $
+# $Id: lonhomework.pm,v 1.310 2009/05/11 16:51:22 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -297,12 +297,15 @@ sub check_slot_access {
 	return ('WAITING_FOR_GRADE');
     }
 
-    # no slot is currently open, and has been checked in for this version
-    # previous slot is therefore CLOSED, so therefore the problem is
+    # Previously used slot is no longer open, and has been checked in for this version.
+    # However, the problem is not closed, and potentially, another slot might be
+    # used to gain access to it to work on it, until the due date is reached, and the
+    # problem then becomes CLOSED.  Therefore return the slotstatus - 
+    # (which will be NOT_IN_SLOT).
     if (!defined($slot_name)
 	&& $checkedin 
 	&& $type eq 'problem') {
-	return ('CLOSED',$datemsg);
+        return ($slotstatus);
     }
 
     if ($slotstatus eq 'NOT_IN_A_SLOT' 
@@ -690,7 +693,7 @@ sub analyze_header {
 
     $result .= 
 	&Apache::lonxml::message_location().'
-            <form name="lonhomework" method="POST" action="'.
+            <form name="lonhomework" method="post" action="'.
 	    &HTML::Entities::encode($env{'request.uri'},'<>&"').'">'.
             '<input type="hidden" name="problemmode" value="'.
             $env{'form.problemmode'}.'" />'.
@@ -777,37 +780,62 @@ sub analyze {
     }
     &Apache::lonhtmlcommon::Update_PrgWin($request,\%prog_state,
 					  &mt('Analyzing Results'));
-    $request->print('<hr class="LC_edit_problem_divide" />'.&mt('List of possible answers').': ');
+    $request->print('<hr class="LC_edit_problem_divide" />'
+                   .'<h3>'
+                   .&mt('List of possible answers')
+                   .'</h3>'
+    );
     foreach my $part (sort(keys(%allparts))) {
 	if (defined(@{ $overall{$part.'.answer'} })) {
 	    for (my $i=0;$i<scalar(@{ $overall{$part.'.answer'} });$i++) {
 		my $num_cols=scalar(@{ $overall{$part.'.answer'}[$i][0] });
-		$request->print('<table class="thinborder"><tr><th colspan="'.($num_cols+1).'">'.&mt('Part').' '.$part);
+                $request->print(&Apache::loncommon::start_data_table()
+                               .&Apache::loncommon::start_data_table_header_row()
+                               .'<th colspan="'.($num_cols+1).'">'
+                               .&mt('Part').' '.$part
+                );
 		if (scalar(@{ $overall{$part.'.answer'} }) > 1) {
-		    $request->print(&mt(' Answer [_1]',$i+1));
+		    $request->print(' '.&mt('Answer [_1]',$i+1));
 		}
-		$request->print('</th></tr>');
+		$request->print('</th>'
+                               .&Apache::loncommon::end_data_table_header_row()
+                );
 		my %frequency;
 		foreach my $answer (sort {$a->[0] <=> $b->[0]} (@{ $overall{$part.'.answer'}[$i] })) {
 		    $frequency{join("\0",@{ $answer })}++;
 		}
-		$request->print('<tr><th colspan="'.($num_cols).'">'.&mt('Answer').'</th><th>'.&mt('Frequency').'<br />('
-				.&mt('click for example').')</th></tr>');
+                $request->print(&Apache::loncommon::start_data_table_header_row()
+                               .'<th colspan="'.($num_cols).'">'.&mt('Answer').'</th>'
+                               .'<th>'.&mt('Frequency').'<br />'
+                               .'('.&mt('click for example').')</th>'
+                               .&Apache::loncommon::end_data_table_header_row()
+                );
 		foreach my $answer (sort {(split("\0",$a))[0] <=> (split("\0",$b))[0]} (keys(%frequency))) {
-		    $request->print('<tr><td class="center">'.
-				    join('</td><td class="center">',split("\0",$answer)).
-				    '</td><td class="center"><a href="'.$request->uri.'?rndseed='.$seedexample{join("\0",$part,$i,$answer)}.'">'.$frequency{$answer}.
-				    '</a></td></tr>');
+                    $request->print(&Apache::loncommon::start_data_table_row()
+                                   .'<td>'
+                                   .join('</td><td>',split("\0",$answer))
+				   .'</td>'
+                                   .'<td>'
+                                   .'<a href="'.$request->uri.'?rndseed='.$seedexample{join("\0",$part,$i,$answer)}.'">'.$frequency{$answer}.'</a>'
+				   .'</td>'
+                                   .&Apache::loncommon::end_data_table_row()
+                    );
 		}
-		$request->print('</table>');
+                $request->print(&Apache::loncommon::end_data_table());
 	    }
 	} else {
-	    $request->print('<p>'.&mt('Response').' '.$part.' '.
-			    &mt('is not analyzable at this time').'</p>');
+            $request->print('<p class="LC_warning">'
+                           .&mt('Response [_1] is not analyzable at this time.',$part)
+			   .'</p>'
+            );
 	}
     }
     if (scalar(keys(%allparts)) == 0 ) {
-	$request->print('<p>'.&mt('Found no analyzable responses in this problem, currently only Numerical, Formula and String response styles are supported.').'</p>');
+        $request->print('<p class="LC_warning">'
+                       .&mt('Found no analyzable responses in this problem.'
+                           .' Currently only Numerical, Formula and String response styles are supported.')
+                       .'</p>'
+        );
     }
     &Apache::lonhtmlcommon::Close_PrgWin($request,\%prog_state);
     &analyze_footer($request);
@@ -855,11 +883,12 @@ sub editxmlmode {
     my $result;
     my $problem=&Apache::lonnet::getfile($file);
     if ($problem eq -1) {
-        &Apache::lonxml::error(
+	&Apache::lonxml::error(
             '<b> '
            .&mt('Unable to find [_1]',
                 '<span class="LC_filename">'.$file.'</span>')
            .'</b>');
+
 	$problem='';
     }
     if (defined($env{'form.editxmltext'}) || defined($env{'form.Undo'})) {
@@ -895,7 +924,7 @@ sub editxmlmode {
 				    }});
 	$result.=$start_page.
 	    &renderpage($request,$file,['no_output_web'],1).
-            '<form '.&Apache::edit::form_change_detection().' name="lonhomework" method="POST" action="'.
+            '<form '.&Apache::edit::form_change_detection().' name="lonhomework" method="post" action="'.
 	    &HTML::Entities::encode($env{'request.uri'},'<>&"').'">'.
 	    &Apache::structuretags::remember_problem_state().'
             <div class="LC_edit_problem_editxml_header">
@@ -966,7 +995,7 @@ sub renderpage {
 	    my $filename=(split('/',$file))[-1];
 	    my $error =
 		"<b> ".&mt('Unable to find [_1]',
-                           '<span class="LC_filename">'.$filename.'</span>')
+			   '<span class="LC_filename">'.$filename.'</span>')
 		."</b>";
 	    $result.=
 		&Apache::loncommon::simple_error_page($request,'Not available',
@@ -1112,12 +1141,12 @@ $start_page
 <h1>".&mt("Creating a new $extension resource.")."</h1>
 $errormsg
 ".&mt("The requested file [_1] currently does not exist.",
-      "<tt>$shownurl</tt>")."
+      '<span class="LC_filename">'.$shownurl.'</span>')."
 <p>
 <b>
 ".&mt("To create a new $extension, select a template from the".
-      " list below. Then click on the \"Create $extension\" button.")."</b>
-</p><form action=\"$url\" method=\"POST\">");
+      " list below. Then click on the \"Create $extension\" button.").'</b>
+</p><form action="'.$url.'" method="post">');
 
 	if (defined($templatelist)) {
 	    $request->print($templatelist);
