@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Simple Problem Parameter Setting "Editor"
 #
-# $Id: lonsimpleproblemedit.pm,v 1.20 2009/02/01 20:40:28 raeburn Exp $
+# $Id: lonsimpleproblemedit.pm,v 1.20.2.4 2010/01/29 15:44:41 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -95,15 +95,34 @@ sub hint {
 ENDHINT
 }
 
+sub script {
+    my $text=$qparms{$prefix.'numericalscript'};
+    my $ht=&mt('Scripting (optional)');
+    return (<<ENDSCRIPT);
+<table bgcolor="#ccccaa" cellspacing="4" cellpadding="2">
+<tr><td><b>$ht</b><br />
+<textarea style="width:100%" name="numericalscript" cols="80" rows="4">$text</textarea>
+</td></tr>
+</table>
+<br />
+ENDSCRIPT
+}
+
 sub foil {
     my $number=shift;
-    my %values='';
+    my (%values,%defaultvalues,%customvalues);
+    %defaultvalues = &Apache::lonlocal::texthash(
+                         'unused' => 'Not shown, not used'
+                     );
     if ($qtype eq 'radio') {
-	%values=('true' => 'True', 'false' => 'False');
+        %customvalues = &Apache::lonlocal::texthash(
+                                       'true' => 'True',
+                                       'false' => 'False'
+        );
     } elsif ($qtype eq 'option') {
-	%values=&evaloptionhash($qparms{$prefix.'options'});
+        %customvalues=&evaloptionhash($qparms{$prefix.'options'});
     }
-    $values{'unused'}='Not shown, not used';
+    %values = (%defaultvalues,%customvalues);
     my $value=$qparms{$prefix.'value'.$number};
     unless (defined($value)) { $value='unused'; }
     unless ($values{$value}) { $value='unused'; }
@@ -115,10 +134,14 @@ sub foil {
     unless ($positions{$position}) {
 	$position='random';
     }
-    my $selectvalue=&Apache::loncommon::select_form
-	                                ($value,'value'.$number,%values);
-    my $selectposition=&Apache::loncommon::select_form
-                               ($position,'position'.$number,%positions);
+    my $selectvalue=&Apache::loncommon::select_form(
+                        $value,
+                        'value'.$number,
+                        &Apache::lonlocal::texthash(%values));
+    my $selectposition=&Apache::loncommon::select_form(
+                           $position,
+                           'position'.$number,
+                           &Apache::lonlocal::texthash(%positions));
     my $text=$qparms{$prefix.'text'.$number};
     my %lt=&Apache::lonlocal::texthash('foil'  => 'Foil',
 				       'value' => 'Value',
@@ -178,6 +201,8 @@ sub handler {
 
 # ------------------------------------------------ Prefix for everything stored
     $prefix=$env{'request.course.id'}.'.'.$symb.'.0.';
+#----------------------------------- Prefix for storing weight of Problem Parts
+    my $weightprefix=$env{'request.course.id'}.'.'.$symb.'.';
 # ---------------------------------------------------------- Anything to store?
 
     if (($symb) && (defined($env{'form.questiontype'}))) {
@@ -203,12 +228,24 @@ sub handler {
 		$storecontent{$prefix.$parm}=~s/\s+$//s;
 	    }
 	}
+# ---------------------------------------------------- Set weights of hidden parts to zero
+# ------------------------------------------------------ and used part to 1
+        $storecontent{$weightprefix.'essay.weight'}=0;
+        $storecontent{$weightprefix.'numerical.weight'}=0;
+        $storecontent{$weightprefix.'option.weight'}=0;
+        $storecontent{$weightprefix.'radio.weight'}=0;
+        $storecontent{$weightprefix.'string.weight'}=0;
+        $storecontent{$weightprefix.$env{'form.questiontype'}.'.weight'}=1;
+
 	my $reply=&Apache::lonnet::cput
 	    ('resourcedata',\%storecontent,
 	     $env{'course.'.$env{'request.course.id'}.'.domain'},
 	     $env{'course.'.$env{'request.course.id'}.'.num'});
-
     }
+        
+    &Apache::lonnet::devalidatecourseresdata(
+                        $env{'course.'.$env{'request.course.id'}.'.num'},
+                        $env{'course.'.$env{'request.course.id'}.'.domain'});
 # ------------------------------------------------------------------- Read Data
 
     %qparms=&Apache::lonnet::dump('resourcedata',
@@ -234,21 +271,28 @@ sub handler {
 	$r->print('<table border="2" bgcolor="#FFFFFF" width="100%"><tr><td>'.
                   &rawrendering($symb).
                   '</td></tr></table><br />');
-        $r->print('<form name="simpleedit" method="POST">');
-# Question Type        
-	my %questiontypes=('radio'  => 
-                               '1 out of N multiple choice (radio button)',
-			   'option' => 'Option response',
-                           'string' => 'Short string response',
-                           'essay'  => 'Essay, open end');
+        $r->print('<form name="simpleedit" method="post">');
+# Question Type
+        my %questiontypes=(
+               'radio'     => '1 out of N multiple choice (radio button)',
+               'option'    => 'Option Response',
+               'string'    => 'Short string response',
+               'essay'     => 'Essay, open end',
+               'numerical' => 'Numerical Response');
         $qtype=$qparms{$prefix.'questiontype'};
         unless (defined($qtype)) { $qtype='radio'; }
         unless ($questiontypes{$qtype}) { $qtype='radio'; }
-        $r->print('<b>'.&mt('Question Type').
-		  ': '.&Apache::loncommon::select_form
-	                               ($qtype,'questiontype',%questiontypes).
+        $r->print('<b>'.&mt('Question Type').': '
+           .&Apache::loncommon::select_form(
+                $qtype,
+                'questiontype',
+                &Apache::lonlocal::texthash(%questiontypes)).
   '</b><br /><input type="submit" value="'.&mt('Save and Edit').
   '" /><p>&nbsp;</p>');
+# Script
+        if ($qtype eq 'numerical') {
+           $r->print(&script());
+        }
 # Question Text
         $r->print(&questiontext());
 # Radio, Option ===
@@ -258,8 +302,9 @@ sub handler {
             unless (defined($maxfoils)) { $maxfoils=10; }
             unless ($maxfoils=~/^\d+$/) { $maxfoils=10; }
             if ($maxfoils<=0) { $maxfoils=10; }
-	    my %randomizes=('yes' => 'Display foils in random order',
-			    'no'  => 'Display foils in order given');
+            my %randomizes=(
+                   'yes' => 'Display foils in random order',
+                   'no'  => 'Display foils in order given');
 	    my $randomize=$qparms{$prefix.'randomize'};
             unless (defined($randomize)) { $randomize='yes'; }
             unless ($randomizes{$randomize}) { $randomize='yes'; }
@@ -267,8 +312,10 @@ sub handler {
 		  '<table bgcolor="#00ee44" cellspacing="4" cellpadding="2">'.
 	          '<tr><td>'.&mt('Max number of foils displayed').
 ': <input type="text" size="3" name="maxfoils" value="'.$maxfoils.'" />&nbsp;&nbsp;'.
-		      &Apache::loncommon::select_form
-		      ($randomize,'randomize',%randomizes).
+                      &Apache::loncommon::select_form(
+                          $randomize,
+                          'randomize',
+                          &Apache::lonlocal::texthash(%randomizes)).
 		  '</td></tr><tr><td bgcolor="#AAAAAA">');
 # Option Response: Options
 	    if ($qtype eq 'option') {
@@ -310,13 +357,33 @@ sub handler {
             unless ($stringtypes{$stringtype}) { $stringtype='cs'; }
 	    $r->print(
 		  '<table bgcolor="#00ee44" cellspacing="4" cellpadding="2">'.
-	          '<tr><td>'.&mt('Correct answer').': <input type="text" size="20" name="stringanswer" value="'.$stringanswer.'" />&nbsp;&nbsp;'.
-		      &Apache::loncommon::select_form
-		      ($stringtype,'stringtype',%stringtypes).
+                  '<tr><td><label>'.&mt('Correct answer').': <input type="text" size="20" name="stringanswer" value="'.$stringanswer.'" /></label>&nbsp;&nbsp;'.
+                      &Apache::loncommon::select_form(
+                          $stringtype,
+                          'stringtype',
+                          &Apache::lonlocal::texthash(%stringtypes)).
 		  '</td></tr></table><br />');
 # Hint
 	    $r->print(&hint());
 	}
+        if ($qtype eq 'numerical') {
+            my $numericalanswer=$qparms{$prefix.'numericalanswer'};
+            unless (defined($numericalanswer)) { $numericalanswer=''; }
+            my $numericaltolerance=$qparms{$prefix.'numericaltolerance'};
+            unless (defined($numericaltolerance)) { $numericaltolerance='5%'; }
+            my $numericalsigfigs=$qparms{$prefix.'numericalsigfigs'};
+            unless (defined($numericalsigfigs)) { $numericalsigfigs='1,15'; }
+
+            $r->print(
+                '<table bgcolor="#00ee44" cellspacing="4" cellpadding="2">'.
+                  '<tr><td><label>'.&mt('Correct answer').': <input type="text" size="20" name="numericalanswer" value="'.$numericalanswer.'" /></label>&nbsp;&nbsp;'.
+                  '<label>'.&mt('Unit').':  <input type="text" size="5" name="numericalunit" value="'.$qparms{$prefix.'numericalunit'}.'" /></label>&nbsp;&nbsp;'.
+                  '<label>'.&mt('Format').':  <input type="text" size="5" name="numericalformat" value="'.$qparms{$prefix.'numericalformat'}.'" /></label>&nbsp;&nbsp;'.
+                  '<label>'.&mt('Tolerance').':  <input type="text" size="5" name="numericaltolerance" value="'.$numericaltolerance.'" /></label>&nbsp;&nbsp;'.
+                  '<label>'.&mt('Significant digits').':  <input type="text" size="5" name="numericalsigfigs" value="'.$numericalsigfigs.'" /></label>'.
+                   '</td></tr></table><br />');
+            $r->print(&hint());
+        }
 # Store Button
 	$r->print(
   '<input type="submit" value="'.&mt('Save and Edit').'" /></form>');
