@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # tags that create controlled output
 #
-# $Id: outputtags.pm,v 1.51 2007/10/08 23:02:57 albertel Exp $
+# $Id: outputtags.pm,v 1.56 2009/11/01 16:10:35 foxr Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -26,6 +26,8 @@
 # http://www.lon-capa.org/
 #
 
+
+
 package Apache::outputtags; 
 
 use strict;
@@ -36,14 +38,75 @@ use POSIX qw(strftime);
 BEGIN {
     &Apache::lonxml::register('Apache::outputtags',('displayduedate','displaytitle','displayweight','displaystudentphoto'));
 }
-#  Empties the hash of tags that have already been displayed
-#  that should only be displayed once.
+
+################################ utilities ###########################
+
+# 
+#  Does a simple substitution of a tab when the opening tag can
+#  be replaced by a fixed string.. and same for the closing tag.
+#  Parameters:
+#    $input   - String in in which to do the substitutions.
+#    $tag     - name of tag without the <>'s e.g. sub for <sub></sub>
+#    $opening - What to replace <$tag> with
+#    $closing - What to replace </$tag> with.
+#  Returns:
+#    Input string appropriately substituted.
 #
+sub substitute_tag {
+    my ($input,
+	$tag,
+	$opening,
+	$closing) = @_;
+
+    $input =~ s/<$tag>/$opening/gi;
+    $input =~ s/<\/$tag>/$closing/gi;
+
+    return $input;
+}  
+
+#
+#  Substitutes the simple formatting tags in a string
+#  Parameters:
+#    $string - input string.
+#  Returns
+#    Result of string after simple substitutions
+#  Tags we handle are:
+#    <sub>, <sup> <em>
+#
+sub substitute_simple_tags_latex {
+    my ($string)  = @_;
+
+    # restore the <>'s:
+
+    $string =~ s/\\ensuremath{<}/</g;
+    $string =~ s/\\ensuremath{>}/>/g;
+
+
+    # Substitute the tags:
+
+    $string = &substitute_tag($string, "sub", '\ensuremath{_', '}');
+    $string = &substitute_tag($string, 'sup', '\ensuremath{^', '}');
+    $string = &substitute_tag($string, 'em', '\em{', '}');
+
+
+    # Escape the remaining <>'s again:
+
+    $string =~ s/</\\ensuremath{<}/g;
+    $string =~ s/>/\\ensuremath{>}/g;
+
+
+
+    return $string;
+}
+
+################################ The parser ##########################
+
 sub initialize_outputtags {
     %Apache::outputtags::showonce=();
 }
 
 
+
 sub start_displayduedate {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval)=@_;
     my $result;
@@ -105,8 +168,10 @@ sub start_displayduedate {
 		my $duetext = &Apache::lonnavmaps::timeToHumanString($date, '', $format);
 		if (lc($style) !~ 'plain') {
 		    # The due date will be put in a box.
-		    
-		    $result = '\framebox{'
+		    # at the start of the line to ensure it won't overlap
+		    # the 1 col boundary.
+
+		    $result = '\\\\ \framebox{'
     			       .&mt('Due').' '.$duetext.'}';
 		} else {
 		    $result = &mt('Due') . ' '.$duetext;
@@ -150,6 +215,7 @@ sub start_displaytitle {
 	$result.=&Apache::edit::end_table();
     } elsif ($target eq 'tex' and $Apache::lonhomework::type ne 'exam') {
 	$name=&Apache::lonxml::latex_special_symbols($name);
+	$name = &substitute_simple_tags_latex($name);
 	if (lc($style) !~ 'plain') { 
 	    $result='\vskip 0 mm\noindent\textbf{'.$name.'}\vskip 0 mm';
 	} else {
@@ -277,3 +343,47 @@ sub end_displaystudentphoto {
 
 1;
 __END__
+
+
+=head1 NAME
+
+Apache::outputtags;
+
+=head1 SYNOPSIS
+
+Handles tags associated with output. Seems to
+relate to due dates of the assignment.
+
+This is part of the LearningOnline Network with CAPA project
+described at http://www.lon-capa.org.
+
+=head1 SUBROUTINES
+
+=over
+
+=item start_displayduedate()
+
+=item initialize_outputtags()
+
+Empties the hash of tags that have already been displayed that should only be displayed once.
+
+=item end_displayduedate()
+
+=item start_displaytitle()
+
+=item end_displaytitle()
+
+=item multipart()
+
+=item start_displayweight()
+
+=item end_displayweight()
+
+=item start_displaystudentphoto()
+
+=item end_displaystudentphoto()
+
+
+=back
+
+=cut
