@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: imsimportdocs.pm,v 1.21 2007/08/21 18:22:41 albertel Exp $
+# $Id: imsimportdocs.pm,v 1.23 2009/08/17 03:52:09 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -218,7 +218,7 @@ sub display_one {
         </td>
        </tr>
        <tr bgcolor='#CCCCFF'>
-        <td valign='middle'><img src='/res/adm/pages/bl_step1.gif'>&nbsp;
+        <td valign="middle"><img src="/res/adm/pages/bl_step1.gif" alt="1" />&nbsp;
         </td>
         <td width='100%' align='left'>&nbsp;&nbsp;
          <font face='arial,helvetica,sans-serif'><b>Specify the Course Management system used to create the package.</b>&nbsp;&nbsp;
@@ -237,7 +237,7 @@ Please choose the CMS used to create your IMS content package.&nbsp;&nbsp;
          <option value='-1' selected="true">Please select</option>
          <option value='bb5'>Blackboard 5</option>
          <option value='bb6'>Blackboard 6</option>
-         <option value='angel'>ANGEL</option>
+         <option value='angel5'>ANGEL 5.5</option>
          <option value='webctce4'>WebCT 4 Campus Edition</option>
         </select>
         </font>
@@ -250,7 +250,7 @@ Please choose the CMS used to create your IMS content package.&nbsp;&nbsp;
        <td colspan='2'>&nbsp;</td>
       </tr>
       <tr bgcolor='#CCCCFF'>
-        <td valign='middle'><img src='/res/adm/pages/bl_step2.gif'>&nbsp;
+        <td valign="middle"><img src="/res/adm/pages/bl_step2.gif" alt="2" />&nbsp;
         </td>
         <td width='100%' align='left'>&nbsp;&nbsp;
          <font face='arial,helvetica,sans-serif'><b>Locate the IMS content package you wish to upload.</b>&nbsp;&nbsp;
@@ -346,7 +346,7 @@ sub display_two {
                             $count{$area} ++;
                         }
                     }
-                } elsif ($cms eq 'angel') {
+                } elsif ($cms eq 'angel5') {
                     foreach my $area (keys %{$cmsmap{$cms}}) {
                         if ($area eq 'doc') {
                             if (grep/^$resources{$res}{type}$/,@{$cmsmap{$cms}{doc}}) {
@@ -369,7 +369,7 @@ sub display_two {
        </td>
       </tr>
       <tr bgcolor='#CCCCFF'>
-       <td valign='middle'><img src='/res/adm/pages/bl_step3.gif'>
+       <td valign="middle"><img src="/res/adm/pages/bl_step3.gif" alt="3" />
        </td>
        <td width='100%' align='left'>&nbsp;&nbsp;
         <font face='arial,helvetica,sans-serif'><b>Choose which content types you wish to import</b></font>
@@ -439,7 +439,7 @@ ENDBLOCK
        <td colspan='2'>&nbsp;<br /><br /></td>
       </tr>
       <tr bgcolor='#CCCCFF'>
-       <td valign='middle'><img src='/res/adm/pages/bl_step4.gif'>
+       <td valign="middle"><img src="/res/adm/pages/bl_step4.gif" alt="4" />
        </td>
        <td width='100%' align='left'>&nbsp;&nbsp;
         <font face='arial,helvetica,sans-serif'><b>Choose display options for listing of contents of top level of package.</b></font>
@@ -553,7 +553,7 @@ sub display_three {
 
     foreach my $area (@{$areas}) {
         if (defined($env{"form.$area"}) && ($env{'form.'.$area} ne '')) {
-            if ($cms eq 'angel' && $area eq 'doc') {
+            if ($cms eq 'angel5' && $area eq 'doc') {
                 foreach (@{$cmsmap{$cms}{$area}}) {
                     $importareas{$_} = 1;
                 }
@@ -673,7 +673,7 @@ sub display_three {
        </td>
       </tr>
       <tr bgcolor='#CCCCFF'>
-       <td valign='middle'><img src='/res/adm/pages/bl_step5.gif'>
+       <td valign="middle"><img src="/res/adm/pages/bl_step5.gif" alt="5" />
        </td>
        <td width='100%' align='left'>&nbsp;&nbsp;
         <font face='arial,helvetica,sans-serif'><b>Your import is complete</b></font>
