@@ -2,7 +2,7 @@
 # The LON-CAPA group sort handler
 # Allows for sorting prior to import into RAT.
 #
-# $Id: groupsort.pm,v 1.62 2008/09/15 13:22:48 bisitz Exp $
+# $Id: groupsort.pm,v 1.65 2009/03/13 15:39:43 bisitz Exp $
 # 
 # Copyright Michigan State University Board of Trustees
 #
@@ -314,14 +314,23 @@ END
 		'cs' => 'Continue Search',
 		'fi' => 'Finish Import',
 		're' => 'Recover Checked',
+		'ip' => 'Import Checked',
 		'ca' => 'Cancel',
 		'co' => 'Change Order',
 		'ti' => 'Title',
 		'pa' => 'Path',
                 'in' => 'Include'
 		);
-	my $title = ($env{'form.recover'}) ? 'Recover Removed Resources'
-                                           : 'Sort Imported Resources';
+        my $title = '';
+        if ($env{'form.recover'}) {
+            $title = 'Recover Removed Resources';
+        } else {
+            $title = 'Sort Imported Resources';
+        }
+        if ($env{'form.bookmarks'}) {
+            $title = 'Import Resources from Bookmarks';
+        }
+
 	$r->print(&Apache::loncommon::start_page($title, $js));
 
 	$r->print(<<END);
@@ -338,10 +347,14 @@ END
 
         $r->print(&Apache::loncommon::inhibit_menu_check('input'));
         # ---
-    
-        if ($env{'form.recover'}) {
+
+        my $buttontext = $lt{'re'};
+        if ($env{'form.bookmarks'}) {
+            $buttontext = $lt{'ip'}
+        }
+        if ($env{'form.recover'} || $env{'form.bookmarks'}) {
 	    $r->print(<<END);
-<input type="button" name="alter" value="$lt{'re'}"
+<input type="button" name="alter" value="$buttontext"
  onClick="finish_import()" />&nbsp;
 <input type="button" name="alter" value="$lt{'ca'}" onClick="self.close()" />
 END
@@ -363,17 +376,26 @@ END
 <br />
 END
         }
-        $r->print(&Apache::loncommon::start_data_table()
-                 .&Apache::loncommon::start_data_table_header_row());
-	if (($env{'form.readfile'}) || ($env{'form.bookmarks'})) { 
-	    $r->print("<th>$lt{'in'}</th>\n");
-	} else { 
-	    $r->print("<th colspan='2'>$lt{'co'}</th>\n"); 
-	}
-	$r->print("<th colspan='2'>$lt{'ti'}</th>\n");
-	$r->print("<th>$lt{'pa'}</th>");
-        $r->print(&Apache::loncommon::end_data_table_header_row()
-                 ."\n");
+
+        # Only display header if content exists
+        if ($clen > 0) {
+            $r->print(&Apache::loncommon::start_data_table()
+                     .&Apache::loncommon::start_data_table_header_row());
+            if (($env{'form.readfile'}) || ($env{'form.bookmarks'})) { 
+                $r->print("<th>$lt{'in'}</th>\n");
+            } else { 
+                $r->print('<th colspan="2">'.$lt{'co'}.'</th>'."\n"); 
+            }
+            $r->print('<th colspan="2">'.$lt{'ti'}.'</th>'."\n");
+            $r->print("<th>$lt{'pa'}</th>");
+            $r->print(&Apache::loncommon::end_data_table_header_row()."\n");
+        } else {
+            $r->print('<p class="LC_info">');
+            if ($env{'form.bookmarks'}) {
+                $r->print(&mt('There are no resources in your bookmarks to import.'));
+            }
+            $r->print('</p>');
+        }
     } else {
 	$r->print(&Apache::loncommon::start_page(undef,$js,
 						 {'only_body' => 1}));
@@ -419,8 +441,10 @@ END
 	} 
     }
     if (($clen > 1) || ($env{'form.readfile'}) || ($env{'form.bookmarks'})) {
-        $r->print(&Apache::loncommon::end_data_table()
-                 ."</form>");
+        if ($clen > 0) {
+            $r->print(&Apache::loncommon::end_data_table());
+        }
+        $r->print('</form>');
     } else {
 	$r->print(<<END);
 <script type="text/javascript">
@@ -495,3 +519,30 @@ sub checkbox {
 1;
 
 __END__
+
+=pod
+
+=head1 NAME
+
+Apache::groupsort.pm
+
+=head1 SYNOPSIS
+
+Implements a second phase of importing
+multiple resources into the RAT. Allows for
+reordering the sequence of resources
+
+This is part of the LearningOnline Network with CAPA project
+described at http://www.lon-capa.org.
+
+
+=head1 NOTABLE SUBROUTINES
+
+=over
+
+=item 
+
+=back
+
+=cut
+
