@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # a pile of common html routines
 #
-# $Id: lonhtmlcommon.pm,v 1.182.2.1 2009/01/12 01:53:38 raeburn Exp $
+# $Id: lonhtmlcommon.pm,v 1.182.4.13 2010/03/19 22:34:23 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -62,6 +62,46 @@ use Apache::lonlocal;
 use Apache::lonnet;
 use LONCAPA;
 
+sub coursepreflink {
+    my ($text,$category)=@_;
+    if (&Apache::lonnet::allowed('opa',$env{'request.course.id'})) {
+        return '<a href="/adm/courseprefs?phase=display&amp;actions='.$category.'">'.$text.'</a>';
+    } else {
+        return '';
+    }
+}
+
+sub raw_href_to_link {
+    my ($message)=@_;
+    $message=~s/(https?\:\/\/[^\s\'\"\<]+)([\s\<]|$)/<a href="$1"><tt>$1<\/tt><\/a>$2/gi;
+    return $message;
+}
+
+##############################################
+##############################################
+
+=pod
+
+=item confirm_success
+
+Successful completion of an operation message
+
+=cut
+
+sub confirm_success {
+   my ($message,$failure)=@_;
+   if ($failure) {
+      return '<span class="LC_error" style="font-size: inherit;">'."\n"
+            .'<img src="/adm/lonIcons/navmap.wrong.gif" alt="'.&mt('Error').'" /> '."\n"
+            .$message."\n"
+            .'</span>'."\n";
+   } else {
+      return '<span class="LC_success">'."\n"
+            .'<img src="/adm/lonIcons/navmap.correct.gif" alt="'.&mt('OK').'" /> '."\n"
+            .$message."\n"
+            .'</span>'."\n";
+   }
+}
 
 ##############################################
 ##############################################
@@ -105,11 +145,13 @@ sub dragmath_js {
     my ($popup) = @_;
     return <<ENDDRAGMATHJS;
                 <script type="text/javascript">
+                // <![CDATA[
                   function mathedit(textarea, doc) {
                      targetEntry = textarea;
                      targetDoc   = doc;
                      newwin  = window.open("/adm/dragmath/applet/$popup.html","","width=565,height=500,resizable");
                   }
+                // ]]>
                 </script>
 
 ENDDRAGMATHJS
@@ -195,6 +237,9 @@ sub select_recent {
 	unless ($value =~/^error\:/) {
 	    my $escaped = &Apache::loncommon::escape_url($value);
 	    &Apache::loncommon::inhibit_menu_check(\$escaped);
+            if ($area eq 'residx') {
+                next if ((!&Apache::lonnet::allowed('bre',$value)) && (!&Apache::lonnet::allowed('bro',$value)));
+            }
 	    $return.="\n<option value='$escaped'>".
 		&unescape((split(/\&/,$recent{$value}))[1]).
 		'</option>';
@@ -285,7 +330,7 @@ sub checkbox {
         $Str .= 'value="'.$value.'"';
     } 
     if ($checked) {
-        $Str .= ' checked="1"';
+        $Str .= ' checked="checked"';
     }
     $Str .= ' />';
     return $Str;
@@ -307,7 +352,7 @@ sub radio {
         $Str .= 'value="'.$value.'"';
     } 
     if ($checked eq $value) {
-        $Str .= ' checked="1"';
+        $Str .= ' checked="checked"';
     }
     $Str .= ' />';
     return $Str;
@@ -391,8 +436,8 @@ sub date_setter {
         ($tzname,$sec,$min,$hour,$mday,$month,$year) = &get_timedates($currentvalue); 
     }
     unless ($wasdefined) {
-        ($tzname,$sec,$min,$hour,$mday,$month,$year) = &get_timedates($now);
 	if (($defhour) || ($defmin) || ($defsec)) {
+            ($tzname,$sec,$min,$hour,$mday,$month,$year) = &get_timedates($now);
 	    $sec=($defsec?$defsec:0);
 	    $min=($defmin?$defmin:0);
 	    $hour=($defhour?$defhour:0);
@@ -405,6 +450,7 @@ sub date_setter {
     my $result = "\n<!-- $dname date setting form -->\n";
     $result .= <<ENDJS;
 <script type="text/javascript">
+// <![CDATA[
     function $dname\_checkday() {
         var day   = document.$formname.$dname\_day.value;
         var month = document.$formname.$dname\_month.value;
@@ -465,6 +511,7 @@ document.$formname.$dname\_year.value,
         }
 
     }
+// ]]>
 </script>
 ENDJS
     $result .= '  <span style="white-space: nowrap;">';
@@ -476,23 +523,23 @@ ENDJS
     unshift(@Months,'If you can read this an error occurred');
     if ($includeempty) { $monthselector.="<option value=''></option>"; }
     for(my $m = 1;$m <=$#Months;$m++) {
-        $monthselector .= qq{      <option value="$m" };
-        $monthselector .= "selected " if ($m-1 eq $month);
-        $monthselector .= '> '.&mt($Months[$m]).' </option>';
+        $monthselector .= qq{      <option value="$m"};
+        $monthselector .= ' selected="selected"' if ($m-1 eq $month);
+        $monthselector .= '> '.&mt($Months[$m]).' </option>'."\n";
     }
     $monthselector.= '  </select>';
     # Day
     my $dayselector = qq{<input type="text" name="$dname\_day" $state value="$mday" size="3" $special onchange="javascript:$dname\_checkday()" />};
     # Year
-    my $yearselector = qq{<input type="year" name="$dname\_year" $state value="$year" size="5" $special onchange="javascript:$dname\_checkday()" />};
+    my $yearselector = qq{<input type="text" name="$dname\_year" $state value="$year" size="5" $special onchange="javascript:$dname\_checkday()" />};
     #
     my $hourselector = qq{<select name="$dname\_hour" $special $state >};
     if ($includeempty) { 
         $hourselector.=qq{<option value=''></option>};
     }
     for (my $h = 0;$h<24;$h++) {
-        $hourselector .= qq{<option value="$h" };
-        $hourselector .= "selected " if (defined($hour) && $hour == $h);
+        $hourselector .= qq{<option value="$h"};
+        $hourselector .= ' selected="selected"' if (defined($hour) && $hour == $h);
         $hourselector .= ">";
         my $timest='';
         if ($h == 0) {
@@ -580,7 +627,7 @@ Inputs:
 
 =item $dname
 
-The name passed to &datesetter, which prefixes the form elements.
+The name passed to &date_setter, which prefixes the form elements.
 
 =item $defaulttime
 
@@ -949,7 +996,8 @@ sub Create_PrgWin {
 
 	#the whole function called through timeout is due to issues
 	#in mozilla Read BUG #2665 if you want to know the whole story
-	&r_print($r,'<script type="text/javascript">'.
+	&r_print($r,'<script type="text/javascript">'."\n".
+        '// <![CDATA['."\n".
         "var popwin;
          function openpopwin () {
          popwin=open(\'\',\'popwin\',\'width=400,height=100\');".
@@ -960,7 +1008,9 @@ sub Create_PrgWin {
 	      &mt('Starting').'" /><\\/form>'.$end_page.
               "\');".
         "popwin.document.close();}".
-        "\nwindow.setTimeout(openpopwin,0)</script>");
+        "\nwindow.setTimeout(openpopwin,0)\n".
+        '// ]]>'."\n".
+        '</script>');
 	$prog_state{'formname'}='popremain';
 	$prog_state{'inputname'}="remaining";
     } elsif ($type eq 'inline') {
@@ -993,10 +1043,14 @@ sub Create_PrgWin {
 # update progress
 sub Update_PrgWin {
     my ($r,$prog_state,$displayString)=@_;
-    &r_print($r,'<script type="text/javascript">'.$$prog_state{'window'}.'.document.'.
+    &r_print($r,'<script type="text/javascript">'."\n".
+             '// <![CDATA['."\n".
+             $$prog_state{'window'}.'.document.'.
 	     $$prog_state{'formname'}.'.'.
 	     $$prog_state{'inputname'}.'.value="'.
-	     $displayString.'";</script>');
+	     $displayString.'";'."\n".
+             '// ]]>'."\n".
+             '</script>');
     $$prog_state{'laststart'}=&Time::HiRes::time();
 }
 
@@ -1014,7 +1068,7 @@ sub Increment_PrgWin {
     # 
     my $str;
     if ($min == 0 && $sec > 1) {
-        $str = '[_2] seconds';
+        $str = '[_1] seconds';
     } elsif ($min == 1 && $sec > 1) {
         $str = '1 minute [_2] seconds';
     } elsif ($min == 1 && $sec < 2) {
@@ -1049,11 +1103,15 @@ sub Increment_PrgWin {
     if ($user_browser eq 'explorer' && $user_os =~ 'mac') {
         $lasttime = '';
     }
-    &r_print($r,'<script>'.$$prog_state{'window'}.'.document.'.
+    &r_print($r,'<script>'."\n".
+             '// <![CDATA['."\n".
+             $$prog_state{'window'}.'.document.'.
 	     $$prog_state{'formname'}.'.'.
 	     $$prog_state{'inputname'}.'.value="'.
 	     $$prog_state{'done'}.'/'.$$prog_state{'max'}.
-	     ': '.$time_est.' '.&mt('remaining').' '.$lasttime.'";'.'</script>');
+	     ': '.$time_est.' '.&mt('remaining').' '.$lasttime.'";'."\n".
+             '// ]]>'."\n".
+             '</script>');
     $$prog_state{'laststart'}=&Time::HiRes::time();
 }
 
@@ -1061,7 +1119,11 @@ sub Increment_PrgWin {
 sub Close_PrgWin {
     my ($r,$prog_state)=@_;
     if ($$prog_state{'type'} eq 'popup') {
-	&r_print($r,'<script>popwin.close()</script>'."\n");
+	&r_print($r,'<script>'."\n".
+                 '// <![CDATA['."\n".
+                 'popwin.close()'."n".
+                 '// ]]>'."\n".
+                 '</script>'."\n");
     } elsif ($$prog_state{'type'} eq 'inline') {
 	&Update_PrgWin($r,$prog_state,&mt('Done'));
     }
@@ -1092,7 +1154,7 @@ sub crumbs {
     my $output='';
     unless ($noformat) { $output.='<br /><tt><b>'; }
     $output.='<font size="'.$size.'">'.$prefix.'/';
-    if ($env{'user.adv'}) {
+    if (($env{'user.adv'}) || ($env{'user.author'})) {
 	my $path=$prefix.'/';
 	foreach my $dir (split('/',$uri)) {
             if (! $dir) { next; }
@@ -1142,7 +1204,8 @@ sub spellheader {
 
     my $nothing=&javascript_nothing();
     return (<<ENDCHECK);
-<script type="text/javascript"> 
+<script type="text/javascript">
+// <![CDATA[
 //<!-- BEGIN LON-CAPA Internal
 var checkwin;
 
@@ -1153,6 +1216,7 @@ function spellcheckerwindow(string) {
     checkwin.document.close();
 }
 // END LON-CAPA Internal -->
+// ]]>
 </script>
 ENDCHECK
 }
@@ -1226,7 +1290,8 @@ sub htmlareaselectactive {
     my @fields=@_;
     unless (&htmlareabrowser()) { return ''; }
     if (&htmlareablocked()) { return '<br />'.&enablelink(@fields); }
-    my $output='<script type="text/javascript" defer="1">';
+    my $output='<script type="text/javascript" defer="defer">'.
+               '// <![CDATA[';
     my $lang = &htmlarea_lang();
     foreach my $field (@fields) {
 	$output.="
@@ -1239,7 +1304,9 @@ sub htmlareaselectactive {
     oFCKeditor.Config['DefaultLanguage'] = '$lang';
 }";
     }
-    $output.="\nwindow.status='Activated Editfields';\n</script><br />".
+    $output.="\nwindow.status='Activated Editfields';\n".
+             '// ]]>'."\n".
+             '</script><br />'.
 	&disablelink(@fields);
     return $output;
 }
@@ -1278,9 +1345,6 @@ Inputs: $component (the large text on the right side of the table),
         $menulink (boolean, controls whether to include a link to /adm/menu)
         $helplink (if 'nohelp' don't include the orange help link)
         $css_class (optional name for the class to apply to the table for CSS)
-        $no_mt (optional flag, 1 if &mt() is _not_ to be applied to $component
-           when including the text on the right.
-
 Returns a string containing breadcrumbs for the current page.
 
 =item clear_breadcrumbs
@@ -1316,7 +1380,7 @@ returns: nothing
         my $bug = '';
 	my $help='';
 	# Crumb Symbol
-	my $crumbsymbol = ' &#x25b6; ';
+	my $crumbsymbol = '&raquo;&nbsp;';
         # The last breadcrumb does not have a link, so handle it separately.
         my $last = pop(@Crumbs);
         #
@@ -1325,8 +1389,9 @@ returns: nothing
         if ($menulink) {
             my $description = 'Menu';
             my $no_mt_descr = 0;
-            if (exists($env{'request.course.id'}) && 
-                $env{'request.course.id'} ne '') {
+            if ((exists($env{'request.course.id'})) &&
+                ($env{'request.course.id'} ne '') &&
+                ($env{'course.'.$env{'request.course.id'}.'.description'} ne '')) {
                 $description = 
                     $env{'course.'.$env{'request.course.id'}.'.description'};
                 $no_mt_descr = 1;
@@ -1472,6 +1537,9 @@ returns: nothing
 # routines, but can also be called directly to start and end rows which have 
 # needs that are not accommodated by the *_select_row() routines.    
 
+{ # Start: row_count block for pick_box
+my @row_count;
+
 sub start_pick_box {
     my ($css_class) = @_;
     if (defined($css_class)) {
@@ -1479,6 +1547,7 @@ sub start_pick_box {
     } else {
 	$css_class= 'class="LC_pick_box"';
     }
+    unshift(@row_count,0);
     my $output = <<"END";
  <table $css_class>
 END
@@ -1486,6 +1555,7 @@ END
 }
 
 sub end_pick_box {
+    shift(@row_count);
     my $output = <<"END";
        </table>
 END
@@ -1501,11 +1571,12 @@ END
 
 sub row_title {
     my ($title,$css_title_class,$css_value_class) = @_;
+    $row_count[0]++;
+    my $css_class = ($row_count[0] % 2)?'LC_odd_row':'LC_even_row';
     $css_title_class ||= 'LC_pick_box_title';
     $css_title_class = 'class="'.$css_title_class.'"';
 
     $css_value_class ||= 'LC_pick_box_value';
-    $css_value_class = 'class="'.$css_value_class.'"';
 
     if ($title ne '') {
         $title .= ':';
@@ -1515,7 +1586,7 @@ sub row_title {
             <td $css_title_class>
 	       $title
             </td>
-            <td $css_value_class>
+            <td class="$css_value_class $css_class">
 ENDONE
     return $output;
 }
@@ -1537,14 +1608,21 @@ ENDTWO
     return $output;
 }
 
+} # End: row_count block for pick_box
+
+
 sub role_select_row {
     my ($roles,$title,$css_class,$show_separate_custom,$cdom,$cnum) = @_;
+    my $crstype = 'Course';
+    if ($cdom ne '' && $cnum ne '') {
+        $crstype = &Apache::loncommon::course_type($cdom.'_'.$cnum);
+    }
     my $output;
     if (defined($title)) {
         $output = &row_title($title,$css_class);
     }
     $output .= qq|
-                                  <select name="roles" multiple >\n|;
+                                  <select name="roles" multiple="multiple" >\n|;
     foreach my $role (@$roles) {
         my $plrole;
         if ($role eq 'ow') {
@@ -1563,7 +1641,7 @@ sub role_select_row {
                 $plrole = &mt('Custom Role');
             }
         } else {
-            $plrole=&Apache::lonnet::plaintext($role);
+            $plrole=&Apache::lonnet::plaintext($role,$crstype);
         }
         if (($role ne 'cr') || (!$show_separate_custom)) {
             $output .= '  <option value="'.$role.'">'.$plrole.'</option>';
@@ -1578,17 +1656,18 @@ sub role_select_row {
 
 sub course_select_row {
     my ($title,$formname,$totcodes,$codetitles,$idlist,$idlist_titles,
-	$css_class) = @_;
+	$css_class,$crstype) = @_;
     my $output = &row_title($title,$css_class);
-    $output .= &course_selection($formname,$totcodes,$codetitles,$idlist,$idlist_titles);
+    $output .= &course_selection($formname,$totcodes,$codetitles,$idlist,$idlist_titles,$crstype);
     $output .= &row_closure();
     return $output;
 }
 
 sub course_selection {
-    my ($formname,$totcodes,$codetitles,$idlist,$idlist_titles) = @_;
+    my ($formname,$totcodes,$codetitles,$idlist,$idlist_titles,$crstype) = @_;
     my $output = qq|
 <script type="text/javascript">
+// <![CDATA[
     function coursePick (formname) {
         for  (var i=0; i<formname.coursepick.length; i++) {
             if (formname.coursepick[i].value == 'category') {
@@ -1611,11 +1690,22 @@ sub course_selection {
             formname.courselist = '';
         }
     }
+// ]]>
 </script>
     |;
+
+    my ($allcrs,$pickspec);
+    if ($crstype eq 'Community') {
+        $allcrs = &mt('All communities');
+        $pickspec = &mt('Pick specific communities:');
+    } else {
+        $allcrs = &mt('All courses');
+        $pickspec = &mt('Pick specific course(s):');
+    }
+
     my $courseform='<b>'.&Apache::loncommon::selectcourse_link
-                     ($formname,'pickcourse','pickdomain','coursedesc','',1).'</b>';
-        $output .= '<input type="radio" name="coursepick" value="all" onclick="coursePick(this.form)" />'.&mt('All courses').'<br />';
+                     ($formname,'pickcourse','pickdomain','coursedesc','',1,$crstype).'</b>';
+        $output .= '<input type="radio" name="coursepick" value="all" onclick="coursePick(this.form)" />'.$allcrs.'<br />';
     if ($totcodes > 0) {
         my $numtitles = @$codetitles;
         if ($numtitles > 0) {
@@ -1660,7 +1750,7 @@ sub course_selection {
             $output .= '</tr></table><br />';
         }
     }
-    $output .= '<input type="radio" name="coursepick" value="specific" onclick="coursePick(this.form);opencrsbrowser('."'".$formname."','dccourse','dcdomain','coursedesc','','1'".')" />'.&mt('Pick specific course(s):').' '.$courseform.'&nbsp;&nbsp;<input type="text" value="0" size="4" name="coursetotal" /><input type="hidden" name="courselist" value="" />selected.<br />'."\n";
+    $output .= '<input type="radio" name="coursepick" value="specific" onclick="coursePick(this.form);opencrsbrowser('."'".$formname."','dccourse','dcdomain','coursedesc','','1'".')" />'.$pickspec.' '.$courseform.'&nbsp;&nbsp;<input type="text" value="0" size="4" name="coursetotal" /><input type="hidden" name="courselist" value="" />selected.<br />'."\n";
     return $output;
 }
 
@@ -1671,7 +1761,7 @@ sub status_select_row {
         $output = &row_title($title,$css_class,'LC_pick_box_select');
     }
     $output .= qq|
-                                    <select name="types" multiple>\n|;
+                                    <select name="types" multiple="multiple">\n|;
     foreach my $status_type (sort(keys(%{$types}))) {
         $output .= '  <option value="'.$status_type.'">'.$$types{$status_type}.'</option>';
     }
@@ -1756,8 +1846,7 @@ sub topic_bar {
     return '
 <div class="LC_topic_bar">
     <img alt="'.&mt('Step [_1]',$imgnum).
-              '"src="/res/adm/pages/bl_step'.$imgnum.'.gif" />&nbsp;
-    <span>'.$title.'</span>
+              '" src="/res/adm/pages/bl_step'.$imgnum.'.gif" />&nbsp;'.$title.'
 </div>
 ';
 }
@@ -1894,7 +1983,7 @@ sub set_form_elements {
             $values{$name}[$i] =~ s/([\r\n\f]+)/\\n/g;
             $values{$name}[$i] =~ s/"/\\"/g;
         }
-        if ($$elements{$name} eq 'text') {
+        if (($$elements{$name} eq 'text') || ($$elements{$name} eq 'hidden')) {
             my $numvalues = @{$values{$name}};
             if ($numvalues > 1) {
                 my $valuestring = join('","',@{$values{$name}});
@@ -1929,6 +2018,8 @@ sub set_form_elements {
                     $output .= qq|
       if (courseForm.elements['$name'].value == "$value") {
           courseForm.elements['$name'].checked = true;
+      } else {
+          courseForm.elements['$name'].checked = false;
       }|;
                 }
             }
@@ -1970,6 +2061,7 @@ sub set_form_elements {
         }
     }
     $output .= "
+    return;
 }\n";
     return $output;
 }
