@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Routines to control the menu
 #
-# $Id: lonmenu.pm,v 1.239.4.5 2009/05/15 20:36:17 raeburn Exp $
+# $Id: lonmenu.pm,v 1.244.2.14 2010/01/19 16:53:10 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -36,6 +36,100 @@
 # browser.interface is 'textual'
 #
 
+=head1 NAME
+
+Apache::lonmenu
+
+=head1 SYNOPSIS
+
+Coordinates the response to clicking an image.
+
+This is part of the LearningOnline Network with CAPA project
+described at http://www.lon-capa.org.
+
+=head1 SUBROUTINES
+
+=over
+
+=item show_course()
+
+Little texts
+
+=item initlittle()
+
+=item menubuttons()
+
+This gets called at the top of the body section
+
+=item show_return_link()
+
+=item registerurl()
+
+This gets called in the header section
+
+=item innerregister()
+
+This gets called in order to register a URL, both with the Remote
+and in the body of the document
+
+=item loadevents()
+
+=item unloadevents()
+
+=item startupremote()
+
+=item setflags()
+
+=item maincall()
+
+=item load_remote_msg()
+
+=item get_menu_name()
+
+=item reopenmenu()
+
+=item open()
+
+Open the menu
+
+=item clear()
+
+=item switch()
+
+Switch a button or create a link
+Switch acts on the javascript that is executed when a button is clicked.  
+The javascript is usually similar to "go('/adm/roles')" or "cstrgo(..)".
+
+=item secondlevel()
+
+=item openmenu()
+
+=item inlinemenu()
+
+=item rawconfig()
+
+=item close()
+
+=item footer()
+
+=item utilityfunctions()
+
+=item serverform()
+
+=item constspaceform()
+
+=item get_nav_status()
+
+=item hidden_button_check()
+
+=item roles_selector()
+
+=item jump_to_role()
+
+=back
+
+=cut
+
 package Apache::lonmenu;
 
 use strict;
@@ -45,6 +139,7 @@ use Apache::loncommon();
 use Apache::lonenc();
 use Apache::lonlocal;
 use LONCAPA qw(:DEFAULT :match);
+use HTML::Entities();
 
 use vars qw(@desklines %category_names %category_members %category_positions $readdesk);
 
@@ -53,7 +148,6 @@ my @inlineremote;
 
 
 
-# ================================================================ Little texts
 sub show_course {
     my $course = !$env{'user.adv'};
     if (!$env{'user.adv'}) {
@@ -72,20 +166,18 @@ sub initlittle {
     return &Apache::lonlocal::texthash('ret' => 'Return to Last Location',
 				       'nav' => 'Navigate Contents',
 				       'main' => 'Main Menu',
-                                       'roles' => (&show_course()?
+                                       'roles' => (&Apache::loncommon::show_course()?
                                                     'Courses':'Roles'),
                                        'other' => 'Other Roles',
                                        'docs' => 'Edit Course',
-                                       'exit' => 'Exit',
+                                       'exit' => 'Logout',
                                        'login' => 'Log In',
 				       'launch' => 'Launch Remote Control',
                                        'groups' => 'Groups',
-                                       'gdoc' => 'Group Documents',
+                                       'gdoc' => 'Community Documents',
                                        );
 }
 
-# ============================= This gets called at the top of the body section
-
 sub menubuttons {
     my $forcereg=shift;
     my $registration=shift;
@@ -150,9 +242,12 @@ ENDNAV
 <a href="/adm/flip?postdata=$escreload" target="_top">$lt{'ret'}</a>
 ENDRELOAD
             }
-	    if (&Apache::lonnet::allowed('mdc',$env{'request.course.id'})) {
-               $docs=(<<ENDDOCS);
-<a href="/adm/coursedocs" target="_top">$lt{'docs'}</a>
+            my $is_community =
+                (&Apache::loncommon::course_type() eq 'Community');
+            if (&Apache::lonnet::allowed('mdc',$env{'request.course.id'})) {
+                my $text = ($is_community) ? $lt{'gdoc'} : $lt{'docs'};
+                $docs=(<<ENDDOCS);
+<a href="/adm/coursedocs" target="_top">$text</a>
 ENDDOCS
             }
             if ($showgroups) {
@@ -217,9 +312,10 @@ ENDINLINEMENU
 	    $navmaps=(<<ENDNAV);
 <td><a href="$link" target="_top">$lt{'nav'}</a></td>
 ENDNAV
-            my $is_group = (&Apache::loncommon::course_type() eq 'Group');
+            my $is_community =
+                (&Apache::loncommon::course_type() eq 'Community');
 	    if (&Apache::lonnet::allowed('mdc',$env{'request.course.id'})) {
-                my $text = ($is_group) ? $lt{'gdoc'} : $lt{'docs'};
+                my $text = ($is_community) ? $lt{'gdoc'} : $lt{'docs'};
 		$docs=(<<ENDDOCS);
 <td><a href="/adm/coursedocs" target="_top">$text</a></td>
 ENDDOCS
@@ -255,8 +351,8 @@ ENDCRELOAD
         my $helplink=&Apache::loncommon::top_nav_help('Help');
 	return (<<ENDINLINEMENU);
 <script type="text/javascript">
-// BEGIN LON-CAPA Internal
 // <![CDATA[
+// BEGIN LON-CAPA Internal
 $utility
 // ]]>
 </script>
@@ -297,7 +393,6 @@ sub show_return_link {
 	     ));
 }
 
-# ====================================== This gets called in the header section
 
 sub registerurl {
     my ($forcereg) = @_;
@@ -314,7 +409,9 @@ sub registerurl {
 	   &unescape($env{'request.noversionuri'})))) &&
         (!$forcereg))) {
  	return $result.
-          '<script type="text/javascript">function LONCAPAreg(){;} function LONCAPAstale(){}</script>'.$force_title;
+               '<script type="text/javascript">'."\n".
+               'function LONCAPAreg(){;} function LONCAPAstale(){}'."\n".
+               '</script>'.$force_title;
     }
 # Graphical display after login only
     if ($env{'request.registered'} && !$forcereg) { return ''; }
@@ -322,9 +419,6 @@ sub registerurl {
     return $result.$force_title;
 }
 
-# =========== This gets called in order to register a URL, both with the Remote
-# =========== and in the body of the document
-
 sub innerregister {
     my ($forcereg, $titletable) = @_;
     my $result = '';
@@ -401,7 +495,7 @@ sub innerregister {
         if ($env{'request.symb'} ne '' &&
 	    $env{'request.filename'}=~/\.(problem|exam|quiz|assess|survey|form|task)$/) {
 	    if (&Apache::lonnet::allowed('mgr',$crs)) {
-		$hwkadd.=&switch('','',7,2,'pgrd.gif','problem[_1]','grades[_3]',
+		$hwkadd.=&switch('','',7,2,'pgrd.gif','problem[_1]','grades[_4]',
                        "gocmd('/adm/grades','gradingmenu')",
                        'Modify user grades for this assessment resource');
             } elsif (&Apache::lonnet::allowed('vgr',$crs)) {
@@ -422,6 +516,12 @@ sub innerregister {
         ### resource
         ###
         my $editbutton = '';
+        my $noeditbutton = 1;
+        my ($cnum,$cdom);
+        if ($env{'request.course.id'}) {
+            $cnum = $env{'course.'.$env{'request.course.id'}.'.num'};
+            $cdom = $env{'course.'.$env{'request.course.id'}.'.domain'};
+        }
         if ($env{'user.author'}) {
             if ($env{'request.role'}=~/^(aa|ca|au)/) {
                 # Set defaults for authors
@@ -449,6 +549,7 @@ sub innerregister {
 		foreach my $id (@ids) { if ($id eq $home) { $allowed=1; } }
 		if (!$allowed) {
 		    $editbutton=&switch('','',6,1,$top,,$bottom,$action,$desc);
+                    $noeditbutton = 0;
                 }
             }
             ##
@@ -457,6 +558,7 @@ sub innerregister {
             my $cfile='';
             my $cfuname='';
             my $cfudom='';
+            my $uploaded;
             if ($env{'request.filename'}) {
                 my $file=&Apache::lonnet::declutter($env{'request.filename'});
                 $file=~s/^($match_domain)\/($match_username)/\/priv\/$2/;
@@ -474,13 +576,42 @@ sub innerregister {
             }        
             # Finally, turn the button on or off
             if ($cfile && !$const_space) {
-                $editbutton=&switch
-                    ('','',6,1,'pcstr.gif','edit[_1]','resource[_2]',
+                my $nocrsedit;
+                # Suppress display where CC has switched to student role.
+                if ($env{'request.course.id'}) {
+                    unless(&Apache::lonnet::allowed('mdc',
+                                                    $env{'request.course.id'})) {
+                        $nocrsedit = 1;
+                    }
+                }
+                if ($nocrsedit) {
+                    $editbutton=&clear(6,1);
+                } else {
+                    $editbutton=&switch
+                       ('','',6,1,'pcstr.gif','edit[_1]','resource[_2]',
                      "go('".$cfile."');","Edit this resource");
+                    $noeditbutton = 0;
+                }
             } elsif ($editbutton eq '') {
                 $editbutton=&clear(6,1);
             }
         }
+        if (($noeditbutton) && ($env{'request.filename'})) {
+            if (&Apache::lonnet::allowed('mdc',$env{'request.course.id'})) {
+                my $file=&Apache::lonnet::declutter($env{'request.filename'});
+                if (defined($cnum) && defined($cdom)) {
+                    if (&is_course_upload($file,$cnum,$cdom)) {
+                        my $cfile = &edit_course_upload($file,$cnum,$cdom);
+                        if ($cfile) {
+                            $editbutton=&switch
+                                        ('','',6,1,'pcstr.gif','edit[_1]',
+                                         'resource[_2]',"go('".$cfile."');",
+                                         'Edit this resource');
+                        }
+                    }
+                }
+            }
+        }
         ###
         ###
 # Prepare the rest of the buttons
@@ -498,7 +629,7 @@ sub innerregister {
                 $menuitems=(<<ENDMENUITEMS);
 s&6&1&list.gif&list[_1]&dir[_1]&golist('$esc_currdir')&List current directory
 s&6&2&rtrv.gif&retrieve[_1]&version[_1]&gocstr('/adm/retrieve','/~$uname/$cleandisfn')&Retrieve old version
-s&6&3&pub.gif&publish[_1]&resource[_1]&gocstr('/adm/publish','/~$uname/$cleandisfn')&Publish this resource
+s&6&3&pub.gif&publish[_1]&resource[_3]&gocstr('/adm/publish','/~$uname/$cleandisfn')&Publish this resource
 s&7&1&del.gif&delete[_1]&resource[_2]&gocstr('/adm/cfile?action=delete','/~$uname/$cleandisfn')&Delete this resource
 s&7&2&prt.gif&prepare[_1]&printout[_1]&gocstr('/adm/printout','/~$uname/$cleandisfn')&Prepare a printable document
 ENDMENUITEMS
@@ -515,22 +646,30 @@ c&8&2
 s&8&3&prt.gif&prepare[_1]&printout[_1]&gopost('/adm/printout',currentURL)&Prepare a printable document
 s&9&1&sbkm.gif&set[_1]&bookmark[_2]&set_bookmark()&Set a bookmark for this resource&&1
 ENDMENUITEMS
-            my $currentURL = &Apache::loncommon::get_symb();
-            my ($symb_old,$symb_old_enc) = &Apache::loncommon::clean_symb($currentURL);
-            my $annotation = &Apache::loncommon::get_annotation($symb_old,$symb_old_enc);
-            $menuitems.="s&9&3&";
-            if (length($annotation) > 0){
-                $menuitems.="anot2.gif";
-            } else {
-                $menuitems.="anot.gif";
-            }
-            $menuitems.="&anno-[_1]&tations[_1]&annotate()&";
-            $menuitems.="Make notes and annotations about this resource&&1\n";
 
+my $currentURL = &Apache::loncommon::get_symb();
+my ($symb_old,$symb_old_enc) = &Apache::loncommon::clean_symb($currentURL);
+my $annotation = &Apache::loncommon::get_annotation($symb_old,$symb_old_enc);
+$menuitems.="s&9&3&";
+if(length($annotation) > 0){
+	$menuitems.="anot2.gif";
+}else{
+	$menuitems.="anot.gif";
+}
+$menuitems.="&anno-[_1]&tations[_1]&annotate()&";
+$menuitems.="Make notes and annotations about this resource&&1\n";
+
+            unless ($noremote) {
+                my $showreqcrs = &check_for_rcrs();
+                if ($showreqcrs) {
+                    $menuitems.="s&8&1&rcrs.gif&request[_1]&course[_16]".
+                                "&go('/adm/requestcourse')&Course requests\n";
+                }
+            }
             unless ($env{'request.noversionuri'}=~/\/(bulletinboard|smppg|navmaps|syllabus|aboutme)(\?|$)/) {
-		if (!$env{'request.enc'}) {
+                if ((!$env{'request.enc'}) && ($env{'request.noversionuri'} !~ m{^/adm/wrapper/ext/})) {
 		    $menuitems.=(<<ENDREALRES);
-s&6&3&catalog.gif&catalog[_1]&info[_1]&catalog_info()&Show catalog information
+s&6&3&catalog.gif&catalog[_2]&info[_1]&catalog_info()&Show Metadata
 ENDREALRES
                 }
 	        $menuitems.=(<<ENDREALRES);
@@ -632,6 +771,7 @@ ENDREGTEXT
 	    $result = (<<ENDREGTHIS);
      
 <script type="text/javascript">
+// <![CDATA[
 // BEGIN LON-CAPA Internal
 var swmenu=null;
 
@@ -667,6 +807,7 @@ var swmenu=null;
       }
 
 // END LON-CAPA Internal 
+// ]]>
 </script>
 ENDREGTHIS
         }
@@ -682,6 +823,7 @@ ENDDONOTREGTEXT
            $result = (<<ENDDONOTREGTHIS);
 
 <script type="text/javascript">
+// <![CDATA[
 // BEGIN LON-CAPA Internal
 var swmenu=null;
 
@@ -706,6 +848,7 @@ var swmenu=null;
     }
 
 // END LON-CAPA Internal
+// ]]>
 </script>
 ENDDONOTREGTHIS
        }
@@ -714,6 +857,42 @@ ENDDONOTREGTHIS
     return $result;
 }
 
+sub is_course_upload {
+    my ($file,$cnum,$cdom) = @_;
+    my $uploadpath = &LONCAPA::propath($cdom,$cnum);
+    $uploadpath =~ s{^\/}{};
+    if (($file =~ m{^\Q$uploadpath\E/userfiles/docs/}) ||
+        ($file =~ m{^userfiles/\Q$cdom\E/\Q$cnum\E/docs/})) {
+        return 1;
+    }
+    return;
+}
+
+sub edit_course_upload {
+    my ($file,$cnum,$cdom) = @_;
+    my $cfile;
+    if ($file =~/\.(htm|html|css|js|txt)$/) {
+        my $ext = $1;
+        my $url = &Apache::lonnet::hreflocation('',$file);
+        my $home = &Apache::lonnet::homeserver($cnum,$cdom);
+        my @ids=&Apache::lonnet::current_machine_ids();
+        my $dest;
+        if ($home && grep(/^\Q$home\E$/,@ids)) {
+            $dest = $url.'?forceedit=1';
+        } else {
+            unless (&Apache::lonnet::get_locks()) {
+                $dest = '/adm/switchserver?otherserver='.
+                        $home.'&role='.$env{'request.role'}.
+                        '&url='.$url.'&forceedit=1';
+            }
+        }
+        if ($dest) {
+            $cfile = &HTML::Entities::encode($dest,'"<>&');
+        }
+    }
+    return $cfile;
+}
+
 sub loadevents() {
     if ($env{'request.state'} eq 'construct' ||
 	$env{'request.noversionuri'} =~ m{^/res/adm/pages/}) { return ''; }
@@ -726,7 +905,6 @@ sub unloadevents() {
     return 'LONCAPAstale();';
 }
 
-# ============================================================= Start up remote
 
 sub startupremote {
     my ($lowerurl)=@_;
@@ -742,6 +920,7 @@ sub startupremote {
     my $message=&mt('"Waiting for Remote Control window to load: "+[_1]','waited');
     return(<<ENDREMOTESTARTUP);
 <script type="text/javascript">
+// <![CDATA[
 var timestart;
 function wheelswitch() {
     if (typeof(document.wheel) != 'undefined') {
@@ -791,7 +970,7 @@ function main() {
    timestart=date.getTime();
    wait();
 }
-
+// ]]>
 </script>
 ENDREMOTESTARTUP
 }
@@ -799,8 +978,10 @@ ENDREMOTESTARTUP
 sub setflags() {
     return(<<ENDSETFLAGS);
 <script type="text/javascript">
+// <![CDATA[
     menuloaded=0;
     tim=0;
+// ]]>
 </script>
 ENDSETFLAGS
 }
@@ -810,7 +991,9 @@ sub maincall() {
         ($env{'environment.remote'} eq 'off')) { return ''; }
     return(<<ENDMAINCALL);
 <script type="text/javascript">
+// <![CDATA[
     main();
+// ]]>
 </script>
 ENDMAINCALL
 }
@@ -822,8 +1005,9 @@ sub load_remote_msg {
         ($env{'environment.remote'} eq 'off')) { return ''; }
 
     my $esclowerurl=&escape($lowerurl);
-    my $link=&mt('<a href="[_1]">Continue</a> on in Inline Menu mode',
-		 "/adm/remote?action=collapse&amp;url=$esclowerurl");
+    my $link=&mt('[_1]Continue[_2] on in Inline Menu mode',
+		 '<a href="/adm/remote?action=collapse&amp;url='.$esclowerurl.'">',
+                 '</a>');
     return(<<ENDREMOTEFORM);
 <p>
 <form name="wheel">
@@ -840,7 +1024,6 @@ sub get_menu_name {
     return 'LCmenu'.$hostid;
 }
 
-# ================================================================= Reopen menu
 
 sub reopenmenu {
    if (($env{'browser.interface'} eq 'textual') ||
@@ -850,13 +1033,17 @@ sub reopenmenu {
    return('window.open('.$nothing.',"'.$menuname.'","",false);');
 } 
 
-# =============================================================== Open the menu
 
 sub open {
     my $returnval='';
     if (($env{'browser.interface'} eq 'textual') ||
         ($env{'environment.remote'} eq 'off')) { 
-	return '<script type="text/javascript">self.name="loncapaclient";</script>';
+	return 
+         '<script type="text/javascript">'."\n".
+         '// <![CDATA['."\n".
+         'self.name="loncapaclient";'."\n".
+         '// ]]>'."\n".
+         '</script>';
     }
     my $menuname = &get_menu_name();
     
@@ -869,11 +1056,13 @@ sub open {
 #}
 #ENDRESIZE
 #    }
-    $returnval.=(<<ENDOPEN);
+    $returnval=(<<ENDOPEN);
+// <![CDATA[
 window.status='Opening LON-CAPA Remote Control';
 var menu=window.open("/res/adm/pages/menu.html","$menuname",
 "height=375,width=150,scrollbars=no,menubar=no,top=5,left=5,screenX=5,screenY=5");
 self.name='loncapaclient';
+// ]]>
 ENDOPEN
     return '<script type="text/javascript">'.$returnval.'</script>';
 }
@@ -1000,11 +1189,14 @@ sub inlinemenu {
     &rawconfig(1);
     my $output='<table id="LC_mainmenu"><tr>';
     for (my $col=1; $col<=2; $col++) {
-        $output.='<td class="LC_mainmenu_column">';
+        $output.='<td class="LC_mainmenu_col_fieldset">';
         for (my $row=1; $row<=8; $row++) {
             foreach my $cat (keys(%category_members)) {
                if ($category_positions{$cat} ne "$col,$row") { next; }
-               $output.='<table id="LC_menubuttons_mainmenu"><tr><td colspan="4" class="LC_menubuttons_category">'.&mt($category_names{$cat}).'</td></tr>';
+               #$output.='<table id="LC_menubuttons_mainmenu"><tr><td colspan="4" class="LC_menubuttons_category">'.&mt($category_names{$cat}).'</td></tr>';
+               $output.='<fieldset id="LC_mainmenu_fieldset">';
+	       $output.='<legend class="LC_mainmenu_fieldset_category">'.&mt($category_names{$cat}).'</legend>';
+               $output.='<table id="LC_menubuttons_mainmenu">';
                my %active=();
                foreach my $menu_item (split(/\:/,$category_members{$cat})) {
                   if ($inlineremote[$menu_item]) {
@@ -1015,6 +1207,7 @@ sub inlinemenu {
                   $output.=$inlineremote[$item];
                }
                $output.='</table>';
+               $output.='</fieldset>';
             }
          }
          $output.="</td>";
@@ -1037,15 +1230,17 @@ sub rawconfig {
     my $uname=$env{'user.name'};
     my $udom=$env{'user.domain'};
     my $adv=$env{'user.adv'};
-    my $show_course=&show_course();
+    my $show_course=&Apache::loncommon::show_course();
     my $author=$env{'user.author'};
     my $crs='';
+    my $crstype='';
     if ($env{'request.course.id'}) {
        $crs='/'.$env{'request.course.id'};
        if ($env{'request.course.sec'}) {
 	   $crs.='_'.$env{'request.course.sec'};
        }
        $crs=~s/\_/\//g;
+       $crstype = &Apache::loncommon::course_type();
     }
     my $pub=($env{'request.state'} eq 'published');
     my $con=($env{'request.state'} eq 'construct');
@@ -1055,13 +1250,18 @@ sub rawconfig {
         my ($row,$col,$pro,$prt,$img,$top,$bot,$act,$desc,$cat)=split(/\:/,$line);
         $prt=~s/\$uname/$uname/g;
         $prt=~s/\$udom/$udom/g;
-        $prt=~s/\$crs/$crs/g; 
+        $prt=~s/\$crs/$crs/g;
+        if ($prt =~ /\$crs/) {
+            next unless ($env{'request.course.id'});
+            next if ($crstype eq 'Community');
+            $prt=~s/\$crs/$crs/g;
+        } elsif ($prt =~ /\$cmty/) {
+            next unless ($env{'request.course.id'});
+            next if ($crstype ne 'Community');
+            $prt=~s/\$cmty/$crs/g;
+        }
         $prt=~s/\$requested_domain/$requested_domain/g;
         if ($category_names{$cat}!~/\w/) { $cat='oth'; }
-        my $type = &Apache::loncommon::course_type();
-        if ($type eq 'Group') {
-            $desc = &convert_menu_function($desc,$type);
-        }
         if ($pro eq 'clear') {
 	    $output.=&clear($row,$col);
         } elsif ($pro eq 'any') {
@@ -1088,26 +1288,69 @@ sub rawconfig {
 	  $uname,$udom,$rol,$crs,$pub,$con,$row,$col,$prt,$img,$top,$bot,$act,$desc,$cat);
             }
         } elsif (($pro=~/^p(\w+)/) && ($prt)) {
-	    if (&Apache::lonnet::allowed($1,$prt)) {
+            my $priv = $1;
+            if ($priv =~ /^mdc(Course|Community)/) {
+                if ($crstype eq $1) {
+                    $priv = 'mdc';
+                } else {
+                    next;
+                }
+            }
+	    if (&Apache::lonnet::allowed($priv,$prt)) {
                $output.=&switch($uname,$udom,$row,$col,$img,$top,$bot,$act,$desc,$cat);
             }
-        } elsif ($pro eq 'course') {
-            if ($env{'request.course.fn'}) {
+        } elsif ($pro eq 'course')  {
+            if (($env{'request.course.fn'}) && ($crstype ne 'Community')) {
                $output.=&switch($uname,$udom,$row,$col,$img,$top,$bot,$act,$desc,$cat);
-	    }
+            }
+        } elsif ($pro eq 'community')  {
+            if (($env{'request.course.fn'}) && ($crstype eq 'Community')) {
+               $output.=&switch($uname,$udom,$row,$col,$img,$top,$bot,$act,$desc,$cat);
+            }
         } elsif ($pro =~ /^courseenv_(.*)$/) {
             my $key = $1;
-            if ($env{'course.'.$env{'request.course.id'}.'.'.$key}) {
-                $output.=&switch($uname,$udom,$row,$col,$img,$top,$bot,$act,$desc,$cat);
+            if ($crstype ne 'Community') {
+                my $coursepref = $env{'course.'.$env{'request.course.id'}.'.'.$key};
+                if ($key eq 'canuse_pdfforms') {
+                    if ($env{'request.course.id'} && $coursepref eq '') {
+                        my %domdefs = &Apache::lonnet::get_domain_defaults($env{'course.'.$env{'request.course.id'}.'.domain'});
+                        $coursepref = $domdefs{'canuse_pdfforms'};
+                    }
+                }
+                if ($coursepref) {
+                    $output.=&switch($uname,$udom,$row,$col,$img,$top,$bot,$act,$desc,$cat);
+                }
+            }
+        } elsif ($pro =~ /^communityenv_(.*)$/) {
+            my $key = $1;
+            if ($crstype eq 'Community') {
+                my $coursepref = $env{'course.'.$env{'request.course.id'}.'.'.$key};
+                if ($key eq 'canuse_pdfforms') {
+                    if ($env{'request.course.id'} && $coursepref eq '') {
+                        my %domdefs = &Apache::lonnet::get_domain_defaults($env{'course.'.$env{'request.course.id'}.'.domain'});
+                        $coursepref = $domdefs{'canuse_pdfforms'};
+                    }
+                }
+                if ($coursepref) {
+                    $output.=&switch($uname,$udom,$row,$col,$img,$top,$bot,$act,$desc,$cat);
+                }
             }
         } elsif ($pro =~ /^course_(.*)$/) {
             # Check for permissions inside of a course
-            if (($env{'request.course.id'}) &&
+            if (($env{'request.course.id'}) && ($crstype ne 'Community') &&
                 (&Apache::lonnet::allowed($1,$env{'request.course.id'}.
             ($env{'request.course.sec'}?'/'.$env{'request.course.sec'}:''))
                  )) {
                 $output.=&switch($uname,$udom,$row,$col,$img,$top,$bot,$act,$desc,$cat);
-	    }
+            }
+        } elsif ($pro =~ /^community_(.*)$/) {
+            # Check for permissions inside of a community
+            if (($env{'request.course.id'}) && ($crstype eq 'Community') &&
+                (&Apache::lonnet::allowed($1,$env{'request.course.id'}.
+            ($env{'request.course.sec'}?'/'.$env{'request.course.sec'}:''))
+                 )) {
+                $output.=&switch($uname,$udom,$row,$col,$img,$top,$bot,$act,$desc,$cat);
+            }
         } elsif ($pro eq 'author') {
             if ($author) {
                 if ((($prt eq 'rca') && ($env{'request.role'}=~/^ca/)) ||
@@ -1135,7 +1378,20 @@ sub rawconfig {
             my @tools = ('aboutme','blog','portfolio');
             if (grep(/^\Q$prt\E$/,@tools)) {
                 if (!&Apache::lonnet::usertools_access($env{'user.name'},
-                                                       $env{'user.domain'},$prt)) {
+                                                       $env{'user.domain'},
+                                                       $prt,undef,'tools')) {
+                    $output.=&clear($row,$col);
+                    next;
+                }
+            } elsif (($prt eq 'reqcrsnsc') || ($prt eq 'reqcrsshc')) {
+                if (($prt eq 'reqcrsnsc') && ($show_course))   {
+                    next;
+                }
+                if (($prt eq 'reqcrsshc') && (!$show_course)) {
+                    next;
+                }
+                my $showreqcrs = &check_for_rcrs();
+                if (!$showreqcrs) {
                     $output.=&clear($row,$col);
                     next;
                 }
@@ -1143,6 +1399,7 @@ sub rawconfig {
             $prt='any';
             $output.=&secondlevel(
           $uname,$udom,$rol,$crs,$pub,$con,$row,$col,$prt,$img,$top,$bot,$act,$desc,$cat);
+
         }
     }
     unless (($env{'browser.interface'} eq 'textual') ||
@@ -1156,6 +1413,28 @@ sub rawconfig {
     return $output;
 }
 
+sub check_for_rcrs {
+    my $showreqcrs = 0;
+    my @reqtypes = ('official','unofficial','community');
+    foreach my $type (@reqtypes) {
+        if (&Apache::lonnet::usertools_access($env{'user.name'},
+                                              $env{'user.domain'},
+                                              $type,undef,'requestcourses')) {
+            $showreqcrs = 1;
+            last;
+        }
+    }
+    if (!$showreqcrs) {
+        foreach my $type (@reqtypes) {
+            if ($env{'environment.reqcrsotherdom.'.$type} ne '') {
+                $showreqcrs = 1;
+                last;
+            }
+        }
+    }
+    return $showreqcrs;
+}
+
 # ======================================================================= Close
 
 sub close {
@@ -1164,6 +1443,7 @@ sub close {
     my $menuname = &get_menu_name();
     return(<<ENDCLOSE);
 <script type="text/javascript">
+// <![CDATA[
 window.status='Accessing Remote Control';
 menu=window.open("/adm/rat/empty.html","$menuname",
                  "height=350,width=150,scrollbars=no,menubar=no");
@@ -1173,6 +1453,7 @@ menu.autologout=0;
 window.status='Closing Remote Control';
 menu.close();
 window.status='Done.';
+// ]]>
 </script>
 ENDCLOSE
 }
@@ -1205,6 +1486,11 @@ sub utilityfunctions {
     unless (($env{'browser.interface'} eq 'textual')  ||
         ($env{'environment.remote'} eq 'off') || ($caller eq '/adm/menu')) { return ''; }
     my $currenturl=&Apache::lonnet::clutter(&Apache::lonnet::fixversion((split(/\?/,$env{'request.noversionuri'}))[0]));
+    if ($currenturl =~ m{^/adm/wrapper/ext/}) {
+        if ($env{'request.external.querystring'}) {
+            $currenturl .= ($currenturl=~/\?/)?'&':'?'.$env{'request.external.querystring'};
+        }
+    }
     $currenturl=&Apache::lonenc::check_encrypt(&unescape($currenturl));
     
     my $currentsymb=&Apache::lonenc::check_encrypt($env{'request.symb'});
@@ -1359,16 +1645,16 @@ function set_bookmark() {
    bmquery=window.open('','bmquery','width=365,height=165,scrollbars=0');
    bmquery.document.write(
    '$start_page_bookmark'
-   +"<center><form method='post'"
-   +" name='newlink' action='/adm/bookmarks' target='bmquery' "
-   +">\\n <table width=340 height=150 "
-   +"bgcolor='ffffff' align=center><tr><td>Link Name:<br /><input "
-   +"type='text' name='title' size=45 value='"+clienttitle+"' />"
-   +"<br />Address:<br /><input type='text' name='address' size='45' "
-   +"value='"+clienthref+"' /><br /><center><input type='submit' "
-   +"value='Save' /> <input type='button' value='Close (no save)' "
-   +"onclick='javascript:window.close();' /><\\/center><\\/td>"
-   +"<\\/tr><\\/table><\\/form><\\/center>"
+   +'<center><form method="post"'
+   +' name="newlink" action="/adm/bookmarks" target="bmquery" '
+   +'> <table width="340" height="150" '
+   +'bgcolor="ffffff" align="center"><tr><td>Link Name:<br /><input '
+   +'type="text" name="title" size="45" value="'+clienttitle+'" />'
+   +'<br />Address:<br /><input type="text" name="address" size="45" '
+   +'value="'+clienthref+'" /><br /><center><input type="submit" '
+   +'value="Save" /> <input type="button" value="Close" '
+   +'onclick="javascript:window.close();" /></center></td>'
+   +'</tr></table></form></center>'
    +'$end_page_bookmark' );
    bmquery.document.close();
 }
@@ -1416,19 +1702,6 @@ sub get_nav_status {
     return $navstatus;
 }
 
-#FIXME this needs to move into mydesktab and the other locations 
-# the text is generated
-sub convert_menu_function {
-    my ($rolename,$type) = @_;
-    if ($type eq 'Group') {
-        $rolename =~ s/student/member/g;
-        $rolename =~ s/group/team/g;
-        $rolename =~ s/course/group/g;
-        $rolename =~ s/Course/Group/g;
-    }
-    return $rolename;
-}
-
 sub hidden_button_check {
     my $hidden;
     if ($env{'request.course.id'} eq '') {
@@ -1443,13 +1716,19 @@ sub hidden_button_check {
 
 sub roles_selector {
     my ($cdom,$cnum) = @_;
+    my $crstype = &Apache::loncommon::course_type();
     my $now = time;
     my (%courseroles,%seccount);
     my $is_cc;
     my $role_selector;
-    if ($env{'user.role.cc./'.$cdom.'/'.$cnum}) {
-        my ($start,$end) = split(/\./,$env{'user.role.cc./'.$cdom.'/'.$cnum});
-        
+    my $ccrole;
+    if ($crstype eq 'Community') {
+        $ccrole = 'co';
+    } else {
+        $ccrole = 'cc';
+    }
+    if ($env{'user.role.'.$ccrole.'./'.$cdom.'/'.$cnum}) {
+        my ($start,$end) = split(/\./,$env{'user.role.'.$ccrole.'./'.$cdom.'/'.$cnum});
         if ((($start) && ($start<0)) || 
             (($end) && ($end<$now))  ||
             (($start) && ($now<$start))) {
@@ -1492,15 +1771,22 @@ sub roles_selector {
             }
         }
     }
-    my @roles_order = ('cc','in','ta','ep','ad','st');
+    my $switchtext;
+    if ($crstype eq 'Community') {
+        $switchtext = &mt('Switch community role to...')
+    } else {
+        $switchtext = &mt('Switch course role to...')
+    }
+
+    my @roles_order = ($ccrole,'in','ta','ep','ad','st');
     if (keys(%courseroles) > 1) {
         $role_selector = &jump_to_role($cdom,$cnum,\%seccount,\%courseroles);
         $role_selector .= '<form name="rolechooser" method="post" action="/adm/roles">
                           <select name="switchrole" onchange="javascript:adhocRole('."'switchrole'".')">';
-        $role_selector .= '<option value="">'.&mt('Switch course role to...').'</option>';
+        $role_selector .= '<option value="">'.$switchtext.'</option>';
         foreach my $role (@roles_order) {
             if (defined($courseroles{$role})) {
-                $role_selector .= "\n".'<option value="'.$role.'">'.&Apache::lonnet::plaintext($role).'</option>'; 
+                $role_selector .= "\n".'<option value="'.$role.'">'.&Apache::lonnet::plaintext($role,$crstype).'</option>'; 
             }
         }
         foreach my $role (sort(keys(%courseroles))) {
@@ -1510,7 +1796,7 @@ sub roles_selector {
         }
         $role_selector .= '</select>'."\n".
                '<input type="hidden" name="destinationurl" value="'.
-               $ENV{'REQUEST_URI'}.'" />'."\n".
+               &HTML::Entities::encode($ENV{'REQUEST_URI'},'"<>&').'" />'."\n".
                '<input type="hidden" name="gotorole" value="1" />'."\n".
                '<input type="hidden" name="selectrole" value="" />'."\n".
                '<input type="hidden" name="switch" value="1" />'."\n".
@@ -1605,8 +1891,9 @@ sub jump_to_role {
                    '    numsec['.$i.'] = "'.$seccount->{$items[$i]}.'";'."\n";
         }
     }
-    my $output = <<"END";
+    return <<"END";
 <script type="text/javascript">
+//<![CDATA[
 function adhocRole(roleitem) {
     $js
     var newrole =  document.rolechooser.elements[roleitem].options[document.rolechooser.elements[roleitem].selectedIndex].value;
@@ -1677,11 +1964,9 @@ function retrieveIndex(item) {
     }
     return -1;
 }
-
-
+// ]]>
 </script>
 END
-    return $output;
 }
 
 
