@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Simple Page Editor
 #
-# $Id: lonsimplepage.pm,v 1.57 2008/10/20 16:29:59 bisitz Exp $
+# $Id: lonsimplepage.pm,v 1.59.2.2 2010/02/13 00:51:06 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -138,7 +138,7 @@ sub handler {
 # --------------------------------------- There is such a user, get environment
 
     if ($target ne 'tex') {
-        my $title = 'Course Page';
+        my $title = 'Simple Course Page';
         if ($group ne '') {
             $title = 'Group Page';
         }
@@ -295,7 +295,9 @@ sub handler {
 	    if (($syllabus{$field}) || ($allowed) || 
                 ($field eq 'abb_links' && $group ne '')) {
 		my $message=$syllabus{$field};
-		&Apache::lonfeedback::newline_to_br(\$message);
+                if (!&Apache::lonfeedback::contains_block_html($message)) {
+                    &Apache::lonfeedback::newline_to_br(\$message);
+                }
 		$message
 		    =~s/(https*\:\/\/[^\s]+)/\<a href=\"$1\"\>\<tt\>$1\<\/tt\>\<\/a\>/g;
 		if ($allowed) {
@@ -382,7 +384,7 @@ sub display_group_links {
     my @available = ();
     my %menu = ();
     %{$menu{'email'}} = (
-                        text => 'Group e-mail',
+                        text => 'Group Message',
                         href => '/adm/email?compose=group&amp;group='.$group.
                                 $refarg,
                       );
@@ -391,16 +393,16 @@ sub display_group_links {
                         href => '/adm/groupboards?group='.$group.$refarg,
                       );
     %{$menu{'chat'}} = (
-                        text => 'Group chat',
+                        text => 'Group Chat Room',
                         href => "javascript:group_chat('$group')",
                       );
     %{$menu{'files'}} = (
-                        text => 'File repository',
+                        text => 'Group Portfolio',
                         href => '/adm/coursegrp_portfolio?group='.$group.
                                 $refarg,
                       );
     %{$menu{'roster'}} = (
-                        text => 'Membership roster',
+                        text => 'Membership Roster',
                         href => '/adm/grouproster?group='.$group.$refarg,
                       );
     foreach my $tool (sort(keys(%menu))) {
@@ -409,16 +411,27 @@ sub display_group_links {
         }
     }
     if (@available > 0) {
-        my $output = '<table cellspacing="4" cellpadding="4"><tr>';
+        my $output = '';
+        if ($target eq 'tex') {
+            $output = '<table cellspacing="4" cellpadding="4">';
+        } else {
+            $output = &Apache::loncommon::start_data_table();
+        }
         foreach my $tool (@available) {
             if ($target eq 'tex') {
-                $output .= '<td>'.&mt($menu{$tool}{text}).'</td>';
+                $output .= '<tr><td>'.&mt($menu{$tool}{text}).'</td></tr>';
             } else {
-                $output .= '<td><a href="'.$menu{$tool}{href}.'">'.
-                           &mt($menu{$tool}{text}).'</a></td>';
+                $output .= &Apache::loncommon::start_data_table_row()
+                          .'<td><a href="'.$menu{$tool}{href}.'">'
+                          .&mt($menu{$tool}{text}).'</a></td>'
+                          .&Apache::loncommon::end_data_table_row();
             }
         }
-        $output .= '</tr></table>';
+        if ($target eq 'tex') {
+            $output .= '</table>';
+        } else {
+            $output .= &Apache::loncommon::end_data_table();
+        }
         if ($target eq 'tex') {
             $r->print(&Apache::lonxml::xmlparse($r,'tex',&mt('Available functions').'<br /><br />'.$output));
         } else {
@@ -429,7 +442,7 @@ sub display_group_links {
         if ($context eq 'edit') {
             $output = &mt('No group functionality.');
         } else {  
-            $output = &mt('No group functionality (e.g., e-mail, discussion, chat or file upload) is currently available to you in this group: [_1].','<b>'.&unescape($groupinfo{'description'}).'</b>');
+            $output = &mt('No group functionality (e.g., e-mail, discussion, chat room or file upload) is currently available to you in this group: [_1].','<b>'.&unescape($groupinfo{'description'}).'</b>');
         }
         if ($target eq 'tex') {
             $r->print(&Apache::lonxml::xmlparse($r,'tex',$output));
@@ -447,11 +460,12 @@ sub grouppage_breadcrumbs {
           text=>"Groups",
           title=>"Display Groups"},
         {href=>"/adm/$cdom/$cnum/$group/smppg?ref=grouplist",
-          text=>"Group: $description",
-          title=>"Go to group's home page"},
+          text=>&mt('Group:')." $description",
+          title=>&mt("Go to group's home page"),
+          no_mt=>1,},
         );
     my $output .= &Apache::lonhtmlcommon::breadcrumbs(&mt('Group page - [_1]',
-                                                           $description));
+                      $description),undef,undef,undef,undef,1);
     return $output;
 }
 
