@@ -1,5 +1,5 @@
 #
-# $Id: lonsupportreq.pm,v 1.50 2008/10/01 17:47:06 raeburn Exp $
+# $Id: lonsupportreq.pm,v 1.55.4.3 2010/04/14 07:31:21 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -77,8 +77,11 @@ sub print_request_form {
     $browser = $env{'browser.type'};
     $bversion = $env{'browser.version'};
     $uhost = $env{'request.host'};
-    $uname = $env{'user.name'};
-    $udom = $env{'user.domain'};
+    my ($uname,$udom);
+    if (($env{'user.name'} ne 'public') && ($env{'user.domain'} ne 'public')) {
+        $uname = $env{'user.name'};
+        $udom = $env{'user.domain'};
+    }
     $uhome = $env{'user.home'};
     $urole = $env{'request.role'};
     $usec = $env{'request.course.sec'};
@@ -266,7 +269,7 @@ function initialize_codes() {
                &Apache::lonhtmlcommon::row_closure();
     $num ++;
     $i = $num%2;
-    if (defined($env{'user.name'})) {
+    if (defined($uname)) {
         $output .= &Apache::lonhtmlcommon::row_title($lt{'emac'},undef,$css[$i]).
                    '<input type="text" size="50" name="cc" value="" /><br />'."\n".
                    &Apache::lonhtmlcommon::row_closure();
@@ -428,7 +431,7 @@ function initialize_codes() {
                &Apache::lonhtmlcommon::row_closure();
     $num ++;
     $i = $num%2; 
-    if (defined($env{'user.name'})) {
+    if (defined($uname)) {
         $output .= &Apache::lonhtmlcommon::row_title($lt{'opfi'},undef,$css[$i]).
                    ' <input type="file" name="screenshot" size="20" /><br />'.$lt{'uplf'}."\n".
         &Apache::lonhtmlcommon::row_closure();
@@ -474,6 +477,32 @@ sub print_request_receipt {
     my $to = &Apache::loncommon::build_recipient_list(undef,'helpdeskmail',
                                                       $defdom,$origmail);
     my $from = $admin;
+    my $bcc;
+    my %domconfig =
+         &Apache::lonnet::get_dom('configuration',['contacts'],$defdom);
+    if (ref($domconfig{'contacts'}) eq 'HASH') {
+        if (exists($domconfig{'contacts'}{'helpdeskmail'})) {
+            if (ref($domconfig{'contacts'}{'helpdeskmail'}) eq 'HASH') {
+                my $bccmail = $domconfig{'contacts'}{'helpdeskmail'}{'bcc'};
+                if ($bccmail ne '') {
+                    my @bccs = split(/,/,$bccmail);
+                    my @ok_bccs;
+                    foreach my $bcc (@bccs) {
+                        $bcc =~ s/^\s+//g;
+                        $bcc =~ s/\s+$//g;
+                        if ($bcc =~ m/^[^\@]+\@[^\@]+$/) {
+                            if (!(grep(/^\Q$bcc\E$/,@ok_bccs))) {
+                                push(@ok_bccs,$bcc);
+                            }
+                        }
+                    }
+                    if (@ok_bccs > 0) {
+                        $bcc = join(', ',@ok_bccs);
+                    }
+                }
+            }
+        }
+    }
     my $reporttime = &Apache::lonlocal::locallocaltime(time);
     my @formvars = ('username','email','uname','udom','sourceurl','phone','section','coursecode','title','subject','description','screenshot');
 
@@ -495,7 +524,7 @@ sub print_request_receipt {
     }
     my %lt = &Apache::lonlocal::texthash (
                  username    => 'Name',
-                 email       => 'Email',
+                 email       => 'E-mail',
                  cc          => 'Cc',
                  user        => 'Username/domain',
                  phone       => 'Phone',
@@ -566,13 +595,15 @@ END
         if ($env{'form.'.$item} ne '') {
             if ($item eq 'description') {
                 my $descrip = $env{'form.description'};
-                $descrip =~ s|\n|<br />|g;
+                $descrip =  &cleanup_html($descrip);
+                $descrip =~ s|[\n\r\f]|<br />|g;
                 $displaymsg .= 
                     '<span class="LC_helpform_receipt_cat">'.
                     "$lt{$item}</span>: $descrip<br />\n";
             } elsif ($item eq 'sourceurl') {
                 my $showurl = $env{'form.sourceurl'};
                 $showurl =~ s/\?.*$//;
+                $showurl =  &cleanup_html($showurl);
                 $displaymsg .= 
                     '<span class="LC_helpform_receipt_cat">'.
                     "$lt{$item}</span>: $showurl<br />\n";
@@ -581,9 +612,11 @@ END
                     '<span class="LC_helpform_receipt_cat">'.
                     "$lt{$item}</span>: $okcclist<br />\n";
             } else {
+                my $showitem = $env{'form.'.$item};
+                $showitem = &cleanup_html($showitem);
                 $displaymsg .= 
                     '<span class="LC_helpform_receipt_cat">'.
-                    "$lt{$item}</span>: $env{'form.'.$item}<br />\n";
+                    "$lt{$item}</span>: $showitem<br />\n";
             }
         }
     }
@@ -665,7 +698,8 @@ END
 
     my $attachmentpath = '';
     my $attachmentsize = '';
-    if (defined($env{'user.name'})) {
+    if ((defined($env{'user.name'})) && ($env{'user.name'} ne 'public')
+        && ($env{'user.domain'} ne 'public')) {
         if ($env{'form.screenshot.filename'}) {
             $attachmentsize = length($env{'form.screenshot'});
             if ($attachmentsize > 131072) {
@@ -684,7 +718,12 @@ END
 
     if ($attachmentpath =~ m-/([^/]+)$-) {
         $fname = $1;
-        $displaymsg .= '<br />'.&mt('An uploaded screenshot file \'[_1]\' ([_2] bytes) was included in the request sent by [_3].',$fname,$attachmentsize,$env{'user.name'}.': '.$env{'user.domain'});
+        $displaymsg .= '<br />'
+                      .&mt('An uploaded screenshot file [_1] ([_2] bytes) was included in the request sent by [_3].'
+                          ,'<span class="LC_filename">'.$fname.'<span>'
+                          ,$attachmentsize
+                          ,$env{'user.name'}.':'.$env{'user.domain'}
+                       );
         $supportmsg .= "\n";
         foreach my $var (@cookievars) {
             $supportmsg .= "$var: $cookies{$var}\n";
@@ -708,6 +747,9 @@ END
         my $cc_string = join(', ',@ok_ccs);
         $msg->add("Cc" => $cc_string);
     }
+    if ($bcc ne '') {
+        $msg->add("Bcc" => $bcc);
+    }
 
     if ($attachmentpath) {
         my ($type, $encoding) = MIME::Types::by_suffix($attachmentpath);
@@ -741,7 +783,8 @@ END
         unlink($attachmentpath);
     }
     $r->print('<b>'.$lt{'your'}.'</b>:<br /><br />'."\n");
-    $r->print(&Apache::lonhtmlcommon::start_pick_box('LC_helpform_receipt').
+    $r->print('<div style="width:620px;">'.
+              &Apache::lonhtmlcommon::start_pick_box().
               &Apache::lonhtmlcommon::row_title($lt{'info'},undef,'LC_oddrow_value')."\n".$displaymsg."\n".
               &Apache::lonhtmlcommon::row_closure().
               &Apache::lonhtmlcommon::row_title($lt{'adin'},undef,'LC_evenrow_value'));
@@ -767,7 +810,8 @@ END
     $envmsg =~ s/, $//;
     $r->print($envmsg."\n".
               &Apache::lonhtmlcommon::row_closure(1)."\n".
-              &Apache::lonhtmlcommon::end_pick_box()."\n".
+              &Apache::lonhtmlcommon::end_pick_box().
+              "</div>\n".
               &Apache::loncommon::end_page());
 }
 
@@ -796,7 +840,11 @@ sub print_header {
     $r->print(<<END);
 <table width="620" border="0" cellspacing="0" cellpadding="0" height="55">   <tr height="50">    <td width='5'>&nbsp;</td>
    <td>
-    <fieldset><legend><img src="$location/lonIcons/minilogo.gif" height='20' width='29' valign='bottom' />&nbsp;&nbsp;<b><font size="+1">LON-CAPA $lt{'headline'}</font></b></legend>
+    <fieldset>
+      <legend>
+        <img src="$location/lonIcons/minilogo.gif" height="20" width="29" valign="bottom" />&nbsp;&nbsp;
+       <b>LON-CAPA $lt{'headline'}</b>
+      </legend>
  <table id="LC_helpmenu_links">
    <tr>
     <td align="center"><span class="LC_nobreak"><img src="$location/help/help.png" border="0" alt="($lt{'login'})" valign="middle" />&nbsp;<b><a href="/adm/loginproblems.html">$lt{'login'}</a></b>&nbsp;</span></td>
@@ -837,9 +885,27 @@ sub get_domain {
     } elsif ($env{'request.role.domain'}) {
         $codedom = $env{'request.role.domain'};
     } else {
-        $codedom = $Apache::lonnet::perlvar{'lonDefDomain'};
+        $codedom = &Apache::lonnet::default_login_domain();
     }
     return $codedom;
 }
 
+sub cleanup_html {
+    my ($incoming) = @_;
+    my $outgoing;
+    if ($incoming ne '') {
+        $outgoing = $incoming;
+        $outgoing =~ s/\#/&#035;/g;
+        $outgoing =~ s/\&/&#038;/g;
+        $outgoing =~ s/</&#060;/g;
+        $outgoing =~ s/>/&#062;/g;
+        $outgoing =~ s/\(/&#040/g;
+        $outgoing =~ s/\)/&#041;/g;
+        $outgoing =~ s/"/&#034;/g;
+        $outgoing =~ s/'/&#039;/g;
+        $outgoing =~ s/\$/&#036;/g;
+    }
+    return $outgoing;
+}
+
 1;
