@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lontrackstudent.pm,v 1.26 2009/01/02 23:07:55 raeburn Exp $
+# $Id: lontrackstudent.pm,v 1.30 2009/08/28 22:47:07 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -119,13 +119,16 @@ sub get_data {
 	$text = 'View more activity by this student';
 	$inc  = $num_records;
 	$r->print(&Apache::loncommon::track_student_link($text,$sname,$sdom,undef,
-							 ($env{'form.start'}+$inc)
+							 ($env{'form.start'}+$inc),
+                                                         $env{'form.only_body'}
 							 ));
 	$r->print('<br />');
     }
+    $r->print('<hr />');
     $text = 'Resubmit last request to check for newer data';
     $r->print(&Apache::loncommon::track_student_link($text,$sname,$sdom,undef,
-						     $env{'form.start'}));
+						     $env{'form.start'},
+                                                     $env{'form.only_body'}));
 
     &Apache::lonhtmlcommon::Update_PrgWin($r,$prog_state,&mt('Finished!'));
     return;
@@ -553,7 +556,7 @@ sub handler {
     #
     # Extract form elements from query string
     &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},
-                                            ['selected_student','start']);
+                      ['selected_student','start','only_body']);
     #
     # We will almost always need this...
     my $navmap = Apache::lonnavmaps::navmap->new();
@@ -571,7 +574,11 @@ sub handler {
                                             bug=>'instructor interface'});
     #
     # Give the LON-CAPA page header
-    $r->print(&Apache::loncommon::start_page('Student Activity',&styles()).
+    my $args;
+    if ($env{'form.only_body'}) {
+        $args = { only_body => 1, };
+    }
+    $r->print(&Apache::loncommon::start_page('Student Activity',&styles(),$args).
               &Apache::lonhtmlcommon::breadcrumbs('Student Activity'));
     $r->rflush();
     #
@@ -579,8 +586,8 @@ sub handler {
     $r->print('<form name="trackstudent" method="post" action="/adm/trackstudent">');
     $r->print('<br />');
     $r->print('<div name="statusline">'.
-              &mt('Status:[_1]',
-                  '<input type="text" name="status" size="60" value="" />').
+              &mt('Status: [_1]',
+                  '<input type="text" name="status" size="60" value="" readonly="readonly" />').
               '</div>');
     $r->rflush();
     my %prog_state=&Apache::lonhtmlcommon::Create_PrgWin
@@ -599,12 +606,13 @@ sub handler {
         if ($sname =~ /^$LONCAPA::username_re$/ 
 	    && $sdom =~ /^$LONCAPA::domain_re$/) {
             $r->print('<h2>'.
-                      &mt('Recent activity of [_1]:[_2]',$sname,$sdom).
+                      &mt('Recent activity of [_1]',$sname.':'.$sdom).
                       '</h2>');
-            $r->print('<p>'.&mt(<<END).'</p>');
-Compiling student activity data can take a long time.
-Your request continues to be processed while results are displayed.
-END
+            $r->print('<p class="LC_info">'
+                     .&mt('Compiling student activity data can take a long time.'
+                         .' Your request continues to be processed while results are displayed.')
+                     .'</p>'
+            );
             &get_data($r,\%prog_state,$navmap,
                       'student:'.$env{'form.selected_student'});
         } else {
