@@ -1,5 +1,5 @@
 #
-# $Id: lonwhatsnew.pm,v 1.80.2.3 2008/12/21 16:41:15 raeburn Exp $
+# $Id: lonwhatsnew.pm,v 1.99.2.2 2010/01/28 22:37:18 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -42,6 +42,7 @@ use Time::Local;
 use GDBM_File;
 use lib '/home/httpd/lib/perl/';
 use LONCAPA;
+use HTML::Entities;
 
 #----------------------------
 # handler
@@ -99,7 +100,7 @@ sub handler {
     &Apache::lonhtmlcommon::clear_breadcrumbs();
     &Apache::lonhtmlcommon::add_breadcrumb
             ({href=>'/adm/whatsnew',
-              text=>"Display Action Items"});
+              text=>"What's New?"});
     if (($command eq 'chgthreshold') && $checkallowed{'abovethreshold'}) {
         &Apache::lonhtmlcommon::add_breadcrumb
             ({href=>'/adm/whatsnew?command=chgthreshold&amp;refpage='.$refpage,
@@ -194,7 +195,7 @@ sub display_main_box {
     );
     my %initpage = &Apache::lonlocal::texthash (
                      firstres => "first resource in the $lctype",
-                     whatsnew => "what's new? page",
+                     whatsnew => "What's New Page",
                      userpref => 'your general user preferences',
                      coursespecific => "specific setting for this $lctype",
                    );
@@ -267,7 +268,7 @@ END
 ';
     }
     my $course_type=&Apache::loncommon::course_type();
-    return &Apache::loncommon::start_page($course_type.' Action Items',
+    return &Apache::loncommon::start_page("What's New?",
 					  $scripttag);
 }
 
@@ -288,7 +289,7 @@ sub display_actions_box {
     my $lctype = lc($crstype);
     my %stulabel = (
                     'Course' => 'students',
-                    'Group' => 'members',
+                    'Community' => 'members',
                    );
     my %lt = &Apache::lonlocal::texthash(
                  'yacc' => 'You are accessing an invalid course',
@@ -327,7 +328,7 @@ sub display_actions_box {
     my %threshold = ();
     my %pagedesc = &Apache::lonlocal::texthash (
                      firstres => 'First resource',
-                     whatsnew => "What's New? page",
+                     whatsnew => "What's New Page",
                      userpref => 'user preference',
                      coursespecific => $lctype.' only',
                      default => 'default',
@@ -341,10 +342,11 @@ sub display_actions_box {
         return;
     }
 
+    my $header = '';
     if ($refpage eq 'start') {
         if (tie(my %bighash,'GDBM_File',$env{'request.course.fn'}.'.db',
             &GDBM_READER(),0640)) {
-            my $furl=$bighash{'first_url'};
+            my $furl=&HTML::Entities::encode($bighash{'first_url'},'"<>&');
             untie(%bighash);
             $r->print('<span style="font-size: larger;"><a href="'.$furl.'">'.$lt{'gtfr'}.
                   '</a></span><br />');
@@ -354,13 +356,17 @@ sub display_actions_box {
               .' <span class="LC_nobreak">'
               .&mt('Currently: [_1].','<i>'.$currinit.'</i>')
               .'&nbsp;&nbsp;'
-              .&mt('<b>Change</b> for just [_1]this course[_2]'
-                  .' or for all [_3]your courses[_2].'
+              .&mt('[_1]Change[_2] for just [_3]this '.$lctype.'[_4] or for [_5]all your courses/communities[_6].'
+                  ,'<b>'
+                  ,'</b>'
                   ,'<a href="/adm/whatsnew?command=courseinit&amp;refpage='.$refpage.'">'
                   ,'</a>'
-                  ,'<a href="/adm/preferences?action=changecourseinit&amp;refpage='.$refpage.'">')
+                  ,'<a href="/adm/preferences?action=changecourseinit&amp;refpage='.$refpage.'">'
+                  ,'</a>')
               .' </span><br /><hr />');
 
+    $r->print($header);
+
     if ($command eq 'reset') {
         $result = &process_reset($cdom,$crs);
     } elsif ($command eq 'update') {
@@ -376,12 +382,14 @@ sub display_actions_box {
     unless ($store_result eq 'ok') { 
         &Apache::lonnet::logthis('Error saving whatsnew settings: '.
             $store_result.' for '.'user '.$uname.':'.$udom.' in '.$lctype.' '.$cid);
-        $result .= &mt('Unable to save visibility settings due to [_1]',
-                       $store_result); 
+        $result .= '<span class="LC_error">'
+                  .&mt('Unable to save visibility settings due to [_1]',
+                       $store_result)
+                  .'</span>';
     }
 
     if ($result) {
-        $r->print($result.'<hr width="100%" />');
+        $r->print($result.'<hr />');
     }
     $r->rflush();
 
@@ -592,7 +600,7 @@ sub display_threshold_config {
                  &Apache::loncommon::end_data_table_row());
     }
     $r->print(&Apache::loncommon::end_data_table()."\n".
-          '<br /><input type="submit" name="threshold" value="'.&mt('Make changes').'" />
+          '<br /><input type="submit" name="threshold" value="'.&mt('Save').'" />
                  <input type="hidden" name="command" value="update" />
                  <input type="hidden" name="refpage" value="'.$refpage.'" />
                </form>');
@@ -648,7 +656,7 @@ sub display_interval_config {
     }
     $r->print('</select>&nbsp;&nbsp;
                <input type="submit" name="display" value="'.
-               &mt('Change interval').'" /></form>');
+               &mt('Save').'" /></form>');
     return;
 }
 
@@ -678,7 +686,13 @@ function toggle_countunread(choice) {
     document.discussionswitch.submit();
 }
 </script>');
-    $r->print('<br />'.&mt('Choose whether or not to display a count of the number of new posts for each resource or bulletin board which has unread posts.').'<br />'.&mt("This can increase the time taken to gather data for the '<i>What's New?</i>' page by a few seconds.").'&nbsp;&nbsp;'.&mt("Currently set to <b>$current</b>."));
+    $r->print('<br />'
+             .&mt('Choose whether or not to display a count of the number of new posts for each resource or discussion board which has unread posts.')
+             .'<br />'
+             .&mt("This can increase the time taken to gather data for the [_1]What's New Page[_2] by a few seconds.",'<i>','</i>')
+             .'&nbsp;&nbsp;'
+             .&mt('Currently set to [_1].','<b>'.$current.'</b>.')
+    );
     $r->print('<br /><br />
 <form method="post" name="discussionswitch" action="/adm/whatsnew">
 <input type="hidden" name="command" value="newdiscconf" />
@@ -717,7 +731,7 @@ sub courseinit_config {
                              'anis' => 'and is set to display',
                              'padc' => 'Page display controlled by',
                              'chce' => 'Choose '.$lctype.' entry',
-                             'moce' => 'Modify '.$lctype.' entry',
+                             'moce' => 'Save',
     );
     $r->print(<<"END"); 
 <br />$lt{'chwp'}
@@ -880,7 +894,7 @@ sub getitems {
         }
 
     }
-    return;
+    return; 
 }
 
 sub check_discussions {
@@ -1116,7 +1130,7 @@ sub process_reset {
 
 sub process_update {
     my ($uname,$udom,$threshold_titles) = @_;
-    my $setoutput = '<b>'.&mt('Changes to threshold(s) for problem tracking:').'</b><br />';
+    my $setoutput = '<b>'.&mt('Changes to threshold(s) for problem tracking:').'</b><br/><br />';
     foreach (keys %env) {
         next if ($_!~/^form\.(.+)\_setparmval$/);
         my $name  = $1;
@@ -1127,17 +1141,17 @@ sub process_update {
            
             my ($shortname) = ($name =~ /^\Q$env{'request.course.id'}\E:threshold_(.+)$/);
             if ($put_result eq 'ok') {
-                $setoutput.=&mt('Set threshold for [_1] to [_2]',
+                $setoutput.= &Apache::lonhtmlcommon::confirm_success(&mt('Set threshold for [_1] to [_2]',
 				'<b>'.$$threshold_titles{$shortname}.'</b>',
-				'<b>'.$value.'</b>').'<br />';
+				'<b>'.$value.'</b>').'<br />');
 	    } else {
-                $setoutput.=&mt('Unable to set threshold for [_1] to [_2] due to [_3].',
+                $setoutput.= &Apache::lonhtmlcommon::confirm_success(&mt('Unable to set threshold for [_1] to [_2] due to [_3].',
 				'<b>'.$name.'</b>','<b>'.$value.'</b>',
-				'<tt>'.$put_result.'</tt>').'<br />';
+				'<tt>'.$put_result.'</tt>').'<br />',1);
             }
         }
     }
-    return $setoutput;
+    return &Apache::loncommon::confirmwrapper($setoutput);
 }
 
 sub getnormalmail {
@@ -1153,9 +1167,9 @@ sub getnormalmail {
         if (($fromcid) && ($fromcid eq $env{'request.course.id'})) {
             if (defined($sendtime) && $sendtime!~/error/) {
                 my $numsendtime = $sendtime;
-                $sendtime = &Apache::lonlocal::locallocaltime($sendtime);
                 if ($status eq 'new') {
-                    $msgcount ++;
+                $sendtime = &Apache::lonlocal::locallocaltime($sendtime);
+		    $msgcount ++;
                     if ($shortsubj eq '') {
                         $shortsubj = &mt('No subject');
                     }
@@ -1691,7 +1705,7 @@ sub display_coursediscussion {
             my $feedurl=&Apache::lonfeedback::get_feedurl($ressymb);
             my $disclink = $feedurl.'?symb='.$$unread{$ressymb}{symb};
             if ($feedurl =~ /bulletinboard/) {
-                $type = 'Bulletin Board';
+                $type = 'Discussion Board';
             }
             if ($$unread{$ressymb}{'enclink'}) {
                 $disclink = $$unread{$ressymb}{'enclink'}.'?symb='.$$unread{$ressymb}{'encsymb'};
@@ -1827,19 +1841,19 @@ sub store_interval_setting {
                                              \%interval_settings,$udom,$uname);
         if ($outcome eq 'ok') {
             if (ref($interval_titles->{$context}) eq 'HASH') {
-                $result = &mt('New filter setting: [_1].','<b>'. 
-                              $interval_titles->{$context}->{$env{'form.interval'}}.'</b>').'<br />';
+                $result = &Apache::lonhtmlcommon::confirm_success(&mt('New filter setting: [_1].','<b>'. 
+                              $interval_titles->{$context}->{$env{'form.interval'}}.'</b>').'<br />');
             }
         } else {
 	    my $lctype = lc(&Apache::loncommon::course_type());
             &Apache::lonnet::logthis('Error saving whatsnew '.$context.' interval setting'.
                 ' '.$outcome.' for '.$uname.':'.$udom.' in '.$lctype.' '.$cid);
-            $result = &mt('Unable to set interval to [_1] due to [_2].',
+            $result = &Apache::lonhtmlcommon::confirm_success(&mt('Unable to set interval to [_1] due to [_2].',
                          '<b>'.$interval_titles->{$context}->{$env{'form.interval'}}.'</b>',
-                         '<tt>'.$outcome.'</tt>.<br />');
+                         '<tt>'.$outcome.'</tt>'),1);
         }
     }
-    return $result;
+    return &Apache::loncommon::confirmwrapper($result);
 }
 
 sub store_discussion_setting {
@@ -1851,20 +1865,20 @@ sub store_discussion_setting {
         my $outcome = &Apache::lonnet::put('nohist_whatsnew',
                                              \%discussion_settings,$udom,$uname);
         if ($outcome eq 'ok') {
-            $result = &mt('Count unread posts in discussions display set to [_1]',
-                  '<b>'.&mt($env{'form.countunread'}).'</b>').'<br />';
+            $result = &Apache::lonhtmlcommon::confirm_success(&mt('Count unread posts in discussions display set to [_1]',
+                  '<b>'.&mt($env{'form.countunread'}).'</b>').'<br />');
                                                                                   
         } else {
 	    my $lctype = lc(&Apache::loncommon::course_type());
             &Apache::lonnet::logthis('Error saving whatsnew countunread setting'.
                 ' '.$outcome.' for '.$uname.':'.$udom.' in '.$lctype.' '.$cid);
-            $result = &mt('Unable to set "number unread posts display" to [_1]'.
+            $result = &Apache::lonhtmlcommon::confirm_success(&mt('Unable to set "number unread posts display" to [_1]'.
                           ' due to [_2].',
                          '<b>'.&mt($env{'form.countunread'}).'</b>',
-                         '<tt>'.$outcome.'</tt>.<br />');
+                         '<tt>'.$outcome.'</tt>'),1);
         }
     }
-    return $result;
+    return &Apache::loncommon::confirmwrapper($result);
 }
 
 sub store_courseinit_setting {
@@ -1889,27 +1903,29 @@ sub store_courseinit_setting {
                                            \%courseinit_settings,$udom,$uname);
             if ($outcome eq 'ok') {
                 if ($page_control eq 'global preferences') {
-                    $result = &mt("Page displayed after role selection in $lctype now set by <b>user's global preferences</b>.");
+                    $result = &Apache::lonhtmlcommon::confirm_success(&mt("Page displayed after role selection in $lctype now set by [_1]user's global preferences[_2].",'<b>','</b>'));
                 } else {
-                    $result = &mt('Page displayed after role selection in this '.$lctype.' set to <b>[_2]</b>',$lctype,$$initpage{$env{'form.courseinit_page'}});
+                    $result = &Apache::lonhtmlcommon::confirm_success(&mt('Page displayed after role selection in this '.$lctype.' set to [_1].'
+                                 ,'<b>'.$$initpage{$env{'form.courseinit_page'}}.'</b>'));
                 }
             } else {
                 &Apache::lonnet::logthis('Error saving whatsnew courseinit '.
                                          'setting: '.$outcome.' for '.$uname.
                                          ':'.$udom.' in '.$lctype.' '.$cid);
                 if ($page_control eq 'global preferences') {
-                    $result = &mt('Unable to set control of page display to [_1]'.
+                    $result = &Apache::lonhtmlcommon::confirm_success(&mt('Unable to set control of page display to [_1]'.
                           ' due to [_2].',
                          '<b>'.$page_control.'</b>',
-                         '<tt>'.$outcome.'</tt>.<br />');
+                         '<tt>'.$outcome.'</tt>'),1);
                 } else {
-                    $result = &mt('Unable to set page display, after role selection, for this '.$lctype.' to <b>[_2]</b> due to <tt>[_3]</tt>.<br />',
-                         $$initpage{$env{'form.courseinit_page'}},$outcome);
+                    $result = &Apache::lonhtmlcommon::confirm_success(&mt('Unable to set page display, after role selection, for this '.$lctype.' to [_1] due to [_2].'
+                                 ,'<b>'.$$initpage{$env{'form.courseinit_page'}}.'</b>'
+                                 ,'<tt>'.$outcome.'</tt>'),1);
                 }
             }
         }
     }
-    return $result;
+    return &Apache::loncommon::confirmwrapper($result);
 }
 
 sub start_box {
@@ -1941,35 +1957,35 @@ sub start_box {
          if ($$show{$caller}) {
              $r->print('
               <tr>
-                <td class="LC_subheader" colspan="2"><a href="/adm/whatsnew?command=chgthreshold&refpage='.$refpage.'">'.$lt{'chth'}.'</a></td>
+                <td class="LC_subheader" colspan="2"><a href="/adm/whatsnew?command=chgthreshold&amp;refpage='.$refpage.'">'.$lt{'chth'}.'</a></td>
               </tr>');
          }
      } elsif (($caller eq 'versionchanges') && ($$show{$caller})) {
          if ($$show{$caller}) {
              $r->print('
               <tr>
-                <td class="LC_subheader" colspan="2"><a href="/adm/whatsnew?command=chginterval&refpage='.$refpage.'">'.$lt{'chin'}.'</a></td>
+                <td class="LC_subheader" colspan="2"><a href="/adm/whatsnew?command=chginterval&amp;refpage='.$refpage.'">'.$lt{'chin'}.'</a></td>
               </tr>');
          }
      } elsif ($caller eq 'coursediscussion') {
          if ($$show{$caller}) {
              $r->print('
               <tr>
-                <td class="LC_subheader" colspan="2"><a href="/adm/whatsnew?command=chgdisc&refpage='.$refpage.'">'.$lt{'chop'}.'</a></td>
+                <td class="LC_subheader" colspan="2"><a href="/adm/whatsnew?command=chgdisc&amp;refpage='.$refpage.'">'.$lt{'chop'}.'</a></td>
               </tr>');
          }
      } elsif (($caller eq 'newroles') && ($$show{$caller})) {
          if ($$show{$caller}) {
              $r->print('
               <tr>
-                <td class="LC_subheader" colspan="2"><a href="/adm/whatsnew?command=chgnewroleinterval&refpage='.$refpage.'">'.$lt{'chin'}.'</a></td>
+                <td class="LC_subheader" colspan="2"><a href="/adm/whatsnew?command=chgnewroleinterval&amp;refpage='.$refpage.'">'.$lt{'chin'}.'</a></td>
               </tr>');
          }
      } elsif (($caller eq 'oldroles') && ($$show{$caller})) {
          if ($$show{$caller}) {
              $r->print('
               <tr>
-                <td class="LC_subheader" colspan="2"><a href="/adm/whatsnew?command=chgoldroleinterval&refpage='.$refpage.'">'.$lt{'chin'}.'</a></td>
+                <td class="LC_subheader" colspan="2"><a href="/adm/whatsnew?command=chgoldroleinterval&amp;refpage='.$refpage.'">'.$lt{'chin'}.'</a></td>
               </tr>');
          }
      }
