@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 # CGI-script to run LaTeX, dvips, ps2ps, ps2pdf etc.
 #
-# $Id: printout.pl,v 1.137 2008/08/27 01:38:10 raeburn Exp $
+# $Id: printout.pl,v 1.142.6.2 2009/11/17 01:13:51 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -45,9 +45,14 @@ use strict;
 
 my $busy_wait_timeout = 30; 
 
+
+my $debugging = 0;
+
 sub debug {
-    my ($text) = @_;
-    print "$text <br />\n";
+    if ($debugging) {
+	my ($text) = @_;
+	print "$text <br />\n";
+    }
 }
 
 #   Determine if a user is operating as a student for this course/domain.
@@ -118,7 +123,7 @@ sub send_error_mail {
 	
 	if (&is_student()) {
 	    # build the subject and message body:
-	    # print "sending message to course coordinators.<br />";
+	    &debug("sending message to course coordinators.");
 
 	    # Todo: Convert badurl into a url from file path:
 
@@ -137,9 +142,9 @@ sub send_error_mail {
 	    }
 	    my (undef, %receivers) = &Apache::lonmsg::decide_receiver(undef, 0,
 								      1,1,1);
-	    # print "<br /> sending...section:  $env{'request.course.sec'}";
+	    &debug("sending...section:  $env{'request.course.sec'}");
 	    foreach my $dest (keys %receivers) {
-		# print "<br /> dest is $dest";
+		&debug("dest is $dest");
 		my @destinfo = split(/:/,$dest);
 		my $user = $destinfo[0];
 		my $dom  = $destinfo[1];
@@ -166,7 +171,7 @@ Your cookie information is incorrect.
 </body>
 </html>
 END
-    return;
+    exit;
 }
 
 my %perlvar=%{&LONCAPA::Configuration::read_conf('loncapa.conf')};
@@ -211,8 +216,11 @@ $duefile =~ s/^(.*_printout)_\d+_\d+_\d+\.tex/$1\.due/;
 #   it contains the names of the files that need to be converted, one per line.
 #
 
+&debug("Figure file is $figfile");
+
 if (-e $figfile) {
-    # print "$figfile exists\n";
+    &debug( "Figure file exists");
+    &debug("$figfile exists");
     my %done_conversion;
     my $temporary_file=IO::File->new($figfile) || die "Couldn't open fig file $figfile for reading: $!\n";
     my @content_of_file = <$temporary_file>;
@@ -223,6 +231,7 @@ if (-e $figfile) {
     print('<br />');
     foreach my $not_eps (@content_of_file) {
 	chomp($not_eps);
+	&debug( "Being asked to convert $not_eps");
 	if ($not_eps ne '') {
 	    $not_eps=~s|\/\.\/|\/|g;
 	    if (!$done_conversion{$not_eps}) { #  Only convert multiple includes once.
@@ -403,7 +412,8 @@ foreach $texfile (@texfile) {
 	  my $papera=$paper;
 	  if ($papera eq 'letter') {$papera='';}
 	  if ($papera ne '') {$papera='-t'.$papera;}
-	  my $comma = "dvips $papera -Ppdf -G0 -o $new_name_file";
+	  my $extra_ps_header = $perlvar{'lonLib'} .'/includepsheader.ps';
+	  my $comma = "dvips $papera -h $extra_ps_header -Ppdf -G0 -o  $new_name_file";
 	  &busy_wait_command("$comma $name_file 1>/dev/null 2>/dev/null",
 			     "for $status_statement now Converting to PS",
 			     \%prog_state,$new_name_file);
@@ -457,14 +467,21 @@ foreach $texfile (@texfile) {
 	      my $ps_file = my $tempo_file = $1.'temporar.ps';
 	      my $pdf_file = $1.'.pdf';
 	      $papera=~s/t/p/;
+              $comma = "fixps --force $new_name_file";
+              &debug("FIXPS command: $comma");
+              &busy_wait_command("$comma 1>/dev/null 2>/dev/null",
+                                 "for $status_statement now validating PS",
+                                 \%prog_state,$tempo_file);
 	      if ($laystyle eq 'album' and $numberofcolumns eq '2') {
 		  $comma = "psnup $papera -2 -s1.0 $new_name_file";
+		  &debug("PSNUP command: $comma");
 		  &busy_wait_command("$comma $tempo_file 1>/dev/null 2>/dev/null",
 				     "for $status_statement now Modifying PS layout",
 				     \%prog_state,$tempo_file);
 	      } elsif ($laystyle eq 'book' and $numberofcolumns eq '2') {
-		  $comma = 'pstops '.$papera.' "2:0+1(0.48w,0)"';
-		  &busy_wait_command("$comma $new_name_file $tempo_file 1>/dev/null 2>/dev/null",
+		  $comma = 'pstops '.$papera.' "2:0+1(0.48w,0)" '.$new_name_file;
+		  &debug("PSTOPS command: $comma ");
+		  &busy_wait_command("$comma $tempo_file 1>/dev/null 2>/dev/null",
 				     "for $status_statement now Modifying PS layout",
 				     \%prog_state,$tempo_file); 
 	      } else {
@@ -491,7 +508,7 @@ foreach $texfile (@texfile) {
 		  close(FFHS);
 		  $ps_file=$new_ps_file;	  
 	      }
-	      &busy_wait_command("ps2pdf $ps_file $pdf_file 1>/dev/null 2>/dev/null",
+	      &busy_wait_command("ps2pdf13 $ps_file $pdf_file 1>/dev/null 2>/dev/null",
 				 "for $status_statement now Converting PS to PDF",
 				 \%prog_state,$pdf_file);
 	    
@@ -845,6 +862,7 @@ sub create_missing_fonts {
 #
 sub convert_figure {
     my ($not_eps) = @_;
+    &debug("in convert_figure");
 
     my $status_statement='EPS picture for '.$not_eps;
     my $eps_f = $not_eps;
@@ -888,7 +906,24 @@ sub convert_figure {
 	    &Apache::lonhtmlcommon::Update_PrgWin('',\%prog_state,
 						  'Converting to EPS '.$prettyname);
 	}
-	system("convert $not_eps $eps_f");
+	#
+	#  If the file is a PDF, need to use pdftops to convert it to a ps file.
+	#  otherwise use imagemagik:
+	#
+	if($not_eps =~/\.(pdf|PDF)$/) {
+
+	    #
+	    # For whatever reason, pure postscript conversions have to be
+	    # in the same dir as the base file:
+	    #
+	    $eps_f = &basename($eps_f);
+	    $eps_f = $perlvar{'lonPrtDir'}.'/'.$eps_f;
+
+	    &debug("Converting pdf $not_eps to postscript: $eps_f");
+	    system("pdftops $not_eps $eps_f");
+	} else {
+	    system("convert $not_eps $eps_f");
+	}
 
 	if (not -e $eps_f) {
 	    # converting an animated gif creates either:
@@ -972,7 +1007,7 @@ sub analyze_logfile {
 
 	if ($advanced_role) {  
 	    #LaTeX failed to parse tex file 
-	    print "<h2>".&mt('LaTeX could not successfully parse your tex file.')."</h2>";
+	    print "<h2>".&mt('LaTeX could not successfully parse your TeX file.')."</h2>";
 	    print &mt('It probably has errors in it.')."<br />";
 	    if ($badtext) {
                 print &mt('With very high probability this error occured in [_1].',$badtext)
@@ -1025,13 +1060,15 @@ sub analyze_logfile {
 	    #    $name_file     - is the name of the LaTeX file.
 	    #    $identifier    - is the unique LaTeX identifier.l
 	    
-            print "<br />";
+            print '<p class="LC_error">';
 	    if ($badtext) {
                 print &mt('There are errors in [_1].',$badtext);
             } else {
                 print &mt('There are errors.');
             }
-	    print "<br />".&mt('These errors prevent this resource from printing correctly.');
+            print '</p>'
+                 .&mt('These errors prevent this resource from printing correctly.');
+
 	    my $tex_handle = IO::File->new($texfile);
 	    my @tex_contents = <$tex_handle>;
 	    &send_error_mail($identifier, $badresource, $body_log_file, \@tex_contents);
