@@ -1,6 +1,8 @@
 # The LearningOnline Network
 # Allow access to password changing via a token sent to user's e-mail. 
 #
+# $Id: resetpw.pm,v 1.22 2009/10/09 00:26:40 raeburn Exp $
+#
 # Copyright Michigan State University Board of Trustees
 #
 # This file is part of the LearningOnline Network with CAPA (LON-CAPA).
@@ -24,6 +26,28 @@
 # http://www.lon-capa.org/
 #
 #
+
+=pod
+
+=head1 NAME
+
+Apache::resetpw: reset user password.
+
+=head1 SYNOPSIS
+
+Handles resetting of forgotten passwords.
+
+This is part of the LearningOnline Network with CAPA project
+described at http://www.lon-capa.org.
+ 
+=head1 OVERVIEW
+
+A user with an e-mail address associated with his/her LON-CAPA username
+can reset a forgotten password, using a link sent to the e-mail address
+if the authentication type for the account is "internal".
+
+=cut
+
 package Apache::resetpw;
 
 use strict;
@@ -44,7 +68,7 @@ sub handler {
     my $contact_name = &mt('LON-CAPA helpdesk');
     my $contact_email =  $r->dir_config('lonSupportEMail');
     my $server = $r->dir_config('lonHostID');
-    my $defdom = $r->dir_config('lonDefDomain');
+    my $defdom = &Apache::lonnet::default_login_domain();
     &Apache::lonacc::get_posted_cgi($r);
     &Apache::lonlocal::get_language_handle($r);
     &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},['token']);
@@ -74,18 +98,26 @@ sub handler {
                 my %userinfo = 
 		    &Apache::lonnet::get('environment',\@emailtypes,
 					 $udom,$uname);
-                my $email = '';
-                my $emailtarget;
+                my @allemails;
                 foreach my $type (@emailtypes) {
-                    $email = $userinfo{$type};
-                    if ($email =~ /[^\@]+\@[^\@]+/) {
-                        $emailtarget = $type; 
-                        last;
+                    my $email = $userinfo{$type};
+                    my @items;
+                    if ($email =~ /,/) {
+                        @items = split(',',$userinfo{$type});
+                    } else {
+                        @items = ($email);
+                    }
+                    foreach my $item (@items) {
+                        if ($item =~ /^[^\@]+\@[^\@]+\.[^\@\.]+$/) {
+                            unless(grep(/^\Q$item\E$/,@allemails)) { 
+                                push(@allemails,$item);
+                            }
+                        }
                     }
                 }
-                if ($email =~ /^[^\@]+\@[^\@]+\.[^\@\.]+$/) {
-                    if ($useremail eq $email) {
-                        $output = &send_token($uname,$udom,$email,$server,
+                if (@allemails > 0) {
+                    if (grep(/^\Q$useremail\E$/,@allemails)) {
+                        $output = &send_token($uname,$udom,$useremail,$server,
                                               $domdesc,$contact_name,
                                               $contact_email);
                     } else {
@@ -118,7 +150,7 @@ sub get_uname {
     my %lt = &Apache::lonlocal::texthash(
                                          unam => 'username',
                                          udom => 'domain',
-                                         uemail => 'Email address in LON-CAPA',
+                                         uemail => 'E-mail address in LON-CAPA',
                                          proc => 'Proceed');
 
     my $msg = &mt('If you use the same account for other campus services besides LON-CAPA, (e.g., e-mail, course registration, etc.), a separate centrally managed mechanism likely exists to reset a password.  However, if your account is used for just LON-CAPA access you will probably be able to reset a password from this page.');
@@ -132,15 +164,15 @@ sub get_uname {
 <table>
 <tr><td>
 <tr><td align="left">LON-CAPA $lt{'unam'}:                      </td>
-    <td><input type="text" name="uname" size="15"  /> </td></tr>
+    <td><input type="text" name="uname" size="15" /></td></tr>
 <tr><td align="left">LON-CAPA $lt{'udom'}:                      </td>
     <td>|;
     $msg .= &Apache::loncommon::select_dom_form($defdom,'udom');
     $msg .= qq|</td></tr>
 <tr><td align="left">$lt{'uemail'}:                             </td>
-    <td><input type="text" name="useremail" size="30"  /></td></tr>
+    <td><input type="text" name="useremail" size="30" /></td></tr>
 <tr><td colspan="2" align="left"><br />
-    <input type="button" value="$lt{'proc'}" onClick="document.forgotpw.submit()"></td></tr>
+    <input type="submit" value="$lt{'proc'}" /></td></tr>
 </table>
 </form>
 |;
@@ -164,14 +196,13 @@ sub send_token {
     my $token = &Apache::lonnet::tmpput(\%info,$server,'resetpw');
     if ($token !~ /^error/ && $token ne 'no_such_host') {
         my $esc_token = &escape($token);
-        my $mailmsg = "A request was submitted on ".&Apache::lonlocal::locallocaltime(time)." for a reset of the ".
-             "password for your LON-CAPA account.".
-             "To complete this process please open a web browser and enter the following ".
-             "URL in the address/location box: ".&Apache::lonnet::absolute_url()."/adm/resetpw?token=$esc_token";
+        my $showtime = &Apache::lonlocal::locallocaltime(time);
+        my $reseturl = &Apache::lonnet::absolute_url().'/adm/resetpw?token='.$esc_token;
+        my $mailmsg = &mt('A request was submitted on [_1] for reset of the password for your LON-CAPA account.',$showtime).' '.&mt('To complete this process please open a web browser and enter the following URL in the address/location box: [_1]',$reseturl);
         my $result = &send_mail($domdesc,$email,$mailmsg,$contact_name,
                                 $contact_email);
         if ($result eq 'ok') {
-            $msg .= &mt("An e-mail message sent to the e-mail address associated with your LON-CAPA account includes the web address for the link you should use to complete the reset process.<br /><br />The link included in the message will be valid for the next <b>two</b> hours.");
+            $msg .= &mt("An e-mail sent to the e-mail address associated with your LON-CAPA account includes the web address for the link you should use to complete the reset process.<br /><br />The link included in the message will be valid for the next <b>two</b> hours.");
         } else {
             $msg .= &mt("An error occurred when sending a message to the e-mail address associated with your LON-CAPA account. Please contact the [_1] ([_2]) for assistance.",$contact_name,$contact_email);
         }
@@ -233,7 +264,8 @@ sub reset_passwd {
     my %data = &Apache::lonnet::tmpget($token);
     my $now = time;
     if (keys(%data) == 0) {
-        $msg = &mt('Sorry, the URL you provided to complete the reset of your password was invalid.  Either the token included in the URL has been deleted or the URL you provided was invalid. Please submit a <a href="/adm/resetpw">new request</a> for a password reset, and follow the link to the new URL included in the e-mail that will be sent to you, to allow you to enter a new password.');
+        $msg = &mt('Sorry, the URL you provided to complete the reset of your password was invalid. Either the token included in the URL has been deleted or the URL you provided was invalid. Please submit a [_1]new request[_2] for a password reset, and follow the link to the new URL included in the e-mail that will be sent to you, to allow you to enter a new password.'
+                  ,'<a href="/adm/resetpw">','</a>');
         return $msg;
     }
     if (($data{'time'} =~ /^\d+$/) && 
@@ -244,6 +276,10 @@ sub reset_passwd {
         my $reqtime = &Apache::lonlocal::locallocaltime($data{'time'});
         if ($now - $data{'time'} < 7200) {
             if ($env{'form.action'} eq 'verify_and_change_pass') {
+                unless (($env{'form.uname'} eq $data{'username'}) && ($env{'form.udom'} eq $data{'domain'}) && ($env{'form.email'} eq $data{'email'})) {
+                    $msg = &generic_failure_msg($contact_name,$contact_email);
+                    return $msg;
+                }
                 my $change_failed = 
 		    &Apache::lonpreferences::verify_and_change_password($r,'reset_by_email',$token);
                 if (!$change_failed) {
@@ -259,24 +295,49 @@ sub reset_passwd {
                     } else {
                         $msg .= &mt('An error occurred when sending e-mail to [_1] confirming setting of your new password.',$data{'email'});
                     }
-                    $msg .= '<br /><br />'.&mt('<a href="/adm/login">Go to the login page</a>.');
+                    $msg .= '<br /><br />'
+                           .'<a href="/adm/login">'.&mt('Go to the login page').'</a>.';
+                } elsif ($change_failed eq 'invalid_client') {
+                    my $homeserver = &Apache::lonnet::homeserver($data{'username'},$data{'domain'});
+                    if ($homeserver eq 'no_host') {
+                        $msg .= &generic_failure_msg($contact_name,$contact_email);
+                    } else {
+                        my $protocol = $Apache::lonnet::protocol{$homeserver};
+                        $protocol = 'http' if ($protocol ne 'https');
+                        my $url = $protocol.'://'.&Apache::lonnet::hostname($homeserver).
+                                  '/adm/resetpw';
+                        my ($opentag,$closetag);
+                        if ($url) {
+                           $opentag = '<a href="'.$url.'">';
+                           $closetag = '</a>';
+                        }
+                        $msg .= &mt('A problem occurred when attempting to reset the password for your account. Please try again from your [_1]home server[_2].',$opentag,$closetag);
+                    }
                 } else {
-                    $msg .= &mt('A problem occurred when attempting to reset the password for your account.  Please contact the [_1] - (<a href="mailto:[_2]">[_2]</a>) for assistance.',$contact_name,$contact_email);
+                    $msg .= &generic_failure_msg($contact_name,$contact_email);
                 }
             } else {
-                $r->print(&mt('The token included in an email sent to you [_1] has been verified, so you may now proceed to reset the password for your LON-CAPA account.',$reqtime).'<br /><br />');
+                $r->print(&mt('The token included in an e-mail sent to you [_1] has been verified, so you may now proceed to reset the password for your LON-CAPA account.',$reqtime).'<br /><br />');
                 $r->print(&mt('Please enter the username and domain of the LON-CAPA account, and the associated e-mail address, for which you are setting a password. The new password must contain at least 7 characters.').' '.&mt('Your new password will be sent to the LON-CAPA server in an encrypted form.').'<br />');
                 &Apache::lonpreferences::passwordchanger($r,'','reset_by_email',$token);
             }
         } else {
-            $msg = &mt('Sorry, the token generated when you requested a password reset has expired. Please submit a <a href="/adm/resetpw">new request</a>, and follow the link to the web page included in the new e-mail that will be sent to you, to allow you to enter a new password.');
+            $msg = &mt('Sorry, the token generated when you requested a password reset has expired. Please submit a [_1]new request[_2], and follow the link to the web page included in the new e-mail that will be sent to you, to allow you to enter a new password.'
+                      ,'<a href="/adm/resetpw">','</a>');
         }
     } else {
-        $msg .= &mt('Sorry, the URL generated when you requested reset of your password contained incomplete information. Please submit a <a href="/adm/resetpw">new request</a> for a password reset, and use the new URL that will be sent to your e-mail account to complete the process.');
+        $msg .= &mt('Sorry, the URL generated when you requested reset of your password contained incomplete information. Please submit a [_1]new request[_2] for a password reset, and use the new URL that will be sent to your e-mail account to complete the process.'
+                   ,'<a href="/adm/resetpw">','</a>');
     }
     return $msg;
 }
 
+sub generic_failure_msg {
+    my ($contact_name,$contact_email) = @_;
+    return &mt('A problem occurred when attempting to reset the password for your account. Please contact the [_1] - ([_2]) for assistance.',
+              $contact_name,'<a href="mailto:'.$contact_email.'">'.$contact_email.'</a>');
+}
+
 sub create_passwd {
     my $passwd = '';
     my @letts = ("a".."z");
