@@ -1,5 +1,5 @@
 #
-# $Id: studentcalc.pm,v 1.43 2007/07/06 19:50:00 albertel Exp $
+# $Id: studentcalc.pm,v 1.44 2009/06/09 14:15:42 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -223,16 +223,16 @@ END
     }
     $tableheader .="</tr>\n";
     if ($self->blackout()) {
-        $r->print('<font color="red" size="+2"><p>'.
+        $r->print('<p class="LC_warning">'.
                   &mt('Some computations are not available at this time.').'<br />'.
                   &mt('There are problems whose status you are not allowed to view.').
-                  '</font></p>'."\n");
+                  '</p>'."\n");
     } else {
         $r->print($tableheader);
         #
         # Print out template row
         if (exists($env{'request.role.adv'}) && $env{'request.role.adv'}) {
-            $r->print('<tr><td>Template</td><td>&nbsp;</td>'.
+            $r->print('<tr><td>'.&mt('Template').'</td><td>&nbsp;</td>'.
                       $self->html_template_row($num_uneditable,
                                                $importcolor)."</tr>\n");
         }
