@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: longradinganalysis.pm,v 1.8 2008/09/12 14:35:45 bisitz Exp $
+# $Id: longradinganalysis.pm,v 1.9 2008/10/23 09:07:51 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -328,11 +328,11 @@ sub create_interface {
     #
     $str .= '<td>';
     ##
-    $str .= '<nobr><label>'.&mt('Status: [_1]',
-                                 '<input type="text" '.
-                                 'name="stats_status" size="60" value="" />'
-                                 ).
-                    '</label></nobr>';
+    $str .= '<span class="LC_nobreak"><label>'
+           .&mt('Status: [_1]',
+                    '<input type="text" name="stats_status"'
+                   .' size="60" value="" readonly="readonly" />')
+           .'</label></span>';
     $str .= '</td>';
     ##
     ##
