@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Construction Space Directory Lister
 #
-# $Id: lonpubdir.pm,v 1.110.2.1 2008/12/21 04:36:58 raeburn Exp $
+# $Id: lonpubdir.pm,v 1.114.2.2 2010/02/12 16:04:18 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -62,7 +62,7 @@ sub handler {
     &Apache::loncacc::constructaccess(
              $fn,$r->dir_config('lonDefDomain')); 
   unless (($uname) && ($udom)) {
-     $r->log_reason($uname.' at '.$udom.
+     $r->log_reason($uname.':'.$udom.
          ' trying to list directory '.$env{'form.filename'}.
          ' ('.$fn.') - not authorized', 
          $r->filename); 
@@ -74,7 +74,7 @@ sub handler {
   $fn=~s/\/$//;
 
   unless ($fn) { 
-     $r->log_reason($env{'user.name'}.' at '.$env{'user.domain'}.
+     $r->log_reason($env{'user.name'}.':'.$env{'user.domain'}.
          ' trying to list empty directory', $r->filename); 
      return HTTP_NOT_FOUND;
   } 
@@ -156,7 +156,8 @@ sub getEffectiveUrl {
 	#   Replace the ~username of the URL with /home/username/public_html
 	#   so that we don't have to worry about ~ expansion internally.
 	#
-	$fn=~s/^https?\:\/\/[^\/]+\///;
+        $fn=~s/^https?\:\/\/[^\/]+\///;
+
         $fn=~s/^\///;
         $fn=~s{~($LONCAPA::username_re)}{/home/$1/public_html};
 	
@@ -233,7 +234,7 @@ parent.lastknownpriv='/~$uname$esc_thisdisfn/';
             document.publishdir.filename.value = theform.filename.value;
 	    document.publishdir.submit();
         }
-        if (theform.dirtask.options[theform.dirtask.selectedIndex].value == 'editcat') {
+        if (theform.dirtask.options[theform.dirtask.selectedIndex].value == 'editmeta') {
             top.location=theform.filename.value+'default.meta'
         }
         if (theform.dirtask.options[theform.dirtask.selectedIndex].value == 'printdir' ) {
@@ -263,7 +264,7 @@ parent.lastknownpriv='/~$uname$esc_thisdisfn/';
         if (theform.diraction.options[theform.diraction.selectedIndex].value == "publish") {
             theform.submit();
         }
-        if (theform.diraction.options[theform.diraction.selectedIndex].value == "editcat") {
+        if (theform.diraction.options[theform.diraction.selectedIndex].value == "editmeta") {
             top.location=theform.filename.value+'default.meta'
         }
         if (theform.diraction.options[theform.diraction.selectedIndex].value == "printdir") {
@@ -330,8 +331,7 @@ ENDPUBDIRSCRIPT
 
     if ((($uname ne $env{'user.name'}) || ($udom ne $env{'user.domain'})) &&
 	$env{'environment.remote'} ne 'off') {
-	$r->print('<h3>'.&mt('Co-Author').': '.$uname.' at '.$udom.
-		  '</h3>');
+        $r->print('<h3>'.&mt('Co-Author [_1]',$uname.':'.$udom).'</h3>');
     }
 }
 
@@ -348,7 +348,7 @@ sub dircontrols {
                                        list => 'List Directory',
                                        uplo => 'Upload file',  
                                        dele => 'Delete',
-                                       edit => 'Edit Catalog Information', 
+                                       edit => 'Edit Metadata', 
                                        sela => 'Select Action',
                                        nfil => 'New file',
                                        nhtm => 'New HTML file',
@@ -385,7 +385,7 @@ sub dircontrols {
            <select name="dirtask" onchange="currdiract(this.form)">
             <option>$lt{'sela'}</option>
             <option value="publish">$lt{'pubd'}</option>
-            <option value="editcat">$lt{'edit'}</option>
+            <option value="editmeta">$lt{'edit'}</option>
             <option value="printdir">$lt{'prnt'}</option>
             <option value="delete">$lt{'dedr'}</option>
            </select>
@@ -449,7 +449,7 @@ sub pubbuttons {
               '<input type="submit" value="'.&mt('Publish Directory').'" /></td><td>'.
 '<input type="button" onclick="window.location='."'/~".
                $uname.$thisdisfn."/default.meta'".'" value="'.
-&mt('Edit Directory Catalog Information').'" /></td></tr></table></form>');
+&mt('Edit Directory Metadata').'" /></td></tr></table></form>');
 }
 
 sub resourceactions {
@@ -550,7 +550,7 @@ sub putdirectory {
                       '<option selected="selected">'.&mt('Select action').'</option>'.
                       '<option value="open">'.&mt('Open').'</option>'.
                       '<option value="publish">'.&mt('Publish').'</option>'.
-                      '<option value="editcat">'.&mt('Edit catalog information').'</option>'.
+                      '<option value="editmeta">'.&mt('Edit Metadata').'</option>'.
                       '<option value="printdir">'.&mt('Print directory').'</option>'.
                       '<option value="delete">'.&mt('Delete directory').'</option>'.
                     '</select>'.
@@ -621,9 +621,17 @@ sub putresource {
 	    $meta_same = 0;
 	}
 	$publish_button=&mt('Re-publish');
-	my $rights_status =
-	    &mt(&getCopyRightString($targetdir.'/'.$filename)).' '.
-	    &mt(&getSourceRightString($targetdir.'/'.$filename));
+
+        my $rights_status =
+            &mt(&getCopyRightString($targetdir.'/'.$filename)).', ';
+
+        my %lt_SourceRight = &Apache::lonlocal::texthash(
+               'open'   => 'Source: open',
+               'closed' => 'Source: closed',
+        );
+        $rights_status .=
+            $lt_SourceRight{&getSourceRightString($targetdir.'/'.$filename)};
+
 	$title = '<a href="/res/'.$targetdir.'/'.$filename.
 	    '.meta" target="cat">'.
 	    &getTitleString($targetdir.'/'.$filename).'</a>';
@@ -785,6 +793,7 @@ sub CategorizeFiles {
 1;
 __END__
 
+
 =head1 NAME
 
 Apache::lonpubdir - Construction space directory lister
@@ -840,4 +849,64 @@ run through list of files and attempt to publish unhidden files
 
 =back
 
+=head1 SUBROUTINES:
+
+=over
+
+=item startpage($r, $uame, $udom, $thisdisfn)
+
+Output the header of the page.  This includes:
+ - The HTML header 
+ - The H1/H3  stuff which includes the directory.
+ 
+    startpage($r, $uame, $udom, $thisdisfn);
+        $r     - The apache request object.
+        $uname - User name.
+        $udom  - Domain name the user is logged in under.
+        $thisdisfn - Displayable version of the filename.
+
+=item getTitleString($fullname)
+
+    Get the title string or "[untitled]" if the file has no title metadata:
+    Without the latter substitution, it's impossible to examine metadata for
+    untitled resources.  Resources may be legitimately untitled, to prevent
+    searches from locating them.
+    
+    $str = getTitleString($fullname);
+        $fullname - Fully qualified filename to check.
+
+=item putdirectory(r, base, here, dirname, modtime)
+
+    Put out a directory table row:
+    
+    putdirectory($r, $base, $here, $dirname, $modtime)
+        $r       - Apache request object.
+        $reqfile - File in request.
+        $here    - Where we are in directory tree.
+        $dirname - Name of directory special file.
+        $modtime - Encoded modification time.
+
+=item CategorizeFiles($location, $files)
+    
+    Categorize files in the directory.
+    For each file in a list of files in a file directory, 
+    the  file categorized as one of:
+        - directory  
+        - sequence
+        - problem 
+        - Other resource.
+
+    For each file the modification date is determined as well.
+    Returned is a list of sublists:
+        (directories, sequences, problems, other)
+    each of the sublists contains entries of the following form (sorted by filename):
+    (filename, typecode, lastmodtime)
+    
+        $list = CategorizeFiles($location, $files)
+        $location   - Directory in which the files live (relative to our execution)
+        $files      - list of files.
+
+=back
+
 =cut
+
