@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler to show and edit custom distribution rights
 #
-# $Id: lonrights.pm,v 1.24 2007/07/13 18:35:28 albertel Exp $
+# $Id: lonrights.pm,v 1.25.2.1 2010/01/27 16:18:17 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -174,7 +174,9 @@ sub handler {
   my $token;
   my $rulecounter=0;
   my $colzero=&mt($constructmode?'Edit action':'Rule');
-  my %lt=&Apache::lonlocal::texthash('ef' => 'Effect',
+  my %lt=&Apache::lonlocal::texthash(
+				     'ef' => 'Effect',
+				     'ty' => 'Type',
 				     'do' => 'Domain',
 				     'co' => 'Course / User',
 				     'se' => 'Section',
@@ -182,7 +184,7 @@ sub handler {
 # ---------------------------------------------------------- Start table output
   $r->print(&Apache::loncommon::start_data_table().
 	    &Apache::loncommon::start_data_table_header_row().
-	    "<th>$colzero</th><th>$lt{'ef'}</th><th>Type</th><th>$lt{'do'}</th>".
+	    "<th>$colzero</th><th>$lt{'ef'}</th><th>$lt{'ty'}</th><th>$lt{'do'}</th>".
 	    "<th>$lt{'co'}</th><th>$lt{'se'}</th><th>$lt{'ro'}</th>".
 	    &Apache::loncommon::end_data_table_header_row());
 # --------------------------------------------------------------------- Default
@@ -194,7 +196,7 @@ sub handler {
   if ($constructmode) {
      $r->print(&Apache::loncommon::select_form('','action_0',
                                   ('' => '',
-				   'insertbelow' => 'Insert rule below    ')));
+                                   'insertbelow' => &mt('Insert rule below'))));
                                                 
   } else {
       $r->print('&nbsp;');
@@ -203,6 +205,7 @@ sub handler {
   if ($constructmode) {
       $r->print(&Apache::loncommon::select_form
                                  ($token->[2]->{'effect'},'effect_0',
+                                  &Apache::lonlocal::texthash
                                    ('allow' => 'allow',
                                     'deny'  => 'deny')));
   } else {
@@ -225,10 +228,11 @@ sub handler {
           if ($constructmode) {
              $r->print(&Apache::loncommon::select_form(
                     '','action_'.$rulecounter,
+                    &Apache::lonlocal::texthash
                     ('' => '', 
                      'delete' => 'Delete this rule',
                      'insertabove' => 'Insert rule above',
-                     'insertbelow' => 'Insert rule below    ',
+                     'insertbelow' => 'Insert rule below',
                      'moveup'      => 'Move rule up',
                      'movedown'    => 'Move rule down')));
 	  }
@@ -239,6 +243,7 @@ sub handler {
              $r->print(&Apache::loncommon::select_form
                                  ($token->[2]->{'effect'},
                                   'effect_'.$rulecounter,
+                                  &Apache::lonlocal::texthash
                                    ('allow' => 'allow',
                                     'deny'  => 'deny')));
           } else {
@@ -251,6 +256,7 @@ sub handler {
           if ($constructmode) {
               $r->print(&Apache::loncommon::select_form($type,
 							'type_'.$rulecounter,
+                            &Apache::lonlocal::texthash
 							('course' => 'Course',
 							 'user'   => 'User')));
           } else {
