@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # TeX Conversion Module
 #
-# $Id: lontexconvert.pm,v 1.95 2009/01/12 04:46:48 raeburn Exp $
+# $Id: lontexconvert.pm,v 1.98 2009/08/12 20:43:25 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -262,7 +262,7 @@ sub mimetex_valign {
                                         Proto    => 'tcp');
     }
     if ($socket) {
-        my $headreq = "HEAD $path HTTP/1.0\r\nUser-Agent: Mozilla/5.0\r\n\r\n";
+        my $headreq = "HEAD $path HTTP/1.0\r\n\r\n";
         print $socket $headreq;
         while (<$socket>) {
             if (/Vertical\-Align\:\s*?([\-\d]+)/) {
@@ -282,8 +282,17 @@ sub mimetex_valign {
 
 sub mimetex_converted {
     my $texstring=shift;
+
+# Alt-Argument for screen readers
+    my $alt_string=$$texstring;
+    $alt_string=~s/\"/\'\'/g;
+
+# Is this displaystyle?
+
     my $displaystyle=&displaystyle($texstring);
 
+# Remove math environment delimiters
+
     &clean_out_math_mode($texstring);
 
     if ($displaystyle) {
@@ -291,7 +300,7 @@ sub mimetex_converted {
     }
     my $esc_texstring = &uri_escape($$texstring);
     my $valign = &mimetex_valign($esc_texstring);
-    my $result='<img src="/cgi-bin/mimetex.cgi?'.$esc_texstring.'" style="vertical-align:'.$valign.'px" alt="$'.$$texstring.'$" />';
+    my $result='<img src="/cgi-bin/mimetex.cgi?'.$esc_texstring.'" style="vertical-align:'.$valign.'px" alt="'.$alt_string.'" />';
     if ($displaystyle) {
 	$result='<center>'.$result.'</center>';
     }
@@ -307,6 +316,8 @@ sub converted {
 	return &jsMath_converted($string);
     } elsif ($mode =~ /mimetex/i) {
 	return &mimetex_converted($string);
+    } elsif ($mode =~ /raw/i) {
+        return $$string;
     }
     return &tth_converted($string);
 }
