@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # XML Parser Module 
 #
-# $Id: lonxml.pm,v 1.484.4.2 2009/03/20 20:59:54 raeburn Exp $
+# $Id: lonxml.pm,v 1.494.4.4 2010/02/11 20:44:15 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -37,6 +37,25 @@
 # to any other parties under any circumstances.
 #
 
+=pod
+
+=head1 NAME
+
+Apache::lonxml
+
+=head1 SYNOPSIS
+
+XML Parsing Module
+
+This is part of the LearningOnline Network with CAPA project
+described at http://www.lon-capa.org.
+
+
+=head1 SUBROUTINES
+
+=cut
+
+
 
 package Apache::lonxml; 
 use vars 
@@ -90,6 +109,7 @@ use Apache::lonfeedback();
 use Apache::lonmsg();
 use Apache::loncacc();
 use Apache::lonmaxima();
+use Apache::lonr();
 use Apache::lonlocal;
 
 #====================================   Main subroutine: xmlparse  
@@ -223,7 +243,7 @@ sub tokeninputfield {
         document.tokeninput.barcode.value='';
     }  
 </script>
-<form method="post" name="tokeninput">
+<form method="post" name="tokeninput" action="">
 <table border="2" bgcolor="#FFFFBB">
 <tr><th>DocID Checkin</th></tr>
 <tr><td>
@@ -231,7 +251,7 @@ sub tokeninputfield {
 <tr>
 <td>Scan in Barcode</td>
 <td><input type="text" size="22" name="barcode" 
-onChange="updatetoken()"/></td>
+onchange="updatetoken()"/></td>
 </tr>
 <tr><td><i>or</i> Type in DocID</td>
 <td>
@@ -240,7 +260,7 @@ onChange="updatetoken()"/></td>
 <input type="text" size="5" name="codetwo" />
 <b><font size="+2">*</font></b>
 <input type="text" size="10" name="codethree" value="$defhost" 
-onChange="this.value=this.value.toUpperCase()" />
+onchange="this.value=this.value.toUpperCase()" />
 </td></tr>
 </table>
 </td></tr>
@@ -505,11 +525,11 @@ sub inner_xmlparse {
 	  if (!$Apache::lonxml::usestyle) {
 	      $extras=$Apache::lonxml::style_values;
 	  }
-	if ( $#$parstack > -1 ) {
-	  $result=&Apache::run::evaluate($result,$safeeval,$extras.$$parstack[-1]);
-	} else {
-	  $result= &Apache::run::evaluate($result,$safeeval,$extras);
-	}
+	  if ( $#$parstack > -1 ) {
+	      $result=&Apache::run::evaluate($result,$safeeval,$extras.$$parstack[-1]);
+	  } else {
+	      $result= &Apache::run::evaluate($result,$safeeval,$extras);
+          }
       }
       $Apache::lonxml::post_evaluate=1;
 
@@ -736,6 +756,13 @@ sub init_safespace {
   $safehole->wrap(\&Apache::lonmaxima::maxima_cas_formula_fix,$safeeval,
 		  '&maxima_cas_formula_fix');
 
+  $safehole->wrap(\&Apache::lonr::r_eval,$safeeval,'&r_eval');
+  $safehole->wrap(\&Apache::lonr::Rentry,$safeeval,'&Rentry');
+  $safehole->wrap(\&Apache::lonr::Rarray,$safeeval,'&Rarray');
+  $safehole->wrap(\&Apache::lonr::r_check,$safeeval,'&r_check');
+  $safehole->wrap(\&Apache::lonr::r_cas_formula_fix,$safeeval,
+                  '&r_cas_formula_fix');
+ 
   $safehole->wrap(\&Apache::caparesponse::capa_formula_fix,$safeeval,
 		  '&capa_formula_fix');
 
@@ -1016,7 +1043,7 @@ sub get_id {
     my ($parstack,$safeeval)=@_;
     my $id= &Apache::lonxml::get_param('id',$parstack,$safeeval);
     if ($env{'request.state'} eq 'construct' && $id =~ /([._]|[^\w\d\s[:punct:]])/) {
-	&error(&mt("ID &quot;[_1]&quot; contains invalid characters, IDs are only allowed to contain letters, numbers, spaces and -",'<tt>'.$id.'</tt>'));
+	&error(&mt("ID [_1] contains invalid characters, IDs are only allowed to contain letters, numbers, spaces and -",'<tt>'.$id.'</tt>'));
     }
     if ($id =~ /^\s*$/) { $id = $Apache::lonxml::curdepth; }
     return $id;
@@ -1485,6 +1512,15 @@ SIMPLECONTENT
   return $filecontents;
 }
 
+sub createnewjs {
+    my $filecontents=(<<SIMPLECONTENT);
+<script type="text/javascript" language="Javascript">
+
+</script>
+SIMPLECONTENT
+    return $filecontents;
+}
+
 sub verify_html {
     my ($filecontents)=@_;
     if ($filecontents!~/(?:\<|\&lt\;)(?:html|xml)[^\<]*(?:\>|\&gt\;)/is) {
@@ -1510,20 +1546,30 @@ sub renderingoptions {
                        = &Apache::loncommon::plainlanguagedescription($_);
         }
     }
-    return
-       '<span class="LC_nobreak">'.
-       &mt('Language:').' '.
-       &Apache::loncommon::select_form($env{'form.languages'},'languages',
-                                                     %langchoices).'
-     </span>
-     <span class="LC_nobreak">'.
+    my $output;
+    unless ($env{'form.forceedit'}) {
+       $output .=
+           '<span class="LC_nobreak">'.
+           &mt('Language:').' '.
+           &Apache::loncommon::select_form(
+               $env{'form.languages'},
+               'languages',
+               &Apache::lonlocal::texthash(%langchoices)).
+           '</span>';
+    }
+    $output .=
+     ' <span class="LC_nobreak">'.
        &mt('Math Rendering:').' '.
-       &Apache::loncommon::select_form($env{'form.texengine'},'texengine',
-                                                     ('' => '',
-                                                      'tth' => 'tth (TeX to HTML)',
-                                                      'jsMath' => 'jsMath',
-                                                      'mimetex' => 'mimetex (Convert to Images)')).'
-     </span>';
+       &Apache::loncommon::select_form(
+           $env{'form.texengine'},
+           'texengine',
+           &Apache::lonlocal::texthash
+               (''        => '',
+                'tth'     => 'tth (TeX to HTML)',
+                'jsMath'  => 'jsMath',
+                'mimetex' => 'mimetex (Convert to Images)')).
+     '</span>';
+    return $output;
 }
 
 sub inserteditinfo {
@@ -1532,6 +1578,7 @@ sub inserteditinfo {
       my $xml_help = '';
       my $initialize='';
       my $textarea_id = 'filecont';
+      my $dragmath_button;
       my ($add_to_onload, $add_to_onresize);
       $initialize=&Apache::lonhtmlcommon::spellheader();
       if ($filetype eq 'html' 
@@ -1569,6 +1616,10 @@ FULLPAGE
     }
 </script>
 FULLPAGE
+          if ($filetype eq 'html') {
+              $initialize .= "\n".&Apache::lonhtmlcommon::dragmath_js('EditMathPopup');
+              $dragmath_button = &Apache::lonhtmlcommon::dragmath_button('filecont',1);
+          }
       }
 
       $add_to_onload = 'initDocument();';
@@ -1608,7 +1659,7 @@ $initialize
     <div class="LC_edit_problem_discards">
       <input type="submit" name="discardview" accesskey="d" value="$lt{'dv'}" />
       <input type="submit" name="Undo" accesskey="u" value="$lt{'un'}" />
-      $spelllink $htmlerror
+      $dragmath_button $spelllink $htmlerror
     </div>
     <div class="LC_edit_problem_saves">
       <input type="submit" name="savethisfile" accesskey="s" value="$lt{'st'}" />
@@ -1655,9 +1706,8 @@ sub get_target {
 
 sub handler {
     my $request=shift;
-    
+
     my $target=&get_target();
-    
     $Apache::lonxml::debug=$env{'user.debug'};
     
     &Apache::loncommon::content_type($request,'text/html');
@@ -1666,6 +1716,21 @@ sub handler {
 	$request->set_last_modified(&Apache::lonnet::metadata($request->uri,
 							      'lastrevisiondate'));
     }
+    # Embedded Flash movies (e.g., from Camtasia) served from https will not display in IE
+    #   if XML config file has expired from cache.
+    if ($ENV{'SERVER_PORT'} == 443) {
+        if ($request->uri =~ /\.xml$/) {
+            my ($httpbrowser,$clientbrowser) =
+                &Apache::loncommon::decode_user_agent($request);
+            if ($clientbrowser =~ /^explorer$/i) {
+                delete $request->headers_out->{'Cache-control'};
+                delete $request->headers_out->{'Pragma'};
+                my $expiration = time + 60;
+                my $date=strftime("%a, %d %b %Y %H:%M:%S GMT",gmtime($expiration));
+                $request->headers_out->set("Expires" => $date);
+            }
+        }
+    }
     $request->send_http_header;
     
     return OK if $request->header_only;
@@ -1673,11 +1738,12 @@ sub handler {
 
     my $file=&Apache::lonnet::filelocation("",$request->uri);
     my $filetype;
-    if ($file =~ /\.sty$/) {
-	$filetype='sty';
+    if ($file =~ /\.(sty|css|js|txt)$/) {
+	$filetype=$1;
     } else {
 	$filetype='html';
     }
+
 #
 # Edit action? Save file.
 #
@@ -1706,7 +1772,9 @@ ENDNOTFOUND
 	if ($env{'request.state'} ne 'published') {
 	    if ($filetype eq 'sty') {
 		$filecontents=&createnewsty();
-	    } else {
+            } elsif ($filetype eq 'js') {
+                $filecontents=&createnewjs();
+            } elsif (($filetype ne 'css') && ($filetype ne 'txt')) {
 		$filecontents=&createnewhtml();
 	    }
 	    $env{'form.editmode'}='Edit'; #force edit mode
@@ -1722,27 +1790,43 @@ ENDNOTFOUND
 						    ['editmode']);
 	}
 	if (!$env{'form.editmode'} || $env{'form.viewmode'} || $env{'form.discardview'}) {
-	    &Apache::structuretags::reset_problem_globals();
-	    $result = &Apache::lonxml::xmlparse($request,$target,$filecontents,
-						'',%mystyle);
+            if ($filetype eq 'html' || $filetype eq 'sty') {
+	        &Apache::structuretags::reset_problem_globals();
+	        $result = &Apache::lonxml::xmlparse($request,$target,
+                                                    $filecontents,'',%mystyle);
 	    # .html files may contain <problem> or <Task> need to clean
 	    # up if it did
-	    &Apache::structuretags::reset_problem_globals();
-	    &Apache::lonhomework::finished_parsing();
+	        &Apache::structuretags::reset_problem_globals();
+	        &Apache::lonhomework::finished_parsing();
+            } else {
+                $result = $filecontents;
+            }
 	    &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},
 						    ['rawmode']);
 	    if ($env{'form.rawmode'}) { $result = $filecontents; }
-	    if ($filetype eq 'sty') {
+	    if ($filetype ne 'html') {
+                my $nochgview = 1; 
 		my $controls =
-		    ($env{'request.state'} eq 'construct') ? &Apache::londefdef::edit_controls()
+		    ($env{'request.state'} eq 'construct') ? &Apache::londefdef::edit_controls($nochgview)
 		                                           : '';
-		my %options = ('bgcolor' => '#FFFFFF');
-		$result = 
-		    &Apache::loncommon::start_page(undef,undef,\%options).
-		    $controls.
-		    $result.
-		    &Apache::loncommon::end_page();
-	    }
+                if ($filetype ne 'sty') {
+                    $result =~ s/</&lt;/g;
+                    $result =~ s/>/&gt;/g;
+                    $result = '<table class="LC_sty_begin">'.
+                              '<tr><td><b><pre>'.$result.
+                              '</pre></b></td></tr></table>';
+                }
+                if ($env{'environment.remote'} eq 'off') {
+                    my %options = ('bgcolor' => '#FFFFFF');
+		    $result = 
+		        &Apache::loncommon::start_page(undef,undef,\%options).
+		        $controls.
+		        $result.
+		        &Apache::loncommon::end_page();
+                } else {
+                    $result = $controls.$result;
+                }
+            }
 	}
     }
 
@@ -1776,7 +1860,7 @@ ENDNOTFOUND
 		&Apache::lonxml::message_location().
 		$edit_info.
 		&Apache::loncommon::end_page();
-	}
+        }
     }
     if ($filetype eq 'html') { &writeallows($request->uri); }
     
@@ -2143,7 +2227,109 @@ sub get_tag {
     return $insertlist{"$tagnum.tag"};
 }
 
+############################################################
+#                                           PDF-FORM-METHODS
+
+=pod
+
+=item &print_pdf_radiobutton(fieldname, value,  text)
+
+Returns a latexline to generate a PDF-Form-Radiobutton with Text.
+
+$fieldname: PDF internalname of the radiobutton
+$value:     Value of radiobutton (read when dumping the PDF data)
+$text:      Text on the rightside of the radiobutton
+
+=cut
+sub print_pdf_radiobutton {
+    my $result = '';
+    my ($fieldName, $value, $text) = @_;
+    $result .= '\begin{tabularx}{\textwidth}{p{0cm}X}'."\n";
+    $result .= '\radioButton[\symbolchoice{circle}]{'. 
+               $fieldName.'}{10bp}{10bp}{'.$value.'}&'.$text."\n";
+    $result .= '\end{tabularx}' . "\n";
+    $result .= '\hspace{2mm}' . "\n";
+    return $result;
+}
+
+
+=pod
+
+=item &print_pdf_start_combobox(fieldname)
+
+Starts a latexline to generate a PDF-Form-Combobox with text.
+
+$fieldname: PDF internal name of the Combobox
+
+=cut
+sub print_pdf_start_combobox {
+    my $result;
+    my ($fieldName) = @_;
+    $result .= '\begin{tabularx}{\textwidth}{p{2.5cm}X}'."\n";
+    $result .= '\comboBox[]{'.$fieldName.'}{2.3cm}{14bp}{'; # 
+
+    return $result;
+}
+
+
+=pod
+
+=item &print_pdf_add_combobox_option(options)
+
+Generates a latexline to add Options to a PDF-Form-ComboBox.
+
+$option: PDF internal name of the Combobox-Option
+
+=cut
+sub print_pdf_add_combobox_option {
+
+    my $result;
+    my ($option) = @_;  
+
+    $result .= '('.$option.')';
+    
+    return $result;
+}
+
+
+=pod
+
+=item &print_pdf_end_combobox(text) {
+
+Returns latexcode to end a PDF-Form-Combobox with text.
+
+=cut
+sub print_pdf_end_combobox {
+    my $result;
+    my ($text) = @_;
+
+    $result .= '}&'.$text."\\\\\n";
+    $result .= '\end{tabularx}' . "\n";
+    $result .= '\hspace{2mm}' . "\n";
+    return $result;
+}
+
+
+=pod
+
+=item &print_pdf_hiddenField(fieldname, user, domain)
+
+Returns a latexline to generate a PDF-Form-hiddenField with userdata.
+
+$fieldname label for hiddentextfield
+$user:    name of user
+$domain:  domain of user
+
+=cut
+sub print_pdf_hiddenfield {
+    my $result;
+    my ($fieldname, $user, $domain) = @_;
+
+    $result .= '\textField [\F{\FHidden}\F{-\FPrint}\V{'.$domain.'&'.$user.'}]{'.$fieldname.'}{0in}{0in}'."\n";
+
+    return $result;
+}
+
 1;
 __END__
 
-
