@@ -1,7 +1,7 @@
 <!--
 The LearningOnline Network
 Resource Assembly Tool
-// $Id: ratcode.js,v 1.7 2007/07/12 19:54:40 albertel Exp $
+// $Id: ratcode.js,v 1.10 2009/04/23 13:09:44 bisitz Exp $
 //
 // Copyright Michigan State University Board of Trustees
 //
@@ -41,7 +41,7 @@ YEAR 2001
 -->
 
 
-<script language="JavaScript">
+<script type="text/javascript" language="JavaScript">
 
 var row=new Array();
 var maxrow=-1;
@@ -998,32 +998,32 @@ function drawcell (rtype,ctype,what,cm,obj1,ej,ek,ne) {
             mime=mime.toLowerCase();
         }
         parent.mapout.document.write
-         ('<img border=0 width='+cw[ctype]+' height='+rh[1]
-          +' src="'+raticons+'resource.gif">');
+         ('<img border="0" width="'+cw[ctype]+'" height="'+rh[1]
+          +'" src="'+raticons+'resource.gif" />');
        if (zscale==3) {
         if ((mime!='') && (ext!='true')) {
            parent.mapout.document.write
-           ('<br><img border=0 src="'+raticons+'left.gif"></a><a target="preview" href="'+
-           url+'.meta"><img border=0 src="'+iconpath+
-           'meta.gif"><a target="preview" href="'+url+
-           '"><img border=0 src="'+iconpath+mime+'.gif">'+
-           '<img border=0 src="'+raticons+'right.gif">');
+           ('<br /><img border="0" src="'+raticons+'left.gif" /></a><a target="preview" href="'+
+           url+'.meta"><img border="0" width="20" src="'+iconpath+
+           'meta.gif" /><a target="preview" href="'+url+
+           '"><img border="0" width="20" src="'+iconpath+mime+'.gif" />'+
+           '<img border="0" src="'+raticons+'right.gif" />');
         } else {
            parent.mapout.document.write
-           ('<br><img border=0 src="'+raticons+'middle.gif">');
+           ('<br /><img border="0" src="'+raticons+'middle.gif" />');
         }
         parent.mapout.document.write
-           ('<br><img border=0 src="'+raticons+'bottom.gif">');
+           ('<br /><img border="0" src="'+raticons+'bottom.gif" />');
        } else {
         parent.mapout.document.write
-           ('<br><img border=0  width='+cw[ctype]+' height='+rh[1]
-          +' src="'+raticons+'bottom.gif">');
+           ('<br /><img border="0" width="'+cw[ctype]+'" height="'+rh[1]
+          +'" src="'+raticons+'bottom.gif" />');
        }
      } else {
         if (what=='c:') {
            parent.mapout.document.write
-            ('<img border=0 width='+cw[ctype]+' height='+rh[rtype]
-             +' src="'+raticons+'condition.gif">');          
+            ('<img border="0" width="'+cw[ctype]+'" height="'+rh[rtype]
+             +'" src="'+raticons+'condition.gif" />');
         } else {
            if (what=='rs:') {
         mime='';
@@ -1038,26 +1038,26 @@ function drawcell (rtype,ctype,what,cm,obj1,ej,ek,ne) {
             mime=mime.toLowerCase();
         }
               parent.mapout.document.write
-               ('<img border=0 width='+cw[ctype]+' height='+rh[1]
-               +' src="'+raticons+'start.gif">');
+               ('<img border="0" width="'+cw[ctype]+'" height="'+rh[1]
+               +'" src="'+raticons+'start.gif" />');
        if (zscale==3) {
         if ((mime!='') && (ext!='true')) {
            parent.mapout.document.write
-           ('<br><img border=0 src="'+raticons+'left.gif"></a><a target="preview" href="'+
-           url+'.meta"><img border=0 src="'+iconpath+
-           'meta.gif"><a target="preview" href="'+url+
-           '"><img border=0 src="'+iconpath+mime+'.gif">'+
-           '<img border=0 src="'+raticons+'right.gif">');
+           ('<br /><img border="0" src="'+raticons+'left.gif" /></a><a target="preview" href="'+
+           url+'.meta"><img border="0" width="20" src="'+iconpath+
+           'meta.gif" /><a target="preview" href="'+url+
+           '"><img border="0" width="20" src="'+iconpath+mime+'.gif" />'+
+           '<img border="0" src="'+raticons+'right.gif" />');
         } else {
            parent.mapout.document.write
-           ('<br><img border=0 src="'+raticons+'middle.gif">');
+           ('<br /><img border="0" src="'+raticons+'middle.gif" />');
         }
         parent.mapout.document.write
-           ('<br><img border=0 src="'+raticons+'bottom.gif">');
+           ('<br /><img border="0" src="'+raticons+'bottom.gif" />');
        } else {
         parent.mapout.document.write
-           ('<br><img border=0  width='+cw[ctype]+' height='+rh[1]
-          +' src="'+raticons+'bottom.gif">');
+           ('<br /><img border="0"  width="'+cw[ctype]+'" height="'+rh[1]
+          +'" src="'+raticons+'bottom.gif" />');
        }
 
            } else {
@@ -1074,32 +1074,32 @@ function drawcell (rtype,ctype,what,cm,obj1,ej,ek,ne) {
             mime=mime.toLowerCase();
         }
                 parent.mapout.document.write
-                ('<img border=0 width='+cw[ctype]+' height='+rh[1]
-                +' src="'+raticons+'finish.gif">');
+                ('<img border="0" width="'+cw[ctype]+'" height="'+rh[1]
+                +'" src="'+raticons+'finish.gif" />');
        if (zscale==3) {
         if ((mime!='') && (ext!='true')) {
            parent.mapout.document.write
-           ('<br><img border=0 src="'+raticons+'left.gif"></a><a target="preview" href="'+
-           url+'.meta"><img border=0 src="'+iconpath+
-           'meta.gif"><a target="preview" href="'+url+
-           '"><img border=0 src="'+iconpath+mime+'.gif">'+
-           '<img border=0 src="'+raticons+'right.gif">');
+           ('<br /><img border="0" src="'+raticons+'left.gif" /></a><a target="preview" href="'+
+           url+'.meta"><img border="0" width="20" src="'+iconpath+
+           'meta.gif" /><a target="preview" href="'+url+
+           '"><img border="0" width="20" src="'+iconpath+mime+'.gif" />'+
+           '<img border="0" src="'+raticons+'right.gif" />');
         } else {
            parent.mapout.document.write
-           ('<br><img border=0 src="'+raticons+'middle.gif">');
+           ('<br /><img border="0" src="'+raticons+'middle.gif" />');
         }
         parent.mapout.document.write
-           ('<br><img border=0 src="'+raticons+'bottom.gif">');
+           ('<br /><img border="0" src="'+raticons+'bottom.gif" />');
        } else {
         parent.mapout.document.write
-           ('<br><img border=0  width='+cw[ctype]+' height='+rh[1]
-          +' src="'+raticons+'bottom.gif">');
+           ('<br /><img border="0"  width="'+cw[ctype]+'" height="'+rh[1]
+          +'" src="'+raticons+'bottom.gif" />');
        }
 
              } else {
                 parent.mapout.document.write
-                ('<img border=0 width='+cw[ctype]+' height='+rh[rtype]
-                +' src="'+raticons+rtype+'.'+ctype+'.'+what+'.gif">');
+                ('<img border="0" width="'+cw[ctype]+'" height="'+rh[rtype]
+                +'" src="'+raticons+rtype+'.'+ctype+'.'+what+'.gif" />');
              }
            }
         }
@@ -1119,8 +1119,8 @@ function drawcell (rtype,ctype,what,cm,obj1,ej,ek,ne) {
          ('onMouseOver="parent.code.infoclear();">');
       parent.mapout.document.write
          (
-         '<img border=0 width='+cw[ctype]+' height='+rh[rtype]
-        +' src="'+raticons+rtype+'.'+ctype+'.empty.gif"></a>');
+         '<img border="0" width="'+cw[ctype]+'" height="'+rh[rtype]
+        +'" src="'+raticons+rtype+'.'+ctype+'.empty.gif" /></a>');
    }
    parent.mapout.document.write('</td>');
  }
@@ -1373,8 +1373,8 @@ function draw () {
       for (k=0;k<=maxrow;k++) { rrow[row[k]]=k; }
       for (k=0;k<=maxcol;k++) { rcol[col[k]]=k; }
       parent.mapout.document.writeln(
-       '<table cellpadding=0 cellspacing=0 border=0 rows='
-       +disrows+' cols='+discols+'>');
+       '<table cellpadding="0" cellspacing="0" border="0" rows="'
+       +disrows+'" cols="'+discols+'">');
       for (kr=0;kr<=maxrow;kr++) {
         message("Generating Output Row "+kr); 
         drawrow(rrow[kr]); 
@@ -1406,24 +1406,24 @@ function infoclear() {
   inf.document.clear();
   inf.document.writeln
    ('<html><body bgcolor="#FFFFFF"><table><tr><td>'+
-    '<img src="/adm/lonIcons/lonlogos.gif"></td>');
+    '<img src="/adm/lonIcons/lonlogos.gif" /></td>');
   if (linkmode!=0) {
    if (tablemode==0) {
      inf.document.writeln(
-      '<td><b>Link Mode</b><hr>Click on a resource to link it with<br><b>'+
+      '<td><b>Link Mode</b><hr />Click on a resource to link it with<br /><b>'+
       (objcont[linkmode].split(':'))[0]+
-      '</b><br>click anywhere else to cancel.</td>');
+      '</b><br />click anywhere else to cancel.</td>');
    } else {
      inf.document.writeln(
-'<td><b>Link Mode</b><hr>Click on a resource number to link it with<br><b>'+
-     (objcont[linkmode].split(':'))[0]+'</b><br>'+
+'<td><b>Link Mode</b><hr />Click on a resource number to link it with<br /><b>'+
+     (objcont[linkmode].split(':'))[0]+'</b><br />'+
 '<a href="javascript:opener.linkmode=0;opener.notclear=0;opener.infoclear();">'
    +'Cancel</a></td>');
    }
   } else {
    if (tablemode==0) {
       inf.document.writeln(
-        '<td><b>Click to Edit</b><hr>Click in a light gray area<br>'
+        '<td><b>Click to Edit</b><hr />Click in a light gray area<br />'
        +'to insert resources, columns and rows</td>'
       );
    }
@@ -1471,7 +1471,7 @@ function info(infostr) {
   inf.document.clear();
   inf.document.writeln(
    '<html><body bgcolor="#FFFFFF">'+
-   '<table><tr><td width=32><img src="'+raticons+'info.gif"></td><td bgcolor="#AAFFAA">');
+   '<table><tr><td width="32"><img src="'+raticons+'info.gif" /></td><td bgcolor="#AAFFAA">');
   data1=infostr.split('&');
   if (data1[0]=='c') {
      inf.document.write('<b>Condition (');
@@ -1490,8 +1490,8 @@ function info(infostr) {
            }
        }
      }   
-     inf.document.writeln(')</b><hr>From <b>'+objcont[data3[0]].split(':')[0]+
-                 '</b><br>to <b>'+objcont[data3[1]].split(':')[0]+'</b>');
+     inf.document.writeln(')</b><hr />From <b>'+objcont[data3[0]].split(':')[0]+
+                 '</b><br />to <b>'+objcont[data3[1]].split(':')[0]+'</b>');
   } else {
      if (data1[0]=='r') {
         data2=objcont[data1[1]].split(':');
@@ -1503,8 +1503,8 @@ function info(infostr) {
         if (ext=='true') { mime=''; }
         if (mime!='') {
            inf.document.write
-           ('<br><a target="preview" align="right" href="'+url+
-           '"><img border=0 src="'+iconpath+mime+'.gif"></a>&nbsp;&nbsp;');
+           ('<br /><a target="preview" align="right" href="'+url+
+           '"><img border="0" width="20" src="'+iconpath+mime+'.gif" /></a>&nbsp;&nbsp;');
         }
        inf.document.write('<b>');
         if (data2[2]=='true') { inf.document.write('External '); }
@@ -1523,14 +1523,14 @@ function info(infostr) {
         if (data2[3]=='optional') {
            inf.document.write(' (Optional)');
         }
-        inf.document.writeln('</b><hr><b>'+data2[0]+'</b><br>');
+        inf.document.writeln('</b><hr /><b>'+data2[0]+'</b><br />');
         inf.document.writeln((data2[1].split('/')).join(' / '));
      } else {
-        inf.document.writeln('<b>Link</b><hr>');
+        inf.document.writeln('<b>Link</b><hr />');
         data2=obj[data1[0]].split('&');
         data3=objlinks[data2[data2.length-2]].split(':');
         inf.document.writeln('From <b>'+objcont[data3[0]].split(':')[0]+
-                 '</b><br>to <b>'+objcont[data3[1]].split(':')[0]+'</b>');
+                 '</b><br />to <b>'+objcont[data3[1]].split(':')[0]+'</b>');
      }
   }
   if (linkmode==0) {
@@ -1727,10 +1727,10 @@ function copydxopen(mode) {
    copydx.document.clear('');
    copydx.document.writeln(
  '<html><body bgcolor="#FFFFFF"><h1>Copy from Map</h1>'+
- '<form name="mapload"><input type=text size=40 name=importmap>'+
- '<input type=button onClick="javascript:opener.openbrowser'+
+ '<form name="mapload"><input type="text" size="40" name="importmap">'+
+ '<input type="button" onClick="javascript:opener.openbrowser'+
  "('mapload','importmap','sequence,page','')"+
- '" value="Browse"><input type=button value="Load Map" '+
+ '" value="Browse"><input type="button" value="Load Map" '+
  'onClick="window.location=document.mapload.importmap.value+'+
  "'?launch=1&forceselect=1'"+'"></form>');
 
@@ -1785,10 +1785,10 @@ function handler(infostr) {
   inf.document.clear();
   inf.document.writeln(
    '<html><body bgcolor="#FFFFFF">'+
-   '<table><tr><td width=32><img src="'+raticons+'edit.gif"></td><td bgcolor="#AAFFAA">');
+   '<table><tr><td width="32"><img src="'+raticons+'edit.gif" /></td><td bgcolor="#AAFFAA">');
   data1=infostr.split('&');
   if (data1[0]=='c') {
-     inf.document.writeln('<b>Condition</b><hr>');
+     inf.document.writeln('<b>Condition</b><hr />');
      linkmode=0;
      if (data1[4]=='-') {
         data2[0]=''; data2[1]='normal';
@@ -1796,20 +1796,20 @@ function handler(infostr) {
         data2=objcont[data1[4]].split(':');
      }
      inf.document.writeln(
-         '<form name=condinfo><textarea name=c cols=30 rows=3>'
-         +data2[0]+'</textarea><br><input type=radio name=s value=normal '+
+         '<form name="condinfo"><textarea name="c" cols="30" rows="3">'
+         +data2[0]+'</textarea><br /><input type="radio" name="s" value="normal" '+
     'onClick="self.document.forms.condinfo.elements.h.value='+"'normal'"+'"');
      if (data2[1]=='normal') { inf.document.write(' checked'); }
      inf.document.write(
-      '> Recommendation if true<br><input type=radio name=s value=stop '+
+      '> Recommendation if true<br /><input type="radio" name="s" value="stop" '+
       'onClick="self.document.forms.condinfo.elements.h.value='+"'stop'"+'"');
      if (data2[1]=='stop') { inf.document.write(' checked'); }
      inf.document.write(
-      '> Blocking this link if false<br><input type=radio name=s value=force '+
+      '> Blocking this link if false<br /><input type="radio" name="s" value="force" '+
       'onClick="self.document.forms.condinfo.elements.h.value='+"'force'"+'"');
      if (data2[1]=='force') { inf.document.write(' checked'); }
      inf.document.write(
-   '> Blocking other links if true<br><a href="javascript:opener.editmode=0;'
+   '> Blocking other links if true<br /><a href="javascript:opener.editmode=0;'
       +'opener.notclear=0;');
      if (data1[4]=='-') {
         inf.document.write('opener.crecond('+data1[2]+','+data1[1]+','
@@ -1823,19 +1823,19 @@ function handler(infostr) {
      inf.document.writeln(
       'opener.infoclear();opener.editmode=0;opener.draw('
       +');"><b>Save Changes</b></a>&nbsp;&nbsp;'
-    +' <a href="javascript:self.document.forms.condinfo.reset()">Reset</a><br>'
-      +'<input type=hidden name=h value='+data2[1]+'>');
+    +' <a href="javascript:self.document.forms.condinfo.reset()">Reset</a><br />'
+      +'<input type="hidden" name="h" value="'+data2[1]+'">');
 
         inf.document.writeln(
            '<a href="javascript:opener.notclear=0;opener.infoclear();'
    +'opener.delcond('+data1[2]+','+data1[1]+');opener.editmode=0;opener.draw('
-         +');">Delete Condition</a><br>');
+         +');">Delete Condition</a><br />');
           inf.document.writeln(
            '<a href="javascript:opener.notclear=0;opener.infoclear();'
    +'opener.dellink('+data1[3]+');opener.editmode=0;opener.draw('
          +');">Delete Link</a>');
 
-        inf.document.writeln('<br><a href="javascript:'+
+        inf.document.writeln('<br /><a href="javascript:'+
          'opener.insertcondlink('+data1[1]+','+data1[3]+');'+
          'opener.editmode=0;opener.notclear=0;opener.infoclear();opener.draw('
                               +');">Insert Resource Into Link</a>');
@@ -1860,34 +1860,34 @@ function handler(infostr) {
            }
         }
         inf.document.write(
-         '<form name=resinfo><table><tr><td>Title:</td><td colspan=2>'
-        +'<input type=text name=t size=30 value="'
-+escape(data2[0])+'"><input type=hidden name=h value='+data2[3]+'></td></tr>');
-           inf.document.write('<tr><td>URL:</td><td colspan=2>'
-        +'<input type=text name=u size=30 value="'+data2[1]+'"></td></tr>'
-        +'<tr><td>External:</td><td><input type=checkbox name=e');
-        if (data2[2]=='true') { inf.document.write(' checked'); }
-        inf.document.write('></td><td align=right>'
+         '<form name="resinfo"><table><tr><td>Title:</td><td colspan="2">'
+        +'<input type="text" name="t" size="30" value="'
++escape(data2[0])+'"><input type="hidden" name="h" value='+data2[3]+'></td></tr>');
+           inf.document.write('<tr><td>URL:</td><td colspan="2">'
+        +'<input type="text" name="u" size="30" value="'+data2[1]+'"></td></tr>'
+        +'<tr><td>External:</td><td><input type="checkbox" name="e"');
+        if (data2[2]=='true') { inf.document.write(' checked="checked"'); }
+        inf.document.write('></td><td align="right">'
         +'<a href="javascript:opener.idxcheck(\'interactive\')">Browse</a> '
         +'<a href="javascript:opener'
 	+'.srchcheck(\'interactive\')">Search</a></td></tr>');
     if ((data2[3]!='start') && (data2[3]!='finish')) {
-        inf.document.write('<tr><td colspan=3>'
-        +'<input type=radio name=y value=normal '+
+        inf.document.write('<tr><td colspan="3">'
+        +'<input type="radio" name="y" value="normal" '+
  'onClick="self.document.forms.resinfo.elements.h.value='+"'normal'"+'"');
-     if (data2[3]=='normal') { inf.document.write(' checked'); }
+     if (data2[3]=='normal') { inf.document.write(' checked="checked"'); }
      inf.document.write(
-      '> Regular&nbsp;&nbsp;<input type=radio name=y value=mandatory '+
+      '> Regular&nbsp;&nbsp;<input type="radio" name="y" value="mandatory" '+
  'onClick="self.document.forms.resinfo.elements.h.value='+"'mandatory'"+'"');
-     if (data2[3]=='mandatory') { inf.document.write(' checked'); }
+     if (data2[3]=='mandatory') { inf.document.write(' checked="checked"'); }
      inf.document.write(
-      '> Mandatory&nbsp;&nbsp;<input type=radio name=y value=optional '+
+      '> Mandatory&nbsp;&nbsp;<input type="radio" name="y" value="optional" '+
  'onClick="self.document.forms.resinfo.elements.h.value='+"'optional'"+'"');
-     if (data2[3]=='optional') { inf.document.write(' checked'); }
+     if (data2[3]=='optional') { inf.document.write(' checked="checked"'); }
      inf.document.write('> Optional</td></tr>');
     } 
         inf.document.writeln(
-         '<tr><td colspan=3><a href="javascript:opener.editmode=0;'
+         '<tr><td colspan="3"><a href="javascript:opener.editmode=0;'
         +'opener.notclear=0;opener.objcont['+data1[1]
         +']=opener.escape(self.document.forms.resinfo.elements.t.value)+'+"':'"
         +'+opener.escape(self.document.forms.resinfo.elements.u.value)+'+"':'"
@@ -1903,41 +1903,41 @@ function handler(infostr) {
          +'opener.delres('+data1[1]+',0);opener.editmode=0;opener.draw('
          +');">Delete Resource (cutting links)</a>');
         inf.document.writeln(
-          '<br><a href="javascript:opener.notclear=0;opener.infoclear();'
+          '<br /><a href="javascript:opener.notclear=0;opener.infoclear();'
          +'opener.delres('+data1[1]+',1);opener.editmode=0;opener.draw('
          +');">Delete Resource (preserving links)</a>');
     }
     if (data2[3]!='finish') {
         inf.document.writeln(
-          '<br><a href="javascript:opener.editmode=0;opener.notclear=0;'
+          '<br /><a href="javascript:opener.editmode=0;opener.notclear=0;'
          +'opener.linkmode='+data1[1]+';'
          +'opener.infoclear();">Link Resource</a>');
     }
         inf.document.writeln(
-          '<br><a href="javascript:'
+          '<br /><a href="javascript:'
          +'opener.setparms('+data1[1]+');'
          +'opener.infoclear();">Set Parameters</a>');
     
       }
      } else {
         linkmode=0;
-        inf.document.writeln('<b>Link</b><hr><form>');
+        inf.document.writeln('<b>Link</b><hr /><form>');
         data2=obj[data1[0]].split('&');
         k=data2[data2.length-2];
         data3=objlinks[k].split(':');
         inf.document.writeln('From <b>'+objcont[data3[0]].split(':')[0]+
-              '</b><br>to <b>'+objcont[data3[1]].split(':')[0]+'</b>');
-        inf.document.writeln('<br><a href="javascript:opener.dellink('+
+              '</b><br />to <b>'+objcont[data3[1]].split(':')[0]+'</b>');
+        inf.document.writeln('<br /><a href="javascript:opener.dellink('+
      k+');opener.editmode=0;opener.notclear=0;opener.infoclear();opener.draw('
                               +');">Delete Link</a>');
-        inf.document.writeln('<br><a href="javascript:'+
+        inf.document.writeln('<br /><a href="javascript:'+
          "opener.insertreslink('"+infostr+"');"+
          'opener.editmode=0;opener.notclear=0;opener.infoclear();opener.draw('
                               +');">Insert Resource Into Link</a>');
      }
   }
   inf.document.writeln(
-     '<br><a href="javascript:opener.editmode=0;opener.notclear=0;'
+     '<br /><a href="javascript:opener.editmode=0;opener.notclear=0;'
      +'opener.infoclear();">Cancel</a>');
   inf.document.writeln('</form></td></tr></table></body></html>');
   inf.document.close();
@@ -1957,10 +1957,10 @@ function empty(rid,k) {
   inf.document.clear();
   inf.document.writeln(
    '<html><body bgcolor="#FFFFFF">'+
-   '<table><tr><td width=32><img src="'+raticons+'edit.gif"></td><td bgcolor="#AAFFAA">'+
-   '<b>Empty Field</b><hr>');
+   '<table><tr><td width="32"><img src="'+raticons+'edit.gif" /></td><td bgcolor="#AAFFAA">'+
+   '<b>Empty Field</b><hr />');
 
-        inf.document.writeln('<br><a href="javascript:opener.newresource('+
+        inf.document.writeln('<br /><a href="javascript:opener.newresource('+
           rid+','+cid+",'','','false','normal');"+
          'opener.mostrecent=opener.obj.length-1;'+
          'opener.editmode=0;opener.notclear=0;opener.infoclear();opener.draw('
@@ -1969,14 +1969,14 @@ function empty(rid,k) {
   if ((mostrecent!=0) && (objcont[mostrecent]!='') && 
                          (typeof(objcont[mostrecent])!="undefined")) {
 
-        inf.document.writeln('<br><a href="javascript:opener.newresource('+
+        inf.document.writeln('<br /><a href="javascript:opener.newresource('+
           rid+','+cid+",'','','false','normal');"+
          'opener.mostrecent=opener.obj.length-1;'+
         'opener.joinres('+mostrecent+',opener.obj.length-1,0);'+
   'opener.editmode=0;opener.notclear=0;opener.infoclear();opener.draw('
           +');">Insert resource linked to from most recent one</a>');
 
-        inf.document.writeln('<br><a href="javascript:opener.newresource('+
+        inf.document.writeln('<br /><a href="javascript:opener.newresource('+
           rid+','+cid+",'','','false','normal');"+
          'opener.mostrecent=opener.obj.length-1;'+
         'opener.joinres(opener.obj.length-1,'+mostrecent+',0);'+
@@ -1985,7 +1985,7 @@ function empty(rid,k) {
   }
 
 
-  inf.document.writeln('<hr>Insert column:');
+  inf.document.writeln('<hr />Insert column:');
         inf.document.writeln('<a href="javascript:opener.insertcol('+
         lcol+');opener.addobj('+rid+",'e&'+opener.maxcol);"
        +'opener.editmode=0;opener.notclear=0;opener.infoclear();opener.draw('
@@ -1994,7 +1994,7 @@ function empty(rid,k) {
         k+');opener.addobj('+rid+",'e&'+opener.maxcol);"
        +'opener.editmode=0;opener.notclear=0;opener.infoclear();opener.draw('
                               +');">right</a> ');
-   inf.document.writeln('<br>Insert row:');
+   inf.document.writeln('<br />Insert row:');
         inf.document.writeln('<a href="javascript:opener.insertrow('+
         trow+');opener.addobj(opener.maxrow'+",'e&"+cid+"');"
        +'opener.editmode=0;opener.notclear=0;opener.infoclear();opener.draw('
@@ -2006,7 +2006,7 @@ function empty(rid,k) {
 
 
   inf.document.writeln(
-   '<br><a href="javascript:opener.editmode=0;opener.notclear=0;'
+   '<br /><a href="javascript:opener.editmode=0;opener.notclear=0;'
   +'opener.infoclear();">Cancel</a>');
   inf.document.writeln('</td></tr></table></body></html>');
   inf.document.close();
@@ -2158,9 +2158,9 @@ function tabledraw() {
         if ((mime!='') && (ext!='true')) {
            parent.mapout.document.write
            ('<a target="preview" align="right" href="'+url+'.meta'+
-           '"><img src="'+iconpath+'meta.gif"></a><p>'+
+           '"><img width="20" src="'+iconpath+'meta.gif" /></a><p>'+
            '<a target="preview" align="right"href="'+url+
-           '"><img src="'+iconpath+mime+'.gif"></a><p>');
+           '"><img width="20" src="'+iconpath+mime+'.gif" /></a><p>');
         }
          parent.mapout.document.write(
          '<b><a href="javascript:if (parent.code.linkmode!=0) { '
@@ -2168,7 +2168,7 @@ function tabledraw() {
         +'parent.code.linkmode=0;parent.code.editmode=0;'
         +'parent.code.notclear=0;parent.code.infoclear();'
         +'parent.code.draw(); }">'+k+'</a></b></td><td bgcolor="'+ck
-        +'"><form name=r'+i+' method=post>');
+        +'"><form name="r'+i+'" method="post">');
       data2=obj[i].split('&');
       parent.mapout.document.write('<table bgcolor="#CCCCCC">');
 
@@ -2179,35 +2179,35 @@ function tabledraw() {
          parent.mapout.document.writeln('<tr><td><b>Finish</b></td></tr>');
       }
       parent.mapout.document.write(
-       '<tr><td>Title:</td><td><input type=text name=t size=50 value="'
-            +data1[0]+'"><input type=hidden name=h value='+data1[3]
-            +'></td></tr>');
+       '<tr><td>Title:</td><td><input type="text" name="t" size="50" value="'
+            +data1[0]+'"><input type="hidden" name="h" value="'+data1[3]
+            +'"></td></tr>');
       parent.mapout.document.write(
-       '<tr><td>URL:</td><td><input type=text name=u size=50 value="'
+       '<tr><td>URL:</td><td><input type="text" name="u" size="50" value="'
                                   +data1[1]+'"></td></tr>'
-          +'<tr><td>External:</td><td><input type=checkbox name=e');
-        if (data1[2]=='true') { parent.mapout.document.write(' checked'); }
+          +'<tr><td>External:</td><td><input type="checkbox" name="e"');
+        if (data1[2]=='true') { parent.mapout.document.write(' checked="checked"'); }
         parent.mapout.document.write('></td></tr>');
     if ((data1[3]!='start') && (data1[3]!='finish')) {
         parent.mapout.document.write(
-        '<tr><td colspan=2><input type=radio name=y value=normal '+
+        '<tr><td colspan="2"><input type="radio" name="y" value="normal" '+
  'onClick="parent.mapout.document.forms.r'+i+'.elements.h.value='+
      "'normal'"+'"');
-     if (data1[3]=='normal') { parent.mapout.document.write(' checked'); }
+     if (data1[3]=='normal') { parent.mapout.document.write(' checked="checked"'); }
      parent.mapout.document.write(
-      '> Regular&nbsp;&nbsp;<input type=radio name=y value=mandatory '+
+      '> Regular&nbsp;&nbsp;<input type="radio" name="y" value="mandatory" '+
  'onClick="parent.mapout.document.forms.r'+i+'.elements.h.value='+
      "'mandatory'"+'"');
-     if (data1[3]=='mandatory') { parent.mapout.document.write(' checked'); }
+     if (data1[3]=='mandatory') { parent.mapout.document.write(' checked="checked"'); }
      parent.mapout.document.write(
-      '> Mandatory&nbsp;&nbsp;<input type=radio name=y value=optional '+
+      '> Mandatory&nbsp;&nbsp;<input type="radio" name="y" value="optional" '+
  'onClick="parent.mapout.document.forms.r'+i+'.elements.h.value='+
      "'optional'"+'"');
-     if (data1[3]=='optional') { parent.mapout.document.write(' checked'); }
+     if (data1[3]=='optional') { parent.mapout.document.write(' checked="checked"'); }
      parent.mapout.document.write('> Optional</td></tr>');
     } 
      parent.mapout.document.write(
-         '<tr><td colspan=2><a href="javascript:parent.code.objcont['+i        
+         '<tr><td colspan="2"><a href="javascript:parent.code.objcont['+i        
         +']=parent.code.escape(parent.mapout.document.forms.r'+i
         +'.elements.t.value)+'+"':'"
         +'+parent.code.escape(parent.mapout.document.forms.r'+i
@@ -2217,15 +2217,15 @@ function tabledraw() {
         +';parent.code.draw();">'
         +'<b>Save Changes</b></a>&nbsp;&nbsp;'
         +' <a href="javascript:parent.mapout.document.forms.r'+i
-        +'.reset()">Reset</a></td></tr><tr><td colspan=2>');
+        +'.reset()">Reset</a></td></tr><tr><td colspan="2">');
     if ((data1[3]!='start') && (data1[3]!='finish')) {
      parent.mapout.document.writeln(
- '<A href="javascript:parent.code.notclear=0;parent.code.infoclear();'
+ '<a href="javascript:parent.code.notclear=0;parent.code.infoclear();'
 +'parent.code.delres('+i+',0);parent.code.editmode=0;parent.code.draw();">'
-+'Delete Resource (cutting links)</A><br>'
-+'<A href="javascript:parent.code.notclear=0;parent.code.infoclear();'
++'Delete Resource (cutting links)</a><br />'
++'<a href="javascript:parent.code.notclear=0;parent.code.infoclear();'
 +'parent.code.delres('+i+',1);parent.code.editmode=0;parent.code.draw();">'
-+'Delete Resource (preserving links)</A><br>');
++'Delete Resource (preserving links)</a><br />');
     }
     if (data1[3]!='finish') {
        parent.mapout.document.writeln(
@@ -2234,11 +2234,11 @@ function tabledraw() {
        'Link resource</a>');
     }
         parent.mapout.document.writeln(
-          '<br><a href="javascript:'
+          '<br /><a href="javascript:'
          +'parent.code.setparms('+i+');">Set Parameters</a>');
 
       parent.mapout.document.writeln('</td></tr>');
-       parent.mapout.document.writeln('<tr><td colspan=2><table><tr>');
+       parent.mapout.document.writeln('<tr><td colspan="2"><table><tr>');
        for (j=2;j<data2.length;j++) {
            data4=data2[j].split(':');
            data3=objlinks[data4[2]].split(':');
@@ -2252,7 +2252,7 @@ function tabledraw() {
                    condid='-';
                  }                 
                  parent.mapout.document.writeln(
-                  '<td bgcolor='+cck+'>Next<br>');
+                  '<td bgcolor="'+cck+'">Next<br />');
                  parent.mapout.document.writeln(
                   '<a href="javascript:parent.code.handler('+
                   "'c&"+data4[0]+'&'+i+'&'+data4[2]+'&'+condid+"');"
@@ -2274,7 +2274,7 @@ function tabledraw() {
                    condid='-';
                  }
                  parent.mapout.document.writeln(
-                  '<td bgcolor='+cck+'>To: '+robjs[data3[1]]+'<br>');
+                  '<td bgcolor="'+cck+'">To: '+robjs[data3[1]]+'<br />');
                  parent.mapout.document.writeln(
                   '<a href="javascript:parent.code.handler('+
                   "'c&"+data4[0]+'&'+i+'&'+data4[2]+'&'+condid+"');"
@@ -2293,7 +2293,7 @@ function tabledraw() {
 
 // ----------------------------------------------------- Insert Resource Output
 function insrestab(irow,be,af,typ) {
-  parent.mapout.document.writeln('<tr><td colspan=2>'+
+  parent.mapout.document.writeln('<tr><td colspan="2">'+
        '<table><tr><td><a href="javascript:parent.code.insertrow('
        +irow+');parent.code.newresource(parent.code.maxrow,'+rcol[1]
  +",'','','false','normal');parent.code.mostrecent=parent.code.obj.length-1;"
@@ -2307,7 +2307,7 @@ function insrestab(irow,be,af,typ) {
        +"parent.code.save();"
        +'parent.code.joinres('+be+',parent.code.mostrecent,0);'
        +'parent.code.draw();">'
-       +'Insert resource linked to from above</a><br>');
+       +'Insert resource linked to from above</a><br />');
   }
   if ((be!=-1) && (af!=-1) && (typ!='finish')) {
      parent.mapout.document.writeln(
@@ -2319,7 +2319,7 @@ function insrestab(irow,be,af,typ) {
        +"parent.code.save();"
        +'parent.code.joinres(parent.code.mostrecent,'+af+',0);'
        +'parent.code.draw();">'
-       +'Insert resource linked to from above and linking to below</a><br>');
+       +'Insert resource linked to from above and linking to below</a><br />');
   }
   if (af!=-1) {
      parent.mapout.document.writeln(
@@ -2329,7 +2329,7 @@ function insrestab(irow,be,af,typ) {
        +"parent.code.save();"
        +'parent.code.joinres(parent.code.mostrecent,'+af+',0);'
        +'parent.code.draw();">'
-       +'Insert resource linking to below</a><br>');
+       +'Insert resource linking to below</a><br />');
   }
   parent.mapout.document.writeln('</td></tr></table></tr>');
 }
@@ -2376,9 +2376,9 @@ function simpletabledraw() {
         if ((mime!='') && (ext!='true')) {
            parent.mapout.document.write
            ('<a target="preview" align="right" href="'+url+'.meta'+
-           '"><img src="'+iconpath+'meta.gif"></a><p>'+
+           '"><img width="20" src="'+iconpath+'meta.gif" /></a><p>'+
            '<a target="preview" align="right"href="'+url+
-           '"><img src="'+iconpath+mime+'.gif"></a><p>');
+           '"><img width="20" src="'+iconpath+mime+'.gif" /></a><p>');
         }        
       parent.mapout.document.write('<b>'+k+'</b></td><td bgcolor="'+ck+'">');
       data2=obj[i].split('&');
@@ -2394,7 +2394,7 @@ function simpletabledraw() {
        '<tr><td>Title:</td><td>'+data1[0]+'</td></tr>');
       parent.mapout.document.write(
        '<tr><td>URL:</td><td>'+data1[1]+'</td></tr>'
-      +'<tr><td colspan=2><table><tr>');
+      +'<tr><td colspan="2"><table><tr>');
        for (j=2;j<data2.length;j++) {
            data4=data2[j].split(':');
            data3=objlinks[data4[2]].split(':');
@@ -2408,7 +2408,7 @@ function simpletabledraw() {
                    condid='-';
                  }                 
                  parent.mapout.document.writeln(
-                  '<td bgcolor='+cck+'>Next<br>');
+                  '<td bgcolor='+cck+'>Next<br />');
                   parent.mapout.document.writeln('</td>');
               }
            }
@@ -2426,7 +2426,7 @@ function simpletabledraw() {
                    condid='-';
                  }
                  parent.mapout.document.writeln(
-                  '<td bgcolor='+cck+'>To: '+robjs[data3[1]]+'<br>');
+                  '<td bgcolor="'+cck+'">To: '+robjs[data3[1]]+'<br />');
                  parent.mapout.document.writeln('</td>');
               }
            }
