@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Page Handler
 #
-# $Id: lonpage.pm,v 1.87.2.1 2008/12/21 04:29:47 raeburn Exp $
+# $Id: lonpage.pm,v 1.92 2009/10/26 10:17:58 foxr Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -27,6 +27,9 @@
 #
 ###
 
+
+
+
 package Apache::lonpage;
 
 use strict;
@@ -271,7 +274,7 @@ sub handler {
                               if ($target eq 'tex') {
 				  $output =~ s/^([^&]+)\\begin{document}//;
 				  $output =~ s/\\end{document}//;
-				  $output = '\parbox{\minipagewidth}{ '.$output.' }';
+#				  $output = '\parbox{\minipagewidth}{ '.$output.' }';
                                   #some additional cleanup necessary for LateX (due to limitations of table environment 
 				  $output =~ s/(\\vskip\s*\d+mm)\s*(\\\\)+/$1/g;
 			      }
@@ -394,17 +397,21 @@ sub handler {
 					.'">');
 			  }
 		      } elsif ($target eq 'tex') {
-			  $r->print('\documentclass{article}
-                                 \newcommand{\keephidden}[1]{}           
-                                 \usepackage[dvips]{graphicx}
-                                 \usepackage{epsfig}
-                                 \usepackage{calc}
-                                 \usepackage{longtable}
-                                 \begin{document}');
+			  #  I think this is not needed as the header
+			  # will be put in for each of the page parts
+			  # by the londefdef.pm now that we are opening up
+			  # the parts of a page.
+			  #$r->print('\documentclass{article}
+                          #       \newcommand{\keephidden}[1]{}           
+                          #       \usepackage[dvips]{graphicx}
+                          #       \usepackage{epsfig}
+                          #       \usepackage{calc}
+                          #       \usepackage{longtable}
+                          #       \begin{document}');
 		      }
 # ----------------------------------------------------------------- Start table
 		      if ($target eq 'tex') {
-			  $r->print('\begin{longtable}INSERTTHEHEADOFLONGTABLE\endfirsthead\endhead ');
+#			 #  $r->print('\begin{longtable}INSERTTHEHEADOFLONGTABLE\endfirsthead\endhead ');
 			  if ($number_of_columns le $lcm) {$number_of_columns=$lcm;};
 		      } else {
 			  $r->print('<table width="100%" cols="'.$lcm.'" border="0">');
@@ -471,22 +478,22 @@ sub handler {
 			      unless ($target eq 'tex') {
 				  $r->print('</td>');
 			      } else {
-                                  for (my $incol=1;$incol<=$avespan;$incol++) {
-				      $r->print(' & ');
-				  }
+#                                  for (my $incol=1;$incol<=$avespan;$incol++) {
+#				      $r->print(' & ');
+#				  }
 			      }
                           }
 			      unless ($target eq 'tex') {
 				  $r->print('</tr>');
 			      } else {
-				  $r->print('REMOVETHEHEADOFLONGTABLE\\\\');
+#				  $r->print('REMOVETHEHEADOFLONGTABLE\\\\');
 			      }
 		        }
                       }
 		      unless ($target eq 'tex') {
 			  $r->print("\n</table>");
 		      } else {
-			  $r->print('\end{longtable}\strut');
+#			  $r->print('\end{longtable}\strut');
 		      }
 # ---------------------------------------------------------------- Submit, etc.
                       if ($nforms) {
@@ -590,6 +597,7 @@ sub get_buttons {
 1;
 __END__
 
+
 =head1 NAME
 
 Apache::lonpage - Page Handler
@@ -691,5 +699,3 @@ tracetable() : Build page table.
 =cut
 
 
-
-
